c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *     *******     *     *     *  *******     *     *******     *       *
c     *     *     *    * *    *     *   *    *    * *       *       * *      *
c     *     *     *   *   *   *     *   *    *   *   *      *      *   *     *
c     *     *******  *******  *  *  *   *    *  *******     *     *******    * 
c     *     *   *    *     *  * * * *   *    *  *     *     *     *     *    * 
c     *     *    *   *     *  **   **   *    *  *     *     *     *     *    * 
c     *     *     *  *     *  *     *  *******  *     *     *     *     *    * 
c     *                                                                      *
c     *                                                                      *
c     *                       *   * ***** *****    *****   *   ***** *****   *
c     *                       *   * *     *   *    *   *   *   *   * *       *
c     *                       *   * ***** *****    *   *   *   *   * *****   *
c     *                        * *  *     *  *  ** *   *   *   *   *     *   *
c     *                         *   ***** *   * ** *****   *   ***** *****   *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *  program   :                                                         *
c     *                                                                      *
c     *               rawdata_v0500.f                                        *
c     *                                                                      *
c     *  objective :                                                         *
c     *                                                                      *
c     *               to retrieve individual raw data files                  *
c     *                                                                      *
c     *                                                                      *
c     *  input     :                                                         *
c     *                                                                      *
c     *                 unit 10  ==  ftp status                              *
c     *                                                                      *
c     *                 unit 20  ==  global GTS station list                 *
c     *                                                                      *
c     *                 unit 21  ==  daily global gts file                   *
c     *                                                                      *
c     *                 unit 22  ==  daily af235                             *
c     *                                                                      *
c     *                 unit 23  ==  daily af275                             *
c     *                                                                      *
c     *                 unit 24  ==  SSM/I rain estimates (global)           *
c     *                                                                      *
c     *                 unit 25  ==  SSM/I sampling number                   *
c     *                                                                      *
c     *                 unit 26  ==  AMSU rain estimates (global)            *
c     *                                                                      *
c     *                                                                      *
c     *  output    :                                                         *
c     *                                                                      *
c     *                 ( raw data at their original resolutions )           *
c     *                                                                      *
c     *                 unit 51  == raw GTS station data                     *
c     *                             over the target domain                   *
c     *                             krain0 (ngauge)                          *
c     *                                                                      *
c     *                 unit 52  == raw GPI estimates                        *
c     *                             at resolution of 0.10 deg grid points    *
c     *                             pgpi0 (nx000,ny000) = precip  (mm/day)   *
c     *                             sgpi0 (nx000,ny000) = sampling           *
c     *                                                                      *
c     *                 unit 53  == Fractional coverage of clouds/surface    *
c     *                             colder than 275K at 0.1 deg grd          *
c     *                             fc275 (nx000,ny000) = fractional coverage*
c     *                                                                      *
c     *                 unit 54  == raw SSM/I estimates                      *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pssm0 ( nx025, ny025 ) = precip (mm/day) *
c     *                             sssm0 ( nx025, ny025 ) = sampling        *
c     *                                                                      *
c     *                 unit 55  == raw AMSU  estimates                      *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pams0 ( nx025, ny025 ) = precip (mm/day) *
c     *                             sams0 ( nx025, ny025 ) = sampling        *
c     *                                                                      *
c     *                                                                      *
c     *                 unit 57  == raw data availability                    *
c     *                             krawout ( 1) = GTS                       *
c     *                                     ( 2) = GPI                       *
c     *                                     ( 3) = AF275                     *
c     *                                     ( 4) = SSM/I                     *
c     *                                     ( 5) = AMSU                      *
c     *                                     ( 6) = GDAS                      *
c     *                                                                      *
c     *                                                                      *
c     *  programmer  :                                                       *
c     *                                                                      *
c     *                 Pingping Xie  / Vadlamani Kumar / Tim Love           *
c     *                 NOAA Climate Prediction Center                       *
c     *                 5200 Auth Road, #805B                                *
c     *                 Camp Springs, MD 20746                               *
c     *                                                                      *
c     *                 Tel.    (301)763-8000, ext.7572                      *
c     *                 Fax     (301)763-8125                                *
c     *                 E-mail: xping@sgi17.wwb.noaa.gov                     *
c     *                 E-mail: tim.love@noaa.gov                            *
c     *                                                                      *
c     *  date        :                                                       *
c     *                                                                      *
c     *                 coded    on September 15, 1999                       *
c     *                 modified on December, 1999                           *
c     *                 modified on 2005-08-18 for fews(lnx)                 *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c 
      integer*2   kgts ( 2534 )  
      dimension   kstatus (6), krawout (5),
     #            pgpi  (751, 801), sgpi  (751, 801), 
     #            fc275 (751, 801), 
     #            pssmi (300, 320), sssmi (300, 320),
     #            pamsu (300, 320), samsu (300, 320)   

c  
c     ************************************************************************
c     *                                                                      *
c     *  1.  to open the data files                                          *
c     *                                                                      *
c     ************************************************************************
      print *, '  ' 
      print *, '*******************************************************' 
      print *, '  ' 
      print *, ' ::: STEP 1: RAW DATA ::: ' 
      print *, '  '

      open  (unit=51, 
     #       file = 'africa_raw_gts_station.bin',
     #       access='direct',status='unknown',recl=2534*2)
      open  (unit=52,
     #       file = 'africa_raw_gpi.bin',
     #       access='direct',status='unknown',recl=751*801*4)
      open  (unit=53,
     #       file = 'africa_raw_af275.bin',
     #       access='direct',status='unknown',recl=751*801*4)
      open  (unit=54, 
     #       file = 'africa_raw_ssmi.bin',  
     #       access='direct',status='unknown',recl=300*320*4)
      open  (unit=55, 
     #       file = 'africa_raw_amsu.bin', 
     #       access='direct',status='unknown',recl=300*320*4)


      open  (unit=57, 
     #       file = 'africa_raw_status.txt',  
     #       access='sequential', status='unknown',form='formatted')       
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to check the ftp status file                                    *
c     *         kststus ( 1)  ==  status for GTS                             *
c     *                 ( 2)  ==             GPI                             *
c     *                 ( 3)  ==             AF275                           *
c     *                 ( 4)  ==             SSM/I rain                      *
c     *                 ( 5)  ==             SSM/I sampling                  *
c     *                 ( 6)  ==             AMSU rain                       *
c     *                                                                      *
c     *                    0  ==  available                                  *
c     *                 other ==  not available                              *
c     *                                                                      *
c     ************************************************************************
c 
      open  (unit=10, 
     #       file='../input/file_ready_status', 
     #       access='sequential', status='old',form='formatted')       
c
      read  (10,   *)  kyy, kmm, kdd 
      do 2001 kk = 1, 6 
        read  (10, *)  kstatus(kk) 
 2001 continue 
      write  (6,*)  'started rawdata for:',kyy,kmm,kdd 
      write  (6,2951)  (kstatus(kk),kk=1,6) 
 2951 format  ('      ftp status:',6i2) 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to get the GTS data over the africa domain                      *
c     *                                                                      *
c     ************************************************************************
c 
      kinp = kstatus (1)  

      call  raw_gts ( kinp, kyy, kmm, kdd, nrep, nobs, kgts )   
      if  (kinp.eq.0.and.nobs.ge.200)  then 
        krawout (1) = 1 
      else 
        krawout (1) = 0 
      end  if  
      write  (6,*)  '     finished raw_gts !!', nrep, nobs, krawout (1)   
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to get the gpi data over the africa domain                      *
c     *                                                                      *
c     ************************************************************************
c
      kinp = kstatus (2) 
      call raw_af235 ( kinp, pgpi, sgpi )  
      nt   = 0 
      ngpi = 0 
      do 4001 jj = 1, 801 
      do 4001 ii = 1, 751 
        nt  =  nt  + 1 
        if  (pgpi(ii,jj).ge.0.0)  then 
          ngpi = ngpi + 1 
        end  if  
 4001 continue 
      nt  =  nint (nt *0.7)  
      if  (kinp.eq.0.and.ngpi.ge.nt)  then 
        krawout (2) = 1 
      else 
        krawout (2) = 0 
      end  if  

      write  (6,*)  '     finished raw_gpi !!', krawout (2)  
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to get the fractional coverage at 275K                          *
c     *                                                                      *
c     ************************************************************************
c
      kinp = kstatus (3)
      call raw_af275 ( kinp, fc275 )
      nt   = 0
      n275 = 0
      do 5001 jj = 1, 801   
      do 5001 ii = 1, 751   
        nt  =  nt  + 1
        if  (fc275(ii,jj).ge.0.0)  then
          n275 = n275 + 1
        end  if 
 5001 continue
      nt  =  nint (nt *0.7)  
      if  (kinp.eq.0.and.n275.ge.nt)  then 
        krawout (3) = 1 
      else 
        krawout (3) = 0 
      end  if  
      write  (6,*)  '     finished raw_af275 !!', krawout (3) 
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to get the ssm/i data over the africa domain                    *
c     *                                                                      *
c     ************************************************************************
c
      kinp1 = kstatus (4) 
      kinp2 = kstatus (5) 
      call raw_ssmi ( kinp1, kinp2, pssmi, sssmi ) 
      nt    = 0 
      nssmi = 0 
      do 6001 jj = 1, 320 
      do 6001 ii = 1, 300 
        nt  =  nt  + 1 
        if  (pssmi(ii,jj).ge.0.0)  then 
          nssmi = nssmi + 1 
        end  if  
 6001 continue 
      nt  =  nint (nt*0.7) 
      if  (kinp1.eq.0.and.
     #     kinp2.eq.0.and.
     #     nssmi.ge.nt)  then 
        krawout (4) = 1 
      else 
        krawout (4) = 0 
      end  if  
      write  (6,*)  '     finished raw_ssmi !!', krawout (4)
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to get the amsu data over the africa domain                     *
c     *                                                                      *
c     ************************************************************************
c
      kinp = kstatus (6) 
      call raw_amsu ( kinp, pamsu, samsu ) 
      nt    =  0 
      namsu = 0 
      do 7001 jj = 1, 320  
      do 7001 ii = 1, 300 
        nt  = nt  + 1 
        if  (pamsu(ii,jj).ge.0.0)  then 
          namsu = namsu + 1
        end  if  
 7001 continue 
      nt  =  nint (nt*0.6) 
      if  (kinp.eq.0.and.namsu.ge.nt)  then 
        krawout (5) = 1 
      else 
        krawout (5) = 0 
      end  if  
      write  (6,*)  '     finished raw_ams !!', krawout (5) 
c

c
c     ************************************************************************
c     *                                                                      *
c     *  9.  to output the raw data over the Africa domain                   *
c     *                                                                      *
c     ************************************************************************
c
      write  (51,rec=1)   kgts 
      write  (52,rec=1)   pgpi 
      write  (52,rec=2)   sgpi 
      write  (53,rec=1)   fc275  
      write  (54,rec=1)   pssmi   
      write  (54,rec=2)   sssmi   
      write  (55,rec=1)   pamsu   
      write  (55,rec=2)   samsu    

      write  (57,5951)    (krawout(kk),kk=1,5) 
 5951 format  (6i2) 
      write  (6,*)  '     finished output raw data !!' 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  10.  to close files                                                 *
c     *                                                                      *
c     ************************************************************************
c
      close  (unit=51) 
      close  (unit=52) 
      close  (unit=53) 
      close  (unit=54) 
      close  (unit=55) 

      close  (unit=57) 
c
      write  (6,*)  'finished rawdata !!'
c
      stop 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *       *******    *    *     *         ******* ******* *******        *
c     *       *     *   * *   *     *         *          *    *              *
c     *       *     *  *   *  *     *         *          *    *              *
c     *       ******* ******* *  *  *         *  ****    *    *******        *
c     *       *   *   *     * * * * *         *     *    *          *        *
c     *       *    *  *     * **   **         *     *    *          *        *
c     *       *     * *     * *     * ******* *******    *    *******        *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine :                                                       *
c     *                                                                      *
c     *                raw_gts                                               *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to retrieve the gauge data over Africa from           *
c     *                the global GTS file                                   *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kinp    ==  status of ftp for the global GTS file     *
c     *                                                                      *
c     *                kyy     ==  year (yyyy)                               *
c     *                                                                      *
c     *                kmm     ==  month (mm)                                *
c     *                                                                      *
c     *                kdd     ==  day   (dd)                                *
c     *                                                                      *
c     *                unit 20 ==  GTS station list                          *
c     *                                                                      *
c     *                unit 21 ==  global daily GTS data file                *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                nrep    ==  number of GTS reports                     *
c     *                                                                      *
c     *                nobs    ==  number of non-missing observations        *
c     *                                                                      *
c     *                kgts    ==  GTS gauge data over Africa                *
c     *                                                                      *
c     ************************************************************************
c 
      subroutine  raw_gts  ( kinp, kyy, kmm, kdd, nrep, nobs, kgts ) 
c
      integer*2     kgts (2534), krain   
      character*5   cstat(2534), cname1, cname2  
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      nrep = 0 
      nobs = 0 
      do 1001 kk = 1, 2534 
        kgts (kk) = -999 
 1001 continue 
      if  (kinp.ne.0)  then 
        return 
      end  if  
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the gts data array over Africa                        *
c     *                                                                      *
c     ************************************************************************
c
c     2.1  to open the GTS files  
      open  (unit=20, 
     #       file='../lib/africa_gts_station_list.txt', 
     #       access='sequential',status='old',form='formatted') 
      open  (unit=21, 
     #       file='../input/input_gts.dat',
     #       access='sequential',status='old',form='formatted') 
c
c     2.2  to read in the station ID 
      do 2001 kk=1,2534  
        read  (20,2901)  cstat(kk) 
 2001 continue 
 2901 format  (15x,a5)   
c
c     2.3  to read in the GTS rain data 
 2002 continue 
      if  (kyy.le.1999.and. 
     #     kmm.le.12.and. 
     #     kdd.le.30)  then  
        read  (21,2902,end=2999)   kyy1,kmm1,kdd1,cname1,krain   
        kyy0  = kyy1 + 1900 
      else 
        read  (21,2903,end=2999)   kyy1,kmm1,kdd1,cname1,krain 
       print *, kyy1,kmm1,kdd1,cname1
        kyy0 = kyy1 
      end  if  
 2902 format  (1x,3i2,1x,a5,35x,i4) 
 2903 format  (i4,2i2,1x,a5,35x,i4)
c 2903 format  (i4,2i2,10x,a6,49x,i4) 

      if  (kyy.eq.kyy0.and. 
     #     kmm.eq.kmm1.and. 
     #     kdd.eq.kdd1)  then 
        nrep = nrep + 1 
        call capital_name (cname1,cname2) 
        do 2003 kk = 1, 2534 
          if  (cname2.eq.cstat(kk))  then 
            if  (krain.ne.9999)  then 
              nobs      = nobs + 1 
              kgts (kk) = krain 
            end  if  
            go  to  2002 
          end  if  
 2003   continue 
        go  to  2002 
      else 
        go  to  2002 
      end  if  
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to close files                                                  *
c     *                                                                      *
c     ************************************************************************
c
 2999 continue 
      close  (unit=20) 
      close  (unit=21) 
c
      return 
      end  
c
c
c
      subroutine  capital_name (cname0,cname1) 
c
      character*5  cname0,cname1 
c
      do 1001 kk=1,5 
        if  (cname0(kk:kk).eq.'a')  then 
          cname1(kk:kk)='A'  
        else  if  (cname0(kk:kk).eq.'b')  then 
          cname1(kk:kk)='B' 
        else  if  (cname0(kk:kk).eq.'c')  then 
          cname1(kk:kk)='C' 
        else  if  (cname0(kk:kk).eq.'d')  then 
          cname1(kk:kk)='D' 
        else  if  (cname0(kk:kk).eq.'e')  then 
          cname1(kk:kk)='E' 
        else  if  (cname0(kk:kk).eq.'f')  then 
          cname1(kk:kk)='F' 
        else  if  (cname0(kk:kk).eq.'g')  then 
          cname1(kk:kk)='G' 
        else  if  (cname0(kk:kk).eq.'h')  then 
          cname1(kk:kk)='H' 
        else  if  (cname0(kk:kk).eq.'i')  then 
          cname1(kk:kk)='I' 
        else  if  (cname0(kk:kk).eq.'j')  then 
          cname1(kk:kk)='J' 
        else  if  (cname0(kk:kk).eq.'k')  then 
          cname1(kk:kk)='K' 
        else  if  (cname0(kk:kk).eq.'l')  then 
          cname1(kk:kk)='L' 
        else  if  (cname0(kk:kk).eq.'m')  then 
          cname1(kk:kk)='M' 
        else  if  (cname0(kk:kk).eq.'n')  then 
          cname1(kk:kk)='N' 
        else  if  (cname0(kk:kk).eq.'o')  then 
          cname1(kk:kk)='O' 
        else  if  (cname0(kk:kk).eq.'p')  then 
          cname1(kk:kk)='P' 
        else  if  (cname0(kk:kk).eq.'q')  then 
          cname1(kk:kk)='Q' 
        else  if  (cname0(kk:kk).eq.'r')  then 
          cname1(kk:kk)='R' 
        else  if  (cname0(kk:kk).eq.'s')  then 
          cname1(kk:kk)='S' 
        else  if  (cname0(kk:kk).eq.'t')  then 
          cname1(kk:kk)='T' 
        else  if  (cname0(kk:kk).eq.'u')  then 
          cname1(kk:kk)='U' 
        else  if  (cname0(kk:kk).eq.'v')  then 
          cname1(kk:kk)='V' 
        else  if  (cname0(kk:kk).eq.'w')  then 
          cname1(kk:kk)='W' 
        else  if  (cname0(kk:kk).eq.'x')  then 
          cname1(kk:kk)='X' 
        else  if  (cname0(kk:kk).eq.'y')  then 
          cname1(kk:kk)='Y' 
        else  if  (cname0(kk:kk).eq.'z')  then 
          cname1(kk:kk)='Z' 
        else  
          cname1(kk:kk)=cname0(kk:kk)  
        end  if  
 1001 continue 
c
      return 
      end 
c
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *  *******    *    *     *        *    ******* ******* ******* ******* *
c     *  *     *   * *   *     *       * *   *             *       * *       *
c     *  *     *  *   *  *     *      *   *  *             *       * *       *
c     *  ******* ******* *  *  *     ******* ******* ******* ******* ******* *
c     *  *   *   *     * * * * *     *     * *       *             *       * *
c     *  *    *  *     * **   **     *     * *       *             *       * *
c     *  *     * *     * *     * *** *     * *       ******* ******* ******* *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine :                                                       *
c     *                                                                      *
c     *                raw_af235                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to retrieve the fractional coverage at 235K           *
c     *                and GPI estimates                                     *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kinp    ==  status of ftp for the FC235               *
c     *                                                                      *
c     *                unit 28 ==  fc235 data                                *
c     *                                                                      *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                fc235   ==  fractional coverage at 235K               *
c     *                                                                      *
c     *                gpi     ==  gpi estimates                             *
c     *                                                                      *
c     ************************************************************************
c  
      subroutine  raw_af235  ( kinp, gpi, samp ) 
c
      dimension   fc235 (751,801), gpi (751,801), 
     #            samp  (751,801)  
      integer test
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, 801 
      do 1001 ii = 1, 751 
        fc235 (ii,jj) = -999.0 
        gpi   (ii,jj) = -999.0 
        samp  (ii,jj) =    0.0 
 1001 continue 
      if  (kinp.ne.0)  then
        return
      end  if
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the grads file of fc235                               *
c     *                                                                      *
c     ************************************************************************
c
      open  (unit=22,
     #       file = '../input/input_gpi_235.dat',
     #       access='direct',status='old',recl=751*801*4)
c
      write  (6,*)  'started reading fc235' 
      read  (22,rec=1)   fc235 
      write  (6,*)  'finished reading fc235' 
      write  (6,*)  'started reading samp' 
      read  (22,rec=2)   samp 
      write  (6,*)  'finished reading samp' 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define the grads file of fc235                               *
c     *                                                                      *
c     ************************************************************************
c
      test=0
      do 3001 jj = 1, 801  
      do 3001 ii = 1, 751 
c           print *, fc235(ii,jj)
        if  (fc235 (ii,jj).ge.0.0.and.
     #       samp  (ii,jj).ge.4.0)  then 
          test=test+1
          gpi  (ii,jj) = 72.0 * fc235 (ii,jj) / samp(ii,jj)  
        else 
          gpi  (ii,jj) = -999.0 
        end  if  

 3001 continue 
c          print *, "test=",test
c        print *, samp
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to close files                                                  *
c     *                                                                      *
c     ************************************************************************
c
      close  (unit=22) 
c
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *  *******    *    *     *        *    ******* ******* ******* ******* *
c     *  *     *   * *   *     *       * *   *             *       * *       *
c     *  *     *  *   *  *     *      *   *  *             *       * *       *
c     *  ******* ******* *  *  *     ******* ******* *******       * ******* *
c     *  *   *   *     * * * * *     *     * *       *             *       * *
c     *  *    *  *     * **   **     *     * *       *             *       * *
c     *  *     * *     * *     * *** *     * *       *******       * ******* *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine :                                                       *
c     *                                                                      *
c     *                raw_af275                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to retrieve the fractional coverage at 275K           *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kinp    ==  status of ftp for the FC275               *
c     *                                                                      *
c     *                unit 23 ==  fc275 data                                *
c     *                                                                      *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                fc275   ==  fractional coverage at 275K               *
c     *                                                                      *
c     ************************************************************************
c  
      subroutine  raw_af275  ( kinp, fc275 ) 
c
      dimension   fc275 (751,801), fc000 (751,801)  
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, 801 
      do 1001 ii = 1, 751 
        fc275 (ii,jj) = -999.0 
 1001 continue 
      if  (kinp.ne.0)  then
        return
      end  if
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the grads file of fc275                               *
c     *                                                                      *
c     ************************************************************************
c
      open  (unit=23,
     #       file = '../input/input_gpi_275.dat',
     #       access='direct',status='old',recl=751*801*4) 
c
      read  (23,rec=1)   fc275 
      read  (23,rec=2)   fc000 
c
      do 2001 jj = 1, 801 
      do 2001 ii = 1, 751 
        if  (fc275(ii,jj).ge.0.0.and.
     #       fc000(ii,jj).ge.4.0)  then 
          fc275 (ii,jj) = fc275 (ii,jj) / fc000 (ii,jj) 
        else 
          fc275 (ii,jj) = -999.0 
        end  if  
 2001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to close files                                                  *
c     *                                                                      *
c     ************************************************************************
c
      close  (unit=23) 
c
      return 
      end 
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******    *    *     *     ******* ******* *     * *******      *
c     *     *     *   * *   *     *     *       *       **   **    *         *
c     *     *     *  *   *  *     *     *       *       * * * *    *         *
c     *     ******* ******* *  *  *     ******* ******* *  *  *    *         *
c     *     *   *   *     * * * * *           *       * *     *    *         *
c     *     *    *  *     * **   **           *       * *     *    *         *
c     *     *     * *     * *     * *** ******* ******* *     * *******      *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine :                                                       *
c     *                                                                      *
c     *                raw_ssmi                                              *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to retrieve the precip estimates and sampling size    *
c     *                for SSM/I                                             *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kinp1   ==  status of ftp for the SSM/I rain          *
c     *                                                                      *
c     *                kinp2   ==  status of ftp for the SSM/I numb          *
c     *                                                                      *
c     *                unit 24 ==  SSM/I rain data                           *
c     *                                                                      *
c     *                unit 25 ==  SSM/I sampling size                       *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                pssmi   ==  SSM/I precip estimates                    *
c     *                                                                      *
c     *                sssmi   ==  SSM/I sampling size                       *
c     *                                                                      *
c     ************************************************************************
c  
      subroutine  raw_ssmi  ( kinp1, kinp2, pssmi, sssmi ) 
c
c
      character   cinp*5760, cout*5760   
      dimension   rain00 (1440), samp00 (1440)  
c
c
      dimension   pssmi (300,320), sssmi (300,320) 
c
      dimension   rain0 (1440,720), rain (1440,720) 
      dimension   rain1 (1440,720), gnumb1 (1440,720)
c      integer*2   numb0 (1440,720), numb (1440,720)   
      dimension   gnumb0 (1440,720), gnumb (1440,720)  
c 
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, 320  
      do 1001 ii = 1, 300  
        pssmi (ii,jj) = -999.0 
        sssmi (ii,jj) = 0.0 
 1001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2. to define the grads file for SSM/I rain data                     *
c     *                                                                      *
c     ************************************************************************
c
c     2.1  to check the data availability 
      if  (kinp1.ne.0)  then
        go to 3000  
      end  if
c 
c     2.2  to open the data file 
c      open  (unit=24, 
      open  (unit=24,convert='little_endian', 
     #       file='input_ssmi_rain.dat',
     #       access='direct',status='old',recl=1440*720*4)      

c     2.3  to read and define for the globe 
      read (24,rec=1) rain1
      do 2001 jj = 1, 720 
      do 2001 ii = 1, 1440 
        js = jj 
	is = ii
        if  (rain1(ii,jj).lt.0.0)  then 
          rain (is,js) = -999.0 
        else 
          rain (is,js) = rain1 (ii,jj)   
        end  if  
 2001 continue
c
c     2.4  to define for the Africa domain 
      do 2002 jj = 1, 321  
      do 2002 ii = 1, 301  
        j0 = jj + 200 
        if  (ii.le.80)  then 
          i0 = ii + 1360 
        else 
          i0 = ii - 80 
        end  if   
        if  (rain(i0,j0).ge.0.0)  then 
          pssmi (ii,jj) = 24.0 * rain (i0,j0) 
        else 
          pssmi (ii,jj) = -999.0 
        end  if 
 2002 continue 
      close  (unit=24) 
c
c     ************************************************************************
c     *                                                                      *
c     *  3. to define the grads file for SSM/I sampling size                 *
c     *                                                                      *
c     ************************************************************************
c
 3000 continue 
c
c     3.1  to check the data availability 
      if  (kinp2.ne.0)  then
        go to 9999  
      end  if
c 
c     3.2  to open the data file 
      open  (unit=25,convert='little_endian',         
     #       file='input_ssmi_num.dat',
     #       access='direct',status='old',recl=1440*720*4)

c     3.3  to read and define for the globe
      read (25,rec=1) gnumb1
      do 3001 jj = 1, 720  
      do 3001 ii = 1, 1440  
        js = jj  
	is = ii
        gnumb (is,js) = gnumb1 (is,js) 
 3001 continue
c
c     3.4  to define for the Africa domain 
      do 3002 jj = 1, 320  
      do 3002 ii = 1, 300    
        j0 = jj + 200   
        if  (ii.le.80)  then   
          i0 = ii + 1360   
        else   
          i0 = ii - 80   
        end  if     
        if  (gnumb(i0,j0).gt.0.0)  then    
          sssmi (ii,jj) = gnumb(i0,j0)     
        else   
          sssmi (ii,jj) = 0.0   
        end  if   
 3002 continue  
      close  (unit=25) 
c
 9999 return 
      end 
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******    *    *     *        *    *     * ******* *     *      *
c     *     *     *   * *   *     *       * *   **   ** *       *     *      *
c     *     *     *  *   *  *     *     *    *  * * * * *       *     *      *
c     *     ******* ******* *  *  *     ******* *  *  * ******* *     *      *
c     *     *   *   *     * * * * *     *     * *     *       * *     *      *
c     *     *    *  *     * **   **     *     * *     *       * *     *      *
c     *     *     * *     * *     * *** *     * *     * ******* *******      *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine :                                                       *
c     *                                                                      *
c     *                raw_amsu                                              *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to retrieve the precip estimates and sampling size    *
c     *                for AMSU                                              *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kinp    ==  status of ftp for the amsu data           *
c     *                                                                      *
c     *                unit 26 ==  AMSU data                                 *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                pamsu   ==  AMSU precip estimates                     *
c     *                                                                      *
c     *                samsu   ==  AMSU sampling size                        *
c     *                                                                      *
c     ************************************************************************
c  
      subroutine  raw_amsu  ( kinp, pamsu, samsu ) 
c
      dimension   pamsu (300,320), samsu (300,320) 
c
c
      dimension   globe (1440,720), 
     #            rain  (1440,720), samp  (1440,720)  
c 
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, 320  
      do 1001 ii = 1, 300  
        pamsu (ii,jj) = -999.0 
        samsu (ii,jj) = 0.0 
 1001 continue 
      if  (kinp.ne.0)  then
        return
      end  if
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the grads file over the global domain                 *
c     *                                                                      *
c     ************************************************************************
c
c     2.1  to open the global file 
      open  (unit=26,
     #       file='input_amsu.dat',
     #       access='direct',status='old',recl=1440*720*4)
c
c     2.2  to define the global data    
      do 2001 jj = 1, 720 
      do 2001 ii = 1, 1440  
        samp (ii,jj) = 0.0 
        rain (ii,jj) = 0.0 
 2001 continue 
      do 2003 kk = 1, 4 
        read  (26,rec=kk)   globe 
        do 2002 jj = 1, 720 
        do 2002 ii = 1, 1440 
          if  (globe(ii,jj).ge.0.0)  then 
            samp (ii,jj) = samp (ii,jj) + 1.0 
            rain (ii,jj) = rain (ii,jj) + globe (ii,jj) 
          end  if  
 2002   continue 
 2003 continue 
      do 2004 jj = 1, 720 
      do 2004 ii = 1, 1440 
        if  (samp(ii,jj).gt.0.0)  then 
          rain (ii,jj) = rain (ii,jj) / samp (ii,jj) 
        else 
          rain (ii,jj) = -999.0 
        end  if  
 2004 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define the grads file over the Africa domain                 *
c     *                                                                      *
c     ************************************************************************
c
      do 3001 jj = 1, 320  
      do 3001 ii = 1, 300   
        j = jj + 200 
        if  (ii.le.80)  then 
          i = ii + 1360  
        else 
          i = ii - 80  
        end  if  
        pamsu (ii,jj) = rain (i,j) 
        samsu (ii,jj) = samp (i,j) 
 3001 continue 
c 
c     ************************************************************************
c     *                                                                      *
c     *  4.  to close the files                                              *
c     *                                                                      *
c     ************************************************************************
c
      close  (unit=26) 

c
      return 
      end 
c
c


