c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *    *******  *******  ********  *******  *******  *******  *******    *
c     *    *     *  *     *  *            *     *     *  *     *  *     *    *
c     *    *     *  *     *  *            *     *     *  *     *  *     *    *
c     *    *******  *     *  *******      *     *******  *******  *     *    * 
c     *    *        *     *        *      *     *        *   *    *     *    * 
c     *    *        *     *        *      *     *        *    *   *     *    * 
c     *    *        *******  *******      *     *        *     *  *******    * 
c     *                                                                      *
c     *                                                                      *
c     *                       *   * ***** *****    *****   *   ***** *****   *
c     *                       *   * *     *   *    *   *   *   *   * *       *
c     *                       *   * ***** *****    *   *   *   *   * *****   *
c     *                        * *  *     *  *  ** *   *   *   *   *     *   *
c     *                         *   ***** *   * ** *****   *   ***** *****   *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *  program   :                                                         *
c     *                                                                      *
c     *               postpro_v0105.f                                        *
c     *                                                                      *
c     *  objective :                                                         *
c     *                                                                      *
c     *               to conduct post-process for the merged analysis        *
c     *                                                                      *
c     *                                                                      *
c     *  input     :                                                         *
c     *                                                                      *
c     *                 unit 10  ==  ftp status file                         *
c     *                                                                      *
c     *                 unit 20  ==  merging output file at 0.1 deg grid     *
c     *                                                                      *
c     *  output    :                                                         *
c     *                                                                      *
c     *                 1)  africa_final_000.gra                             *
c     *                          grads data file containing main inputs      *
c     *                          and final results at 0.1 deg grid points    *
c     *                                                                      *
c     *                 2)  africa_qc_gts_station.bin_all_gauges             *
c     *                          quality controled GTS station observations  *
c     *                                                                      *
c     *  programmer  :                                                       *
c     *                                                                      *
c     *                 Pingping Xie  / Vadlamani Kumar / Tim Love           *
c     *                 NOAA Climate Prediction Center                       *
c     *                 5200 Auth Road, #805B                                *
c     *                 Camp Springs, MD 20746                               *
c     *                                                                      *
c     *                 Tel.    (301)763-8000, ext.7572                      *
c     *                 Fax     (301)763-8125                                *
c     *                 E-mail: xping@sgi17.wwb.noaa.gov                     *
c     *                 E-mail: tim.love@noaa.gov                            *
c     *                                                                      *
c     *  date        :                                                       *
c     *                                                                      *
c     *                 coded    on July      18, 1999  ( V9907 )            *
c     *                 modified on September 21, 1999  ( V9909 )            *
c     *                 modified on December  20, 1999  ( V9912 )            *
c     *                 modified on June      14, 2000  ( V9912 )            *
c     *                 modified on 2001-05-30          ( V0105 )            *
c     *                 modified on 2005-08-23 for fews(lnx)                 *
c     *                                                                      *
c     ************************************************************************
c 
      character   cbuff*8, cfile51*31, cfile52*30  
            
c
      integer*2   kgts ( 2534 )  
      dimension   pgts (751,801), sgts (751,801), 
     #            pcom1(751,801), pcom2(751,801), pcom3(751,801),
     #            pmer1(751,801), pmer2(751,801), pmer3(751,801) 
     
      dimension   gpi(751,801), ssmi(751,801), amsu(751,801),
     #            clim(751,801), comb(751,801), comberr(751,801), 
     #            bullseye_gone(751,801)     
c  
      write  (6,*)  'started postpro !!' 
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to open the ftp status file                                     *
c     *                                                                      *
c     ************************************************************************
      print *, '  ' 
      print *, '*******************************************************' 
      print *, '  ' 
      print *, ' ::: STEP 4: POST-PROCESSING ::: ' 
      print *, '  ' 
c 
      open  (unit=10, 
     #       file='file_ready_status', 
     #       access='sequential', status='old',form='formatted')       
      open  (unit=20, 
     #       file='africa_output_000.gra', 
     #       access='direct',status='old',recl=751*801*4) 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to read the date for which you want to construct analysis       *
c     *                                                                      *
c     ************************************************************************
c
      read  (10,*)  kyear, kmonth, kdate 
      if  (kdate.lt.1.or.kdate.gt.31)  then 
        write  (6,*)  '     wrong date:',kyear,kmonth,kdate 
        stop 
      end  if  
      write  (cbuff,2951) kyear*10000 + kmonth*100 + kdate 
 2951 format  (i8) 
      write  (6,*)  '     finished reading target date !!',
     #                    kyear,kmonth,kdate 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to create output analysis file                                  *
c     *                                                                      *
c     ************************************************************************
c

c      read  (20,rec= 1)   pgts  
c      read  (20,rec= 2)   sgts  
c      read  (20,rec=21)   pcom1   
c      read  (20,rec=22)   pmer1   
c      read  (20,rec=24)   pcom2  
c      read  (20,rec=25)   pmer2  
c      read  (20,rec=27)   pcom3  
c      read  (20,rec=28)   pmer3 
c
      read  (20,rec= 1)   pgts  
      read  (20,rec= 2)   sgts  
      read  (20,rec=27)   gpi   
      read  (20,rec= 9)   ssmi   
      read  (20,rec=13)   amsu  
      read  (20,rec=28)   clim  
      read  (20,rec=25)   comb  
      read  (20,rec=26)   comberr 	
c
      do 999 i=1,751
       do 999 j=1,801
         if (clim(i,j).gt.300) then
           print *, clim(i,j), 'changed to: ', gpi(i,j)
	     bullseye_gone(i,j)=gpi(i,j)
         else
	     bullseye_gone(i,j)=clim(i,j)
         end if
999   continue
c
 
      cfile51 ( 1:23) = 'africa_output_CLIM_010.' 
      cfile51 (24:31) = cbuff (1:8) 
      open  (unit=51, 
     #       file=cfile51,convert='big_endian',
     #       access='direct',status='unknown',recl=751*801*4) 
      write  (51,rec=1)   pgts 
      write  (51,rec=2)   sgts 
      write  (51,rec=3)   gpi 
      write  (51,rec=4)   ssmi  
      write  (51,rec=5)   amsu  
      write  (51,rec=6)   clim  
      write  (51,rec=7)   comb 
c      write  (51,rec=8)   comberr 
      write  (51,rec=8)   bullseye_gone
c
      cfile52 (1:22) = 'all_products_CLIM.bin.' 
      cfile52 (23:30) = cbuff (1:8)
      open  (unit=52,
     #       file=cfile52,convert='big_endian',
     #       access='direct',status='unknown',recl=751*801*4)
c      write  (52,rec=1)   comb 
      write  (52,rec=1)   bullseye_gone 

c
      write  (6,*)  '     finished creating output analysis file !!' 
c

c
c
      write  (6,*)  'finished postpro !!' 
c
      stop 
      end 
