c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *     *  *******  *******  *******  *******  *     *  *******    *
c     *     **   **  *        *     *  *     *     *     **    *  *     *    *
c     *     * * * *  *        *     *  *           *     * *   *  *          *
c     *     *  *  *  *******  *******  *  ****     *     *  *  *  *  ****    * 
c     *     *     *  *        *   *    *  *  *     *     *   * *  *  *  *    * 
c     *     *     *  *        *    *   *     *     *     *    **  *     *    * 
c     *     *     *  *******  *     *  *******  *******  *     *  *******    * 
c     *                                                                      *
c     *                                                                      *
c     *                       *   * ***** *****    *****   *   ***** *****   *
c     *                       *   * *     *   *    *   *   *   *   * *       *
c     *                       *   * ***** *****    *   *   *   *   * *****   *
c     *                        * *  *     *  *  ** *   *   *   *   *     *   *
c     *                         *   ***** *   * ** *****   *   ***** *****   *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *  program   :                                                         *
c     *                                                                      *
c     *               merging_v0105.f                                        *
c     *                                                                      *
c     *  objective :                                                         *
c     *                                                                      *
c     *               to constrcut precipitation analysis by merging         *
c     *               gauge observations, satellite estimates and            *
c     *               numerical weather forecast                             *
c     *                                                                      *
c     *  input     :                                                         *
c     *                                                                      *
c     *               PART I  ( land/ocean mask )                            *
c     *                       land   = 1.0                                   *
c     *                       ocean  = 0.0                                   *
c     *                                                                      *
c     *                 unit 11  == land/ocean mask at 0.10 deg grid points  *
c     *                             rland000 ( nx000, ny000 )                *
c     *                                                                      *
c     *                 unit 12  == land/ocean mask at 0.25 deg grid boxes   *
c     *                             rland025 ( nx025, ny025 )                *
c     *                                                                      *
c     *                 unit 13  == land/ocean mask at 0.50 deg grid boxes   *
c     *                             rland050 ( nx050, ny050 )                *
c     *                                                                      *
c     *                 unit 14  == land/ocean mask at 1.00 deg grid boxes   *
c     *                             rland100 ( nx100, ny100 )                *
c     *                                                                      *
c     *                 unit 15  == land/ocean mask at 2.50 deg grid boxes   *
c     *                             rland250 ( nx250, ny250 )                *
c     *                                                                      *
c     *                 unit 16  == land/ocean mask at 5.00 deg grid boxes   *
c     *                             rland500 ( nx500, ny500 )                *
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *               PART II  ( input from various sources                  *
c     *                          at their original resolution )              *
c     *                                                                      *
c     *                 unit 20  == raw data availability                    *
c     *                             kraw (kk),kk=1,5                         *
c     *                                       1  ==>  GTS                    *
c     *                                       2  ==>  GPI                    *
c     *                                       3  ==>  AF275                  *
c     *                                       4  ==>  SSM/I                  *
c     *                                       5  ==>  AMSU                   *
c     *                                                                      *
c     *                 unit 21  == GTS gauge based analysis                 *
c     *                             at resolution of 0.10 deg grid points    *
c     *                             pgts0 ( nx000, ny000 ) = precip (mm/day) *
c     *                             sgts0 ( nx000, ny000 ) = gauge number    *
c     *                             egts0 ( nx000, ny000 ) = error  (mm/day) *
c     *                             dgts0 ( nx000, ny000 ) = distance (km)   *
c     *                                                                      *
c     *                 unit 22  == GPI estimates                            *
c     *                             at resolution of 0.10 deg grid points    *
c     *                             pgpi0 ( nx000, ny000 ) = precip (mm/day) *
c     *                             sgpi0 ( nx000, ny000 ) = sampling        *
c     *                                                                      *
c     *                 unit 23  == SSM/I based estimates                    *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pssmi0 ( nx025, ny025 ) = precip (mm/day)*
c     *                             sssmi0 ( nx025, ny025 ) = sampling       *
c     *                                                                      *
c     *                 unit 24  == AMSU based estimates                     *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pamsu0 ( nx025, ny025 ) = precip (mm/day)*
c     *                             samsu0 ( nx025, ny025 ) = sampling       *
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *  output  :                                                           *
c     *                                                                      *
c     *             re-gridded individual input fields and merged analysis   *
c     *             at various spatial resolution                            *
c     *                                                                      *
c     *                 unit 91  == output file at 0.10 deg grid points      *
c     *                                                                      *
c     *                 unit 92  == output file at 0.25 deg grid boxes       *
c     *                                                                      *
c     *                 unit 93  == output file at 0.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 94  == output file at 1.00 deg grid boxes       *
c     *                                                                      *
c     *                 unit 95  == output file at 2.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 96  == output file at 5.00 deg grid boxes       *
c     *                                                                      *
c     *                 In each file :                                       *
c     *                                                                      *
c     *                 ch 01    == GTS  precip    (mm/day)                  *
c     *                    02    ==      samping   (gauge number)            *
c     *                    03    ==      error1    (mm/day,all sources)      *
c     *                    04    ==      error2    (mm/day,obs only)         *
c     *                    05    == GPI  precip    (mm/day)                  *
c     *                    06    ==      sampling                            *
c     *                    07    ==      error1    (mm/day,all sources)      *
c     *                    08    ==      error2    (mm/day,obs only)         *
c     *                    09    == SSMI precip    (mm/day)                  *
c     *                    10    ==      sampling                            *
c     *                    11    ==      error1    (mm/day,all sources)      *
c     *                    12    ==      error2    (mm/day,obs only)         *
c     *                    13    == AMSU precip    (mm/day)                  *
c     *                    14    ==      sampling                            *
c     *                    15    ==      error1    (mm/day,all sources)      *
c     *                    16    ==      error2    (mm/day,obs only)         *
c     *                    21    == combined analysis using all data (mm/day)*
c     *                    22    == merged analysis using all data (mm/day)  *
c     *                    23    == error estimation   (mm/day)              *
c     *                    24    == combined analysis without GDAS (mm/day)  *
c     *                    25    == merged analysis without GDAS   (mm/day)  *
c     *                    26    == error estimation   (mm/day)              *
c     *                    27    == combined analysis (GPI only)   (mm/day)  *
c     *                    28    == merged analysis   (GPI + GTS)  (mm/day)  *
c     *                    29    == error estimation  (mm/day)               *
c     *                                                                      *
c     *                                                                      *
c     *  programmer  :                                                       *
c     *                                                                      *
c     *                 Pingping Xie  /  Vadlamani Kumar / Tim Love          *
c     *                 NOAA Climate Prediction Center                       *
c     *                 5200 Auth Road, #805B                                *
c     *                 Camp Springs, MD 20746                               *
c     *                                                                      *
c     *                 Tel.    (301)763-8000, ext.7572                      *
c     *                 Fax     (301)763-8125                                *
c     *                 E-mail: xping@sgi17.wwb.noaa.gov                     *
c     *                                                                      *
c     *  date        :                                                       *
c     *                                                                      *
c     *                 coded    on July      18, 1999  ( V9907 )            *
c     *                 modified on September 15, 1999  ( V9909 )            *
c     *                 modified on December  20, 1999  ( V9912 )            *
c     *                 modified on 2001-05-30          ( V0105 )            *
c     *                 modified on 2005-08-22 for fews(lnx)                 *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
      include  'merging_v0500_parameter.h' 
c
      dimension  ratio (nsate), factor (nsate), kinp (5)   
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to open the data files                                          *
c     *                                                                      *
c     ************************************************************************
      print *, '  ' 
      print *, '*******************************************************' 
      print *, '  ' 
      print *, ' ::: STEP 3: MERGING ::: ' 
      print *, '  ' 
c 
      open  (unit=11,
     #       file='../lib/mask_land_africa_000.linux.gra', 
     #       access='direct',status='old',recl=nx000*ny000*4) 
      open  (unit=12, 
     #       file='../lib/mask_land_africa_025.linux.gra', 
     #       access='direct',status='old',recl=nx025*ny025*4) 
      open  (unit=13, 
     #       file='../lib/mask_land_africa_050.linux.gra', 
     #       access='direct',status='old',recl=nx050*ny050*4) 
      open  (unit=14, 
     #       file='../lib/mask_land_africa_100.linux.gra', 
     #       access='direct',status='old',recl=nx100*ny100*4) 
      open  (unit=15, 
     #       file='../lib/mask_land_africa_250.linux.gra', 
     #       access='direct',status='old',recl=nx250*ny250*4) 
      open  (unit=16, 
     #       file='../lib/mask_land_africa_500.linux.gra', 
     #       access='direct',status='old',recl=nx500*ny500*4) 
c
      open  (unit=20,
     #       file = 'africa_raw_status.txt',
     #       access='sequential',status='old',form='formatted')
     
      open  (unit=21,
     #       file='africa_input_gts_000.gra',
     #       access='direct',status='old',recl=nx000*ny000*4)
      open  (unit=22,
     #       file='africa_input_gpi_000.gra', 
     #       access='direct',status='old',recl=nx000*ny000*4)
      open  (unit=23, 
     #       file='africa_input_ssmi_025.gra',             
     #       access='direct',status='old',recl=nx025*ny025*4)
      open  (unit=24, 
     #       file='africa_input_amsu_025.gra',            
     #       access='direct',status='old',recl=nx025*ny025*4)

c
      open  (unit=91, 
     #       file='africa_output_000.gra',            
     #       access='direct',status='unknown',recl=nx000*ny000*4)
      open  (unit=92, 
     #       file='africa_output_025.gra',                
     #       access='direct',status='unknown',recl=nx025*ny025*4)
      open  (unit=93, 
     #       file='africa_output_050.gra',                
     #       access='direct',status='unknown',recl=nx050*ny050*4)
      open  (unit=94, 
     #       file='africa_output_100.gra',                
     #       access='direct',status='unknown',recl=nx100*ny100*4)
      open  (unit=95, 
     #       file='africa_output_250.gra',                
     #       access='direct',status='unknown',recl=nx250*ny250*4)
      open  (unit=96, 
     #       file='africa_output_500.gra',                
     #       access='direct',status='unknown',recl=nx500*ny500*4) 
c
      write  (6,*)  'started merging !!' 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to read in the land mask and the individual input data          *
c     *                                                                      *
c     ************************************************************************
c
      write  (6,*)  '     started get_dat !!'  
      call  get_dat  ( kinp )  
      write  (6,*)  '     finished get_dat !!'  
      write  (6,2951)  (kinp(kk),kk=1,5)   
 2951 format  ('          ',6i2) 
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define the error for individual input precipitation          *
c     *                                                                      *
c     ************************************************************************
c
      write  (6,*)  '     started get_err !!'  
      ratio (1) = 0.5 
      ratio (2) = 0.5 
      ratio (3) = 0.5 

      factor(1) = 1.0 
      factor(2) = 1.0 
      factor(3) = 1.0 

      call  get_err  ( ratio, factor, kinp )   
      write  (6,*)  '     finished get_err !!'  
c      stop 
c 
c     ************************************************************************
c     *                                                                      *
c     *  5.  to combine the individual input data sources                    *
c     *      mode  ==  1  ==>  combining all sources                         *
c     *                2  ==>  combining all sources except the GDAS         *
c     *                3  ==>  combining (GPI only)                          *
c     *                                                                      *
c     ************************************************************************
c 
      write  (6,*)  '     started combining for mode 1' 
      mode = 1 
      call  get_com ( mode ) 
      write  (6,*)  '     finished combining for mode 1' 
      write  (6,*)  '     started combining for mode 2' 
      mode = 2 
      call  get_com ( mode ) 
      write  (6,*)  '     finished combining for mode 2'
      write  (6,*)  '     started combining for mode 3' 
      mode = 3 
      call  get_com ( mode )
      write  (6,*)  '     finished combining for mode 3'
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to blend the combined analysis with the gauge data              *
c     *      mode  ==  1  ==>  combining all sources                         *
c     *                2  ==>  combining all sources except the GDAS         *
c     *                3  ==>  combining  (GPI + GTS)                        *
c     *                                                                      *
c     ************************************************************************
c 
cc      write  (6,*)  '     started blending for mode 1' 
cc      mode = 1 
cc     kinp_gts = kinp (1) 
cc      kinp_com = kinp (2) + kinp (4) + kinp (5)  
cc     call  get_bnd  ( mode, kinp_gts, kinp_com ) 
cc      write  (6,*)  '     finished blending for mode 1' 
cc      write  (6,*)  '     started blending for mode 2' 
cc      mode = 2 
cc      kinp_gts = kinp (1) 
cc      kinp_com = kinp (2) + kinp (4) + kinp (5)   
cc      call  get_bnd  ( mode, kinp_gts, kinp_com )       
cc      write  (6,*)  '     finished blending for mode 2'  
      write  (6,*)  '     started blending for mode 3'
      mode = 3  
      kinp_gts = kinp (1)
      kinp_com = kinp (2)   
      call  get_bnd  ( mode, kinp_gts, kinp_com )
      write  (6,*)  '     finished blending for mode 3' 
c
      close  ( unit = 91 ) 
      close  ( unit = 92 ) 
      close  ( unit = 93 ) 
      close  ( unit = 94 ) 
      close  ( unit = 95 ) 
      close  ( unit = 96 ) 
c
      write  (6,*)  'finished merging !!' 
c
      stop 
      end 
c
c
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******  *******  *******           *******     *     *******    *
c     *     *        *           *               *    *    * *       *       *
c     *     *        *           *               *    *   *   *      *       *
c     *     *  ****  *******     *               *    *  *******     *       * 
c     *     *  *  *  *           *               *    *  *     *     *       * 
c     *     *     *  *           *               *    *  *     *     *       * 
c     *     *******  *******     *     *******  *******  *     *     *       * 
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *                       *   * ***** *****    ***** ***** ***** *****   *
c     *                       *   * *     *   *    *   * *   * *   * *   *   *
c     *                       *   * ***** *****    ***** ***** *   * *****   *
c     *                        * *  *     *  *  **     *     * *   *     *   *
c     *                         *   ***** *   * ** ***** ***** ***** *****   *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_dat                                               *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to read the land/ocean masks and the individual       *
c     *                data sources at their original resolution and         *
c     *                regrid them into required resolutions                 *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                                                                      *
c     *               PART I  ( land/ocean mask )                            *
c     *                       land   = 1.0                                   *
c     *                       ocean  = 0.0                                   *
c     *                                                                      *
c     *                 unit 11  == land/ocean mask at 0.10 deg grid points  *
c     *                             rland000 ( nx000, ny000 )                *
c     *                                                                      *
c     *                 unit 12  == land/ocean mask at 0.25 deg grid boxes   *
c     *                             rland025 ( nx025, ny025 )                *
c     *                                                                      *
c     *                 unit 13  == land/ocean mask at 0.50 deg grid boxes   *
c     *                             rland050 ( nx050, ny050 )                *
c     *                                                                      *
c     *                 unit 14  == land/ocean mask at 1.00 deg grid boxes   *
c     *                             rland100 ( nx100, ny100 )                *
c     *                                                                      *
c     *                 unit 15  == land/ocean mask at 2.50 deg grid boxes   *
c     *                             rland250 ( nx250, ny250 )                *
c     *                                                                      *
c     *                 unit 16  == land/ocean mask at 5.00 deg grid boxes   *
c     *                             rland500 ( nx500, ny500 )                *
c     *                                                                      *
c     *                                                                      *
c     *               PART II  ( input from various sources                  *
c     *                          at their original resolution )              *
c     *                                                                      *
c     *                 unit 20  == raw data availability                    *
c     *                             kraw (kk),kk=1,5                         *
c     *                                       1  ==>  GTS                    *
c     *                                       2  ==>  GPI                    *
c     *                                       3  ==>  AF275                  *
c     *                                       4  ==>  SSM/I                  *
c     *                                       5  ==>  AMSU                   *

c     *                                                                      *
c     *                 unit 21  == GTS gauge based analysis                 *
c     *                             at resolution of 0.10 deg grid points    *
c     *                             pgts0 ( nx000, ny000 ) = precip (mm/day) *
c     *                             egts0 ( nx000, ny000 ) = error  (mm/day) *
c     *                             dgts0 ( nx000, ny000 ) = distance (km)   *
c     *                                                                      *
c     *                 unit 22  == GPI estimates                            *
c     *                             at resolution of 0.10 deg grid points    *
c     *                             pgpi0 ( nx000, ny000 ) = precip (mm/day) *
c     *                             sgpi0 ( nx000, ny000 ) = sampling        *
c     *                                                                      *
c     *                 unit 23  == SSM/I based estimates                    *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pssmi0 ( nx025, ny025 ) = precip (mm/day)*
c     *                             sssmi0 ( nx025, ny025 ) = sampling       *
c     *                                                                      *
c     *                 unit 24  == AMSU based estimates                     *
c     *                             at resolution of 0.25 deg grid boxes     *
c     *                             pamsu0 ( nx025, ny025 ) = precip (mm/day)*
c     *                             samsu0 ( nx025, ny025 ) = sampling       *
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *  output  :                                                           *
c     *                                                                      *
c     *             re-gridded individual input fields and merged analysis   *
c     *             at various spatial resolution                            *
c     *                                                                      *
c     *                 unit 91  == output file at 0.10 deg grid points      *
c     *                                                                      *
c     *                 unit 92  == output file at 0.25 deg grid boxes       *
c     *                                                                      *
c     *                 unit 93  == output file at 0.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 94  == output file at 1.00 deg grid boxes       *
c     *                                                                      *
c     *                 unit 95  == output file at 2.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 96  == output file at 5.00 deg grid boxes       *
c     *                                                                      *
c     *                 In each file :                                       *
c     *                                                                      *
c     *                 ch 01    == GTS  precip    (mm/day)                  *
c     *                    02    ==      samping   (gauge number)            *
c     *                    03    ==      error1    (mm/day,all sources)      *
c     *                    04    ==      error2    (mm/day,obs only)         *
c     *                    05    == GPI  precip    (mm/day)                  *
c     *                    06    ==      sampling                            *
c     *                    07    ==      error1    (mm/day,all sources)      *
c     *                    08    ==      error2    (mm/day,obs only)         *
c     *                    09    == SSMI precip    (mm/day)                  *
c     *                    10    ==      sampling                            *
c     *                    11    ==      error1    (mm/day,all sources)      *
c     *                    12    ==      error2    (mm/day,obs only)         *
c     *                    13    == AMSU precip    (mm/day)                  *
c     *                    14    ==      sampling                            *
c     *                    15    ==      error1    (mm/day,all sources)      *
c     *                    16    ==      error2    (mm/day,obs only)         *

c     *                                                                      *
c     ************************************************************************
c
      subroutine   get_dat   ( kinp )     
c
      include  'merging_v0500_parameter.h' 
c
      dimension   kinp (5) 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  0.  to get the land/ocean masks                                     *
c     *                                                                      *
c     ************************************************************************
c
      read  (11,rec=1)   rland000 
      read  (12,rec=1)   rland025 
      read  (13,rec=1)   rland050 
      read  (14,rec=1)   rland100 
      read  (15,rec=1)   rland250 
      read  (16,rec=1)   rland500 
      read  (20,    *)   ( kinp (kk), kk=1,5) 
      write  (6,*)  '          finished reading land mask !!' 
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to get the GTS gauge-based precipitation analysis               *
c     *                                                                      *
c     ************************************************************************
c
      call  get_gts 
      write  (6,*)  '          finished get_gts !!' 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to get the GPI precipitation estimates                          *
c     *                                                                      *
c     ************************************************************************
c
      call  get_gpi 
      write  (6,*)  '          finished get_gpi !!' 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to get the SSMI-based precipitation estimates                   *
c     *                                                                      *
c     ************************************************************************
c
      call  get_ssmi  
      write  (6,*)  '          finished get_ssmi !!' 
c 
c     ************************************************************************
c     *                                                                      *
c     *  4.  to get the AMSU-based precipitation estimates                   *
c     *                                                                      *
c     ************************************************************************
c
      call  get_amsu 
      write  (6,*)  '          finished get_amsu !!' 
c

c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to close input files                                            *
c     *                                                                      *
c     ************************************************************************
c
      close  ( unit=11 ) 
      close  ( unit=12 ) 
      close  ( unit=13 ) 
      close  ( unit=14 ) 
      close  ( unit=15 ) 
      close  ( unit=16 ) 
      close  ( unit=20 ) 
      close  ( unit=21 ) 
      close  ( unit=22 ) 
      close  ( unit=23 ) 
      close  ( unit=24 ) 

      write  (6,*)  '          finished closing input files !!' 
c
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *          *****  *****  *****         *****  *****  *****             *
c     *          *      *        *           *        *    *                 *
c     *          * ***  *****    *           * ***    *    *****             *
c     *          * * *  *        *           * * *    *        *             *
c     *          *****  *****    *    *****  *****    *    *****             *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_gts                                               *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to read the GTS-based precipitation analysis at       *
c     *                0.1 grid points and re-grid them into required        *
c     *                resolutions                                           *
c     *                                                                      *
c     ************************************************************************
c   
      subroutine   get_gts   
c
      include  'merging_v0500_parameter.h' 
c
      dimension  rn000 (nx000,ny000), sm000 (nx000,ny000), 
     #           er000 (nx000,ny000),  
     #           rn025 (nx025,ny025), sm025 (nx025,ny025), 
     #           er025 (nx025,ny025),
     #           rn050 (nx050,ny050), sm050 (nx050,ny050), 
     #           er050 (nx050,ny050),
     #           rn100 (nx100,ny100), sm100 (nx100,ny100), 
     #           er100 (nx100,ny100),
     #           rn250 (nx250,ny250), sm250 (nx250,ny250), 
     #           er250 (nx250,ny250),
     #           rn500 (nx500,ny500), sm500 (nx500,ny500), 
     #           er500 (nx500,ny500)
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to read the data at original resolution (0.1 deg grid points)   *
c     *                                                                      *
c     ************************************************************************
c
      read  (21,rec=1)   rn000 
      read  (21,rec=2)   sm000 
      read  (21,rec=3)   er000 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the data at 0.25 grid box                             *
c     *                                                                      *
c     ************************************************************************
c
      do 2002 jj = 1, ny025  
      do 2002 ii = 1, nx025   
        mj = mod (jj,2) 
        nj = jj / 2 
        if  (mj.eq.1)  then 
          j1 = nj * 5 + 1  
        else 
          j1 = (nj-1) * 5 + 3  
        end  if   
        j2 = j1 + 3 
        mi = mod (ii,2)       
        ni = ii / 2 
        if  (mi.eq.1)  then 
          i1 = ni * 5 + 1   
        else 
          i1 = (ni-1) * 5 + 3
        end  if   
        i2 = i1 + 3
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 2001 j = j1, j2
        do 2001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef.and.
     #         er000(i,j).ne.undef)  then
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
            se = se + er000 (i,j)
          end  if
 2001   continue
        if  (nn.gt.0)  then
          rn025 (ii,jj) = sr / nn
          sm025 (ii,jj) = ss 
          er025 (ii,jj) = se / nn  
        else
          rn025 (ii,jj) = undef  
          sm025 (ii,jj) = 0.0   
          er025 (ii,jj) = undef  
        end  if
 2002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define the data at 0.50 grid box                             *
c     *                                                                      *
c     ************************************************************************
c
      do 3002 jj = 1, ny050 
      do 3002 ii = 1, nx050 
        j1 = (jj-1)*5 + 1 
        j2 = j1 + 5 
        i1 = (ii-1)*5 + 1 
        i2 = i1 + 5 
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 3001 j = j1, j2
        do 3001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef.and.
     #         er000(i,j).ne.undef)  then
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
            se = se + er000 (i,j)
          end  if
 3001   continue
        if  (nn.gt.0)  then
          rn050 (ii,jj) = sr / nn
          sm050 (ii,jj) = ss 
          er050 (ii,jj) = se / nn  
        else
          rn050 (ii,jj) = undef  
          sm050 (ii,jj) = 0.0   
          er050 (ii,jj) = undef  
        end  if
 3002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define the data at 1.00 grid box                             *
c     *                                                                      *
c     ************************************************************************
c
      do 4002 jj = 1, ny100  
      do 4002 ii = 1, nx100  
        j1 = (jj-1)*10 + 1 
        j2 = j1 + 10 
        i1 = (ii-1)*10 + 1 
        i2 = i1 + 10 
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 4001 j = j1, j2
        do 4001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef.and.
     #         er000(i,j).ne.undef)  then
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
            se = se + er000 (i,j)
          end  if
 4001   continue
        if  (nn.gt.0)  then
          rn100 (ii,jj) = sr / nn
          sm100 (ii,jj) = ss 
          er100 (ii,jj) = se / nn  
        else
          rn100 (ii,jj) = undef  
          sm100 (ii,jj) = 0.0   
          er100 (ii,jj) = undef  
        end  if
 4002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define the data at 2.50 grid box                             *
c     *                                                                      *
c     ************************************************************************
c
      do 5002 jj = 1, ny250    
      do 5002 ii = 1, nx250    
        j1 = (jj-1)*25 + 1
        j2 = j1 + 25  
        i1 = (ii-1)*25 + 1
        i2 = i1 + 25  
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 5001 j = j1, j2
        do 5001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef.and.
     #         er000(i,j).ne.undef)  then
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
            se = se + er000 (i,j)
          end  if
 5001   continue
        if  (nn.gt.0)  then
          rn250 (ii,jj) = sr / nn
          sm250 (ii,jj) = ss 
          er250 (ii,jj) = se / nn  
        else
          rn250 (ii,jj) = undef  
          sm250 (ii,jj) = 0.0   
          er250 (ii,jj) = undef  
        end  if
 5002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define the data at 5.00 grid box                             *
c     *                                                                      *
c     ************************************************************************
c
      do 6002 jj = 1, ny500    
      do 6002 ii = 1, nx500    
        j1 = (jj-1)*50 + 1
        j2 = j1 + 50 
        i1 = (ii-1)*50 + 1
        i2 = i1 + 50 
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 6001 j = j1, j2
        do 6001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef.and.
     #         er000(i,j).ne.undef)  then
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
            se = se + er000 (i,j)
          end  if
 6001   continue
        if  (nn.gt.0)  then
          rn500 (ii,jj) = sr / nn
          sm500 (ii,jj) = ss 
          er500 (ii,jj) = se / nn  
        else
          rn500 (ii,jj) = undef  
          sm500 (ii,jj) = 0.0   
          er500 (ii,jj) = undef  
        end  if
 6002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to output the regridded fields into files                       *
c     *                                                                      *
c     ************************************************************************
c
      kdat = 1 
      kout1 = (kdat-1)*4 + 1 
      kout2 = (kdat-1)*4 + 2 
      kout3 = (kdat-1)*4 + 3 
      kout4 = (kdat-1)*4 + 4 
      write  (91,rec=kout1)   rn000 
      write  (91,rec=kout2)   sm000 
      write  (91,rec=kout3)   er000 
      write  (91,rec=kout4)   er000 
      write  (92,rec=kout1)   rn025 
      write  (92,rec=kout2)   sm025
      write  (92,rec=kout3)   er025
      write  (92,rec=kout4)   er025
      write  (93,rec=kout1)   rn050  
      write  (93,rec=kout2)   sm050 
      write  (93,rec=kout3)   er050 
      write  (93,rec=kout4)   er050 
      write  (94,rec=kout1)   rn100  
      write  (94,rec=kout2)   sm100 
      write  (94,rec=kout3)   er100
      write  (94,rec=kout4)   er100
      write  (95,rec=kout1)   rn250  
      write  (95,rec=kout2)   sm250 
      write  (95,rec=kout3)   er250
      write  (95,rec=kout4)   er250
      write  (96,rec=kout1)   rn500  
      write  (96,rec=kout2)   sm500 
      write  (96,rec=kout3)   er500
      write  (96,rec=kout4)   er500
c
c
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *           *****  *****  *****         *****  *****  *****            *
c     *           *      *        *           *      *   *    *              *
c     *           * ***  *****    *           * ***  *****    *              *
c     *           * * *  *        *           * * *  *        *              *
c     *           *****  *****    *    *****  *****  *      *****            *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_gpi                                               *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to read the GPI estimates at their original           *
c     *                resolution ( 0.1 deg grid points ) and re-grid        *
c     *                them into required resolutions                        *
c     *                                                                      *
c     ************************************************************************
c
      subroutine   get_gpi 
c
      include  'merging_v0500_parameter.h' 
c
      dimension  rn000 (nx000,ny000), sm000 (nx000,ny000), 
     #           er000 (nx000,ny000),  
     #           rn025 (nx025,ny025), sm025 (nx025,ny025), 
     #           er025 (nx025,ny025),
     #           rn050 (nx050,ny050), sm050 (nx050,ny050), 
     #           er050 (nx050,ny050),
     #           rn100 (nx100,ny100), sm100 (nx100,ny100), 
     #           er100 (nx100,ny100),
     #           rn250 (nx250,ny250), sm250 (nx250,ny250), 
     #           er250 (nx250,ny250),
     #           rn500 (nx500,ny500), sm500 (nx500,ny500), 
     #           er500 (nx500,ny500)
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to read the values at 0.10 deg grid point                       *
c     *                                                                      *
c     ************************************************************************
c
      read  (22,rec=1)   rn000 
      read  (22,rec=2)   sm000 
c         print *, rn000
      do 1001 jj = 1, ny000 
      do 1001 ii = 1, nx000 
        er000 (ii,jj) = undef      
 1001 continue  
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define areal mean at 0.25 deg grid boxes                     *
c     *                                                                      *
c     ************************************************************************
c
      do 2002 jj = 1, ny025  
      do 2002 ii = 1, nx025   
        mj = mod (jj,2) 
        nj = jj / 2 
        if  (mj.eq.1)  then 
          j1 = nj * 5 + 1  
        else 
          j1 = (nj-1) * 5 + 3  
        end  if   
        j2 = j1 + 3 
        mi = mod (ii,2)       
        ni = ii / 2 
        if  (mi.eq.1)  then 
          i1 = ni * 5 + 1   
        else 
          i1 = (ni-1) * 5 + 3
        end  if   
        i2 = i1 + 3
        nn = 0
        sr = 0.0
        ss = 0.0
        do 2001 j = j1, j2
        do 2001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef)  then 
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
          end  if
 2001   continue
        if  (nn.gt.0)  then
          rn025 (ii,jj) = sr / nn
          sm025 (ii,jj) = ss 
        else
          rn025 (ii,jj) = undef  
          sm025 (ii,jj) = 0.0   
        end  if
        er025 (ii,jj) = undef  
c        print *, rn025(ii,jj),ii,jj
 2002 continue

c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define areal mean at 0.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 3002 jj = 1, ny050 
      do 3002 ii = 1, nx050 
        j1 = (jj-1)*5 + 1 
        j2 = j1 + 5 
        i1 = (ii-1)*5 + 1 
        i2 = i1 + 5 
        nn = 0
        sr = 0.0
        ss = 0.0
        do 3001 j = j1, j2
        do 3001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef)  then 
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
          end  if
 3001   continue
        if  (nn.gt.0)  then
          rn050 (ii,jj) = sr / nn
          sm050 (ii,jj) = ss 
        else
          rn050 (ii,jj) = undef  
          sm050 (ii,jj) = 0.0   
        end  if
        er050 (ii,jj) = undef  
 3002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define areal mean at 1.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 4002 jj = 1, ny100  
      do 4002 ii = 1, nx100  
        j1 = (jj-1)*10 + 1 
        j2 = j1 + 10 
        i1 = (ii-1)*10 + 1 
        i2 = i1 + 10 
        nn = 0
        sr = 0.0
        ss = 0.0
        do 4001 j = j1, j2
        do 4001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef)  then 
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
          end  if
 4001   continue
        if  (nn.gt.0)  then
          rn100 (ii,jj) = sr / nn
          sm100 (ii,jj) = ss 
        else
          rn100 (ii,jj) = undef  
          sm100 (ii,jj) = 0.0   
        end  if
        er100 (ii,jj) = undef  
 4002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define areal mean at 2.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 5002 jj = 1, ny250    
      do 5002 ii = 1, nx250    
        j1 = (jj-1)*25 + 1
        j2 = j1 + 25  
        i1 = (ii-1)*25 + 1
        i2 = i1 + 25  
        nn = 0
        sr = 0.0
        ss = 0.0
        do 5001 j = j1, j2
        do 5001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef)  then 
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
          end  if
 5001   continue
        if  (nn.gt.0)  then
          rn250 (ii,jj) = sr / nn
          sm250 (ii,jj) = ss 
        else
          rn250 (ii,jj) = undef  
          sm250 (ii,jj) = 0.0   
        end  if
        er250 (ii,jj) = undef  
 5002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define areal mean at 5.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 6002 jj = 1, ny500    
      do 6002 ii = 1, nx500    
        j1 = (jj-1)*50 + 1
        j2 = j1 + 50 
        i1 = (ii-1)*50 + 1
        i2 = i1 + 50 
        nn = 0
        sr = 0.0
        ss = 0.0
        se = 0.0
        do 6001 j = j1, j2
        do 6001 i = i1, i2
          if  (rn000(i,j).ne.undef.and.
     #         sm000(i,j).ne.undef)  then 
            nn = nn + 1
            sr = sr + rn000 (i,j)
            ss = ss + sm000 (i,j)
          end  if
 6001   continue
        if  (nn.gt.0)  then
          rn500 (ii,jj) = sr / nn
          sm500 (ii,jj) = ss 
        else
          rn500 (ii,jj) = undef  
          sm500 (ii,jj) = 0.0   
        end  if
        er500 (ii,jj) = undef  
 6002 continue

c          print *, rn500
c          print *, sm500
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to output the regridded fields into files                       *
c     *                                                                      *
c     ************************************************************************
c
      kdat = 2 
      kout1 = (kdat-1)*4 + 1 
      kout2 = (kdat-1)*4 + 2
      kout3 = (kdat-1)*4 + 3 
      kout4 = (kdat-1)*4 + 4 
      write  (91,rec=kout1)   rn000 
      write  (91,rec=kout2)   sm000
      write  (91,rec=kout3)   er000
      write  (91,rec=kout4)   er000
      write  (92,rec=kout1)   rn025  
      write  (92,rec=kout2)   sm025
      write  (92,rec=kout3)   er025
      write  (92,rec=kout4)   er025
      write  (93,rec=kout1)   rn050  
      write  (93,rec=kout2)   sm050 
      write  (93,rec=kout3)   er050 
      write  (93,rec=kout4)   er050 
      write  (94,rec=kout1)   rn100  
      write  (94,rec=kout2)   sm100 
      write  (94,rec=kout3)   er100
      write  (94,rec=kout4)   er100
      write  (95,rec=kout1)   rn250  
      write  (95,rec=kout2)   sm250 
      write  (95,rec=kout3)   er250
      write  (95,rec=kout4)   er250
      write  (96,rec=kout1)   rn500  
      write  (96,rec=kout2)   sm500 
      write  (96,rec=kout3)   er500
      write  (96,rec=kout4)   er500
c
c 
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *        *****  *****  *****         *****  *****  *   *  *****        *
c     *        *      *        *           *      *      ** **    *          *
c     *        * ***  *****    *           *****  *****  * * *    *          *
c     *        * * *  *        *               *      *  *   *    *          *
c     *        *****  *****    *    *****  *****  *****  *   *  *****        *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_ssmi                                              *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to read the SSM/I-based estimates at their original   *
c     *                resolution and re-grid them into required resolutions *
c     *                                                                      *
c     ************************************************************************
c   
      subroutine   get_ssmi    
c
      include  'merging_v0500_parameter.h' 
c
      dimension  rn000 (nx000,ny000), sm000 (nx000,ny000), 
     #           er000 (nx000,ny000),  
     #           rn025 (nx025,ny025), sm025 (nx025,ny025), 
     #           er025 (nx025,ny025),
     #           rn050 (nx050,ny050), sm050 (nx050,ny050), 
     #           er050 (nx050,ny050),
     #           rn100 (nx100,ny100), sm100 (nx100,ny100), 
     #           er100 (nx100,ny100),
     #           rn250 (nx250,ny250), sm250 (nx250,ny250), 
     #           er250 (nx250,ny250),
     #           rn500 (nx500,ny500), sm500 (nx500,ny500), 
     #           er500 (nx500,ny500)
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to read the values at 0.25 deg grid box                         *
c     *                                                                      *
c     ************************************************************************
c 
      read  (23,rec=1)   rn025 
      read  (23,rec=2)   sm025 
      do 1001 jj = 1, ny025 
      do 1001 ii = 1, nx025 
        er025 (ii,jj) = undef 
 1001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to assign values to 0.1 deg grid points                         *
c     *                                                                      *
c     ************************************************************************
c 
      mode   = 2 
      nx0    = nx025 
      ny0    = ny025 
      rlat0  = -39.875 
      rlon0  = -19.875 
      dgrid0 = 0.25 
      nx1    = nx000 
      ny1    = ny000  
      rlat1  = -40.00  
      rlon1  = -20.00  
      dgrid1 = 0.1  
      call        fill_fine            
     #          ( mode, undef, 
     #            nx0, ny0, rlat0, rlon0, dgrid0, rn025,  
     #            nx1, ny1, rlat1, rlon1, dgrid1, rn000 )  
      do 2001 jj = 1, ny000  
      do 2001 ii = 1, nx000  
c
        j0 = int ((jj-1.0)/2.5) + 1  
        if  (j0.lt.1)  then 
          j0 = 1 
        else if  (j0.gt.ny025)  then 
          j0 = ny025  
        end  if  
        i0 = int ((ii-1.0)/2.5) + 1
        if  (i0.lt.1)  then 
          i0 = 1 
        else if  (i0.gt.nx025)  then 
          i0 = nx025  
        end  if
        sm000 (ii,jj) = sm025 (i0,j0) / 6.25  
        if  (sm000 (ii,jj).eq.0.0)  then 
          rn000 (ii,jj) = undef 
        end  if  
        if  (rn000(ii,jj).eq.undef)  then 
          sm000 (ii,jj) = 0.0 
        end  if  
        er000 (ii,jj) = undef 
c
 2001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define areal mean at 0.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 3002 jj = 1, ny050  
      do 3002 ii = 1, nx050  
        j1 = (jj-1)*2 + 1 
        j2 = j1 + 1 
        i1 = (ii-1)*2 + 1 
        i2 = i1 + 1 
        nn = 0 
        sr = 0.0 
        ss = 0.0 
        do 3001 j = j1, j2 
        do 3001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 3001   continue 
        if  (nn.gt.0)  then 
          rn050 (ii,jj) = sr / nn 
          sm050 (ii,jj) = ss  
        else 
          rn050 (ii,jj) = undef 
          sm050 (ii,jj) = 0.0  
        end  if  
        er050 (ii,jj) = undef 
 3002 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define areal mean at 1.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 4002 jj = 1, ny100  
      do 4002 ii = 1, nx100  
        j1 = (jj-1)*4 + 1 
        j2 = j1 + 3 
        i1 = (ii-1)*4 + 1 
        i2 = i1 + 3 
        nn = 0 
        sr = 0.0 
        ss = 0.0 
        do 4001 j = j1, j2 
        do 4001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 4001   continue 
        if  (nn.gt.0)  then 
          rn100 (ii,jj) = sr / nn 
          sm100 (ii,jj) = ss  
        else 
          rn100 (ii,jj) = undef 
          sm100 (ii,jj) = 0.0  
        end  if  
        er100 (ii,jj) = undef 
 4002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define areal mean at 2.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 5002 jj = 1, ny250   
      do 5002 ii = 1, nx250   
        j1 = (jj-1)*10 + 1 
        j2 = j1 + 9 
        i1 = (ii-1)*10 + 1 
        i2 = i1 + 9 
        nn = 0
        sr = 0.0
        ss = 0.0 
        do 5001 j = j1, j2 
        do 5001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 5001   continue 
        if  (nn.gt.0)  then 
          rn250 (ii,jj) = sr / nn 
          sm250 (ii,jj) = ss  
        else 
          rn250 (ii,jj) = undef 
          sm250 (ii,jj) = 0.0  
        end  if  
        er250 (ii,jj) = undef 
 5002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define areal mean at 5.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 6002 jj = 1, ny500   
      do 6002 ii = 1, nx500  
        j1 = (jj-1)*20 + 1
        j2 = j1 + 19 
        i1 = (ii-1)*20 + 1
        i2 = i1 + 19 
        nn = 0
        sr = 0.0
        ss = 0.0
        do 6001 j = j1, j2 
        do 6001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 6001   continue 
        if  (nn.gt.0)  then 
          rn500 (ii,jj) = sr / nn 
          sm500 (ii,jj) = ss  
        else 
          rn500 (ii,jj) = undef 
          sm500 (ii,jj) = 0.0  
        end  if  
        er500 (ii,jj) = undef 
 6002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to output the regridded fields into files                       *
c     *                                                                      *
c     ************************************************************************
c
      kdat = 3  
      kout1 = (kdat-1)*4 + 1 
      kout2 = (kdat-1)*4 + 2
      kout3 = (kdat-1)*4 + 3 
      kout4 = (kdat-1)*4 + 4 
      write  (91,rec=kout1)   rn000 
      write  (91,rec=kout2)   sm000
      write  (91,rec=kout3)   er000
      write  (91,rec=kout4)   er000
      write  (92,rec=kout1)   rn025  
      write  (92,rec=kout2)   sm025
      write  (92,rec=kout3)   er025
      write  (92,rec=kout4)   er025
      write  (93,rec=kout1)   rn050  
      write  (93,rec=kout2)   sm050 
      write  (93,rec=kout3)   er050 
      write  (93,rec=kout4)   er050 
      write  (94,rec=kout1)   rn100  
      write  (94,rec=kout2)   sm100 
      write  (94,rec=kout3)   er100
      write  (94,rec=kout4)   er100
      write  (95,rec=kout1)   rn250  
      write  (95,rec=kout2)   sm250 
      write  (95,rec=kout3)   er250
      write  (95,rec=kout4)   er250
      write  (96,rec=kout1)   rn500  
      write  (96,rec=kout2)   sm500 
      write  (96,rec=kout3)   er500
      write  (96,rec=kout4)   er500
c
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *        *****  *****  *****           *    *   *  *****  *   *        *
c     *        *      *        *            * *   ** **  *      *   *        *
c     *        * ***  *****    *           *****  * * *  *****  *   *        *
c     *        * * *  *        *           *   *  *   *      *  *   *        *
c     *        *****  *****    *    *****  *   *  *   *  *****  *****        *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_amsu                                              *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to read the AMSU-based estimates at their original    *
c     *                resolution and re-grid them into required resolutions *
c     *                                                                      *
c     ************************************************************************
c   
      subroutine  get_amsu 
c
      include  'merging_v0500_parameter.h' 
c
c
      dimension  rn000 (nx000,ny000), sm000 (nx000,ny000), 
     #           er000 (nx000,ny000),  
     #           rn025 (nx025,ny025), sm025 (nx025,ny025), 
     #           er025 (nx025,ny025),
     #           rn050 (nx050,ny050), sm050 (nx050,ny050), 
     #           er050 (nx050,ny050),
     #           rn100 (nx100,ny100), sm100 (nx100,ny100), 
     #           er100 (nx100,ny100),
     #           rn250 (nx250,ny250), sm250 (nx250,ny250), 
     #           er250 (nx250,ny250),
     #           rn500 (nx500,ny500), sm500 (nx500,ny500), 
     #           er500 (nx500,ny500)
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to read the values at 0.50 deg grid box                         *
c     *                                                                      *
c     ************************************************************************
c 
      read  (24,rec=1)   rn025   
      read  (24,rec=2)   sm025  
      do 1001 jj = 1, ny025 
      do 1001 ii = 1, nx025 
        er025 (ii,jj) = undef 
 1001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to assign values to 0.1 deg grid points                         *
c     *                                                                      *
c     ************************************************************************
c 
      mode   = 2 
      nx0    = nx025 
      ny0    = ny025 
      rlat0  = -39.875 
      rlon0  = -19.875 
      dgrid0 = 0.25 
      nx1    = nx000 
      ny1    = ny000  
      rlat1  = -40.00  
      rlon1  = -20.00  
      dgrid1 = 0.1  
      call        fill_fine            
     #          ( mode, undef, 
     #            nx0, ny0, rlat0, rlon0, dgrid0, rn025,  
     #            nx1, ny1, rlat1, rlon1, dgrid1, rn000 )  
      do 2001 jj = 1, ny000  
      do 2001 ii = 1, nx000  
c
        j0 = int ((jj-1.0)/2.5) + 1  
        if  (j0.lt.1)  then 
          j0 = 1 
        else if  (j0.gt.ny025)  then 
          j0 = ny025  
        end  if  
        i0 = int ((ii-1.0)/2.5) + 1
        if  (i0.lt.1)  then 
          i0 = 1 
        else if  (i0.gt.nx025)  then 
          i0 = nx025  
        end  if
        sm000 (ii,jj) = sm025 (i0,j0) / 6.25  
        if  (sm000 (ii,jj).eq.0.0)  then 
          rn000 (ii,jj) = undef 
        end  if  
        if  (rn000(ii,jj).eq.undef)  then 
          sm000 (ii,jj) = 0.0 
        end  if  
        er000 (ii,jj) = undef 
c
 2001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define areal mean at 0.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 3002 jj = 1, ny050  
      do 3002 ii = 1, nx050  
        j1 = (jj-1)*2 + 1 
        j2 = j1 + 1 
        i1 = (ii-1)*2 + 1 
        i2 = i1 + 1 
        nn = 0 
        sr = 0.0 
        ss = 0.0 
        do 3001 j = j1, j2 
        do 3001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 3001   continue 
        if  (nn.gt.0)  then 
          rn050 (ii,jj) = sr / nn 
          sm050 (ii,jj) = ss  
        else 
          rn050 (ii,jj) = undef 
          sm050 (ii,jj) = 0.0  
        end  if  
        er050 (ii,jj) = undef 
 3002 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define areal mean at 1.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 4002 jj = 1, ny100  
      do 4002 ii = 1, nx100  
        j1 = (jj-1)*4 + 1 
        j2 = j1 + 3 
        i1 = (ii-1)*4 + 1 
        i2 = i1 + 3 
        nn = 0 
        sr = 0.0 
        ss = 0.0 
        do 4001 j = j1, j2 
        do 4001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 4001   continue 
        if  (nn.gt.0)  then 
          rn100 (ii,jj) = sr / nn 
          sm100 (ii,jj) = ss  
        else 
          rn100 (ii,jj) = undef 
          sm100 (ii,jj) = 0.0  
        end  if  
        er100 (ii,jj) = undef 
 4002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define areal mean at 2.5 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 5002 jj = 1, ny250   
      do 5002 ii = 1, nx250   
        j1 = (jj-1)*10 + 1 
        j2 = j1 + 9 
        i1 = (ii-1)*10 + 1 
        i2 = i1 + 9 
        nn = 0
        sr = 0.0
        ss = 0.0 
        do 5001 j = j1, j2 
        do 5001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 5001   continue 
        if  (nn.gt.0)  then 
          rn250 (ii,jj) = sr / nn 
          sm250 (ii,jj) = ss  
        else 
          rn250 (ii,jj) = undef 
          sm250 (ii,jj) = 0.0  
        end  if  
        er250 (ii,jj) = undef 
 5002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define areal mean at 5.0 deg grid boxes                      *
c     *                                                                      *
c     ************************************************************************
c
      do 6002 jj = 1, ny500   
      do 6002 ii = 1, nx500  
        j1 = (jj-1)*20 + 1
        j2 = j1 + 19 
        i1 = (ii-1)*20 + 1
        i2 = i1 + 19 
        nn = 0
        sr = 0.0
        ss = 0.0
        do 6001 j = j1, j2 
        do 6001 i = i1, i2 
          if  (rn025(i,j).ne.undef.and. 
     #         sm025(i,j).ne.undef)  then  
            nn = nn + 1 
            sr = sr + rn025 (i,j) 
            ss = ss + sm025 (i,j) 
          end  if  
 6001   continue 
        if  (nn.gt.0)  then 
          rn500 (ii,jj) = sr / nn 
          sm500 (ii,jj) = ss  
        else 
          rn500 (ii,jj) = undef 
          sm500 (ii,jj) = 0.0  
        end  if  
        er500 (ii,jj) = undef 
 6002 continue
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to output the regridded fields into files                       *
c     *                                                                      *
c     ************************************************************************
c
      kdat = 4  
      kout1 = (kdat-1)*4 + 1 
      kout2 = (kdat-1)*4 + 2
      kout3 = (kdat-1)*4 + 3 
      kout4 = (kdat-1)*4 + 4 
      write  (91,rec=kout1)   rn000 
      write  (91,rec=kout2)   sm000
      write  (91,rec=kout3)   er000
      write  (91,rec=kout4)   er000
      write  (92,rec=kout1)   rn025  
      write  (92,rec=kout2)   sm025
      write  (92,rec=kout3)   er025
      write  (92,rec=kout4)   er025
      write  (93,rec=kout1)   rn050  
      write  (93,rec=kout2)   sm050 
      write  (93,rec=kout3)   er050 
      write  (93,rec=kout4)   er050 
      write  (94,rec=kout1)   rn100  
      write  (94,rec=kout2)   sm100 
      write  (94,rec=kout3)   er100
      write  (94,rec=kout4)   er100
      write  (95,rec=kout1)   rn250  
      write  (95,rec=kout2)   sm250 
      write  (95,rec=kout3)   er250
      write  (95,rec=kout4)   er250
      write  (96,rec=kout1)   rn500  
      write  (96,rec=kout2)   sm500 
      write  (96,rec=kout3)   er500
      write  (96,rec=kout4)   er500
c
c
      return 
      end 
c
c

c
c
c
c     ************************************************************************
c     *                                                                      *
c     *     *****  *****  *      *             *****  *****  *   *  *****    *
c     *     *        *    *      *             *        *    **  *  *        *
c     *     *****    *    *      *             *****    *    * * *  *****    *
c     *     *        *    *      *             *        *    *  **  *        *
c     *     *      *****  *****  *****  *****  *      *****  *   *  *****    *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                fill_fine                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to regrid filed with finer resolution from that       *
c     *                of coarser resolution                                 *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                1)  This is based on interpolation/extrapolation      *
c     *                    using square of distance as weight;               *
c     *                                                                      *
c     *                2)  The regrid will be limitted to interpolation      *
c     *                    if you choose mode 2.                             *
c     *                                                                      *
c     *   input / output    :                                                *
c     *                                                                      *
c     *                mode  =   operation mode                              *
c     *                          1 ==> interpolation / extrapolation         *
c     *                          2 ==> interpolation only                    *
c     *                                                                      *
c     *                undef =   undefine code                               *
c     *                                                                      *
c     *                                                                      *
c     *                ( coarser grid )                                      *
c     *                                                                      *
c     *                nx0   =   dimension in east-west direction            *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                ny0   =   dimension in north-south direction          *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                rlat0 =   latitude for the coarser grid at j = 1      *
c     *                                                                      *
c     *                rlon0 =   longitude for the coarser grid at i = 1     *
c     *                                                                      *
c     *                dgrid0=   lat/lon increment in the coarser grid       *
c     *                                                                      *
c     *                rain0 =   blended field at coarser resolution         *
c     *                          rain0 (nx0,ny0)                             *
c     *                                                                      *
c     *                                                                      *
c     *                ( finer grid )                                        *
c     *                                                                      *
c     *                nx1   =   dimension in east-west direction            *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                ny1   =   dimension in north-south direction          *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                rlat1 =   latitude for the finer grid at j = 1        *
c     *                                                                      *
c     *                rlon1 =   longitude for the finer grid at i = 1       *
c     *                                                                      *
c     *                dgrid1=   lat/lon increment in the finer grid         *
c     *                                                                      *
c     *   (output)     rain1 =   blended field at finer resolution           *
c     *                          rain1 (nx1,ny1)                             *
c     *                                                                      *
c     ************************************************************************
c
      subroutine  fill_fine            
     #          ( mode, undef, 
     #            nx0, ny0, rlat0, rlon0, dgrid0, rain0,  
     #            nx1, ny1, rlat1, rlon1, dgrid1, rain1 )  
c
      dimension   rain0 (nx0,ny0),  rain1 (nx1,ny1)  
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to check the operation mode and initialize the output           *
c     *                                                                      *
c     *         mode  = 1 ===> fill in all grid points in the domain of      *
c     *                        nx1 by ny1                                    *
c     *                 2 ===> fill in grid points where interpolation is    *
c     *                        possible. no extrapolation.                   *
c     *                                                                      *
c     ************************************************************************
c
      if  (mode.lt.1.or. 
     #     mode.gt.2)  then 
        write  (6,*)  'Wrong Operation In Subroutine fill_fine !' 
        write  (6,*)  'Choose 1 for inter- and extrapolation !' 
        write  (6,*)  'Choose 2 for interpolation only !' 
        stop 
      end  if  
c
      do 1001 jj = 1, ny1 
      do 1001 ii = 1, nx1 
        rain1 (ii,jj) = undef 
 1001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define on all grid points                                    *  
c     *                                                                      *
c     ************************************************************************
c
      kdst    = 1 
 2001 missing = 0 
      do 2003 jj = 1, ny1    
      do 2003 ii = 1, nx1   
c
        if  (rain1(ii,jj).ne.undef)  then 
          go  to  2003 
        end  if  
c
c       2.1  to select the center pixel in the input domain  
        rlat  = (jj-1)*dgrid1 + rlat1 
        rlon  = (ii-1)*dgrid1 + rlon1 
        jc    = nint ((rlat-rlat0)/dgrid0) + 1  
        ic    = nint ((rlon-rlon0)/dgrid0) + 1 
c
c       2.2  to determine the pixels in the input domain used to interpolate 
        j0 = jc - kdst  
        if  (j0.lt.1)  then 
          j0 = 1 
        end  if  
        j1 = jc + kdst  
        if  (j1.gt.ny0)  then 
          j1 = ny0 
        end  if  
        i0 = ic - kdst  
        if  (i0.lt.1)  then 
          i0 = 1 
        end  if  
        i1 = ic + kdst  
        if  (i1.gt.nx0)  then 
          i1 = nx0 
        end  if  
c
c       2.3  to interpolate 
        dm = (kdst*dgrid0) * (kdst*dgrid0) 
        nn = 0 
        sw = 0.0 
        ss = 0.0 
        do 2002 j = j0, j1 
        do 2002 i = i0, i1   
          if  (rain0(i,j).ne.undef)  then
            dlat = (j-1)*dgrid0 + rlat0 - rlat 
            dlon = (i-1)*dgrid0 + rlon0 - rlon 
            dist = dlat*dlat + dlon*dlon 
            if  (dist.eq.0.0)  then 
              rain1 (ii,jj) = rain0 (i,j) 
              go  to  2003 
            else 
              if  (dist.le.dm)  then 
                nn = nn + 1 
                w  = 1.0 / dist 
                sw = sw + w 
                ss = ss + w * rain0 (i,j) 
              end  if  
            end  if  
          end  if 
 2002   continue 
        if  (nn.ge.1)  then 
          rain1 (ii,jj) = ss / sw 
        else 
          missing = missing + 1  
        end  if  
 2003 continue 
      if  (missing.ne.0.and. 
     #     kdst.le.2)  then 
        kdst = kdst + 2 
        go  to  2001 
      end  if  
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  To define the extra-polation points as undef in Mode 2          *
c     *                                                                      *
c     ************************************************************************
c
      if  (mode.eq.2)  then 
        do 3002 j = 1, ny0 
        do 3002 i = 1, nx0 
          if  (rain0(i,j).eq.undef)  then 
            rlats = rlat0 + (j-1.5)*dgrid0 
            rlatn = rlats + dgrid0 
            rlonw = rlon0 + (i-1.5)*dgrid0 
            rlone = rlonw + dgrid0 
            jj0   = int ((rlats-rlat1)/dgrid1) + 1 
            jj1   = int ((rlatn-rlat1)/dgrid1) + 1 
            ii0   = int ((rlonw-rlon1)/dgrid1) + 1 
            ii1   = int ((rlone-rlon1)/dgrid1) + 1
            do 3001 jj = jj0, jj1 
            do 3001 ii = ii0, ii1 
              rain1 (ii,jj) = undef 
 3001       continue 
          end  if  
 3002   continue 
      end  if  
c
      return 
      end    
c
c
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******  *******  *******           *******  *******  *******    *
c     *     *        *           *              *        *     *  *     *    *
c     *     *        *           *              *        *     *  *     *    *
c     *     * *****  *******     *              *******  *******  *******    * 
c     *     * *   *  *           *              *        *    *   *    *     * 
c     *     *     *  *           *              *        *    *   *    *     * 
c     *     *******  *******     *     *******  *******  *     *  *     *    * 
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *                      *   * ***** *****    ***** ***** ***** *****    *
c     *                      *   * *     *   *    *   * *   * *   * *   *    *
c     *                      *   * ***** *****    ***** ***** *   * *****    *
c     *                       * *  *     *  *  **     *     * *   *     *    *
c     *                        *   ***** *   * ** ***** ***** ***** *****    *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_err.f                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to estimate random error for each individual          *
c     *                data sources                                          *
c     *                                                                      *
c     *   files     :                                                        *
c     *                                                                      *
c     *             re-gridded individual input fields and merged analysis   *
c     *             at various spatial resolution                            *
c     *                                                                      *
c     *                 unit 91  == output file at 0.10 deg grid points      *
c     *                                                                      *
c     *                 unit 92  == output file at 0.25 deg grid boxes       *
c     *                                                                      *
c     *                 unit 93  == output file at 0.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 94  == output file at 1.00 deg grid boxes       *
c     *                                                                      *
c     *                 unit 95  == output file at 2.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 96  == output file at 5.00 deg grid boxes       *
c     *                                                                      *
c     *                 In each file :                                       *
c     *                                                                      *
c     *                 ch 01    == GTS  precip    (mm/day)                  *
c     *                    02    ==      samping   (gauge number)            *
c     *                    03    ==      error1    (mm/day,all sources)      *
c     *                    04    ==      error2    (mm/day,obs only)         *
c     *                    05    == GPI  precip    (mm/day)                  *
c     *                    06    ==      sampling                            *
c     *                    07    ==      error1    (mm/day,all sources)      *
c     *                    08    ==      error2    (mm/day,obs only)         *
c     *                    09    == SSMI precip    (mm/day)                  *
c     *                    10    ==      sampling                            *
c     *                    11    ==      error1    (mm/day,all sources)      *
c     *                    12    ==      error2    (mm/day,obs only)         *
c     *                    13    == AMSU precip    (mm/day)                  *
c     *                    14    ==      sampling                            *
c     *                    15    ==      error1    (mm/day,all sources)      *
c     *                    16    ==      error2    (mm/day,obs only)         *

c     *                                                                      *
c     ************************************************************************
c
      subroutine  get_err  ( ratio, factor, kinp )  
c
      include  'merging_v0500_parameter.h'
c
      dimension  ratio (nsate), factor (nsate), kinp (5)   
c
      dimension  kinp_sate ( nsate) 
c
      dimension  prn1000 (nx000,ny000), prn2000 (nx000,ny000),  
     #           pgts000 (nx000,ny000), sgts000 (nx000,ny000), 
     #           psat000 (nx000,ny000), ssat000 (nx000,ny000), 
     #           esat000 (nx000,ny000), 
     #           prn1025 (nx025,ny025), prn2025 (nx025,ny025),  
     #           pgts025 (nx025,ny025), sgts025 (nx025,ny025),
     #           psat025 (nx025,ny025), ssat025 (nx025,ny025),
     #           esat025 (nx025,ny025),
     #           prn1050 (nx050,ny050), prn2050 (nx050,ny050),  
     #           pgts050 (nx050,ny050), sgts050 (nx050,ny050),
     #           psat050 (nx050,ny050), ssat050 (nx050,ny050),
     #           esat050 (nx050,ny050),
     #           prn1100 (nx100,ny100), prn2100 (nx100,ny100),  
     #           pgts100 (nx100,ny100), sgts100 (nx100,ny100),
     #           psat100 (nx100,ny100), ssat100 (nx100,ny100),
     #           esat100 (nx100,ny100),
     #           prn1250 (nx250,ny250), prn2250 (nx250,ny250),  
     #           pgts250 (nx250,ny250), sgts250 (nx250,ny250),
     #           psat250 (nx250,ny250), ssat250 (nx250,ny250),
     #           esat250 (nx250,ny250),
     #           prn1500 (nx500,ny500), prn2500 (nx500,ny500),  
     #           pgts500 (nx500,ny500), sgts500 (nx500,ny500),
     #           psat500 (nx500,ny500), ssat500 (nx500,ny500),
     #           esat500 (nx500,ny500)
c
      dimension  pc100 (nx100,ny100,nsate) 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  0.  to check the data availability                                  *
c     *                                                                      *
c     ************************************************************************
c
      kinp_gts      = kinp (1) 
      kinp_sate (1) = kinp (2) 
      kinp_sate (2) = kinp (4) 
      kinp_sate (3) = kinp (5) 

c
      kinp_all = kinp_sate (1) 
     #         + kinp_sate (2)
     #         + kinp_sate (3)

      kinp_obs = kinp_sate (1) 
     #         + kinp_sate (2)
     #         + kinp_sate (3)
      kinp_gpi = kinp_sate (1)
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to define for 5.00 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     1.1  to set the parameters
      kunit  =  96  
      nx     =  nx500   
      ny     =  ny500    
      kdg    =  5 
      kstp   =  1
      jsouth =  3 
      jnorth =  12 
c
c     1.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland500, prn1500, prn2500 )
c
c     1.3  to calculate the error variance
      read  (kunit,rec=1)   pgts500
      read  (kunit,rec=2)   sgts500
c          print *, pgts500
c          print *, sgts500
      do 1004 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 1001 jj = 1, ny 
          do 1001 ii = 1, nx 
            psat500 (ii,jj) = undef
            ssat500 (ii,jj) = undef
 1001     continue 
        else  if  (kinp_gts.eq.0)  then 
          do 1002 jj = 1, ny
          do 1002 ii = 1, nx
            psat500 (ii,jj) = 100.0 
            ssat500 (ii,jj) = 100.0 
 1002     continue
        else 
          read  (kunit,rec=krec1)   psat500
          read  (kunit,rec=krec2)   ssat500
          call  cal_err_pc  ( nx, ny, kdg, kstp,
     #                        jsouth, jnorth,
     #                        undef, ratio (kk), rland500,
     #                        pgts500, sgts500,
     #                        psat500, ssat500, esat500 )
          do 1003 jj = 1, ny
          do 1003 ii = 1, nx
c                 print *, esat500(ii,jj)
c                 print *, ssat500(ii,jj)                  

            if  (esat500(ii,jj).ne.undef.and.
     #           ssat500(ii,jj).gt.0.0)  then
              if  (prn1500(ii,jj).ne.undef)  then
                psat500 (ii,jj) = factor (kk)
     #                          * esat500 (ii,jj)
     #                          * prn1500 (ii,jj)
     #                          / ssat500 (ii,jj)
                if  (psat500(ii,jj).lt.0.01)  then 
                  psat500(ii,jj) = 0.01 
                end  if  
              else
                psat500 (ii,jj) = undef
              end  if
              if  (prn2500(ii,jj).ne.undef)  then
                ssat500 (ii,jj) = factor (kk)
     #                          * esat500 (ii,jj)
     #                          * prn2500 (ii,jj)
     #                          / ssat500 (ii,jj)
                if  (ssat500(ii,jj).lt.0.01)  then 
                  ssat500 (ii,jj) = 0.01 
                end  if  
              else
                ssat500 (ii,jj) = undef
              end  if
            else
              psat500 (ii,jj) = undef
              ssat500 (ii,jj) = undef
            end  if
 1003     continue
        end  if  
        write  (kunit,rec=krec3)   psat500
        write  (kunit,rec=krec4)   ssat500
c                    print *, psat500
c                    print *, ssat500
 1004 continue
      write  (6,*)  '          finished defining error for 5.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define for 2.50 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     2.1  to set the parameters
      kunit  =  95  
      nx     =  nx250   
      ny     =  ny250    
      kdg    =  10  
      kstp   =  1
      jsouth =  5  
      jnorth =  24  
c
c     2.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland250, prn1250, prn2250 )
c
c     2.3  to calculate the error variance
      read  (kunit,rec=1)   pgts250
      read  (kunit,rec=2)   sgts250
      do 2004 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 2001 jj = 1, ny 
          do 2001 ii = 1, nx 
            psat250 (ii,jj) = undef
            ssat250 (ii,jj) = undef
 2001     continue
        else  if  (kinp_gts.eq.0)  then 
          do 2002 jj = 1, ny
          do 2002 ii = 1, nx
            psat250 (ii,jj) = 100.0 
            ssat250 (ii,jj) = 100.0 
 2002     continue
        else 
          read  (kunit,rec=krec1)   psat250
          read  (kunit,rec=krec2)   ssat250
          call  cal_err_pc  ( nx, ny, kdg, kstp,
     #                        jsouth, jnorth,
     #                        undef, ratio (kk), rland250,
     #                        pgts250, sgts250,
     #                        psat250, ssat250, esat250 )
          do 2003 jj = 1, ny
          do 2003 ii = 1, nx
            if  (esat250(ii,jj).ne.undef.and.
     #           ssat250(ii,jj).gt.0.0)  then
              if  (prn1250(ii,jj).ne.undef)  then
                psat250 (ii,jj) = factor (kk)
     #                          * esat250 (ii,jj)
     #                          * prn1250 (ii,jj)
     #                          / ssat250 (ii,jj)
                if  (psat250(ii,jj).lt.0.01)  then 
                  psat250 (ii,jj) = 0.01 
                end  if  
              else
                psat250 (ii,jj) = undef
              end  if
              if  (prn2250(ii,jj).ne.undef)  then
                ssat250 (ii,jj) = factor (kk)
     #                          * esat250 (ii,jj)
     #                          * prn2250 (ii,jj)
     #                          / ssat250 (ii,jj)
                if  (ssat250(ii,jj).lt.0.01)  then 
                  ssat250 (ii,jj) = 0.01 
                end  if  
              else
                ssat250 (ii,jj) = undef
              end  if
            else
              psat250 (ii,jj) = undef
              ssat250 (ii,jj) = undef
            end  if
 2003     continue
        end  if  
        write  (kunit,rec=krec3)   psat250
        write  (kunit,rec=krec4)   ssat250
 2004 continue
      write  (6,*)  '          finished defining error for 2.50 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define for 1.00 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     3.1  to set the parameters
      kunit  =  94  
      nx     =  nx100  
      ny     =  ny100  
      kdg    =  25    
      kstp   =  1 
      jsouth =  11
      jnorth =  60
c
c     3.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland100, prn1100, prn2100 )
c
c     3.3  to calculate the error variance
      read  (kunit,rec=1)   pgts100 
      read  (kunit,rec=2)   sgts100 
      do 3004 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 3001 jj = 1, ny 
          do 3001 ii = 1, nx 
            psat100 (ii,jj) = undef
            ssat100 (ii,jj) = undef
 3001     continue
        else  if  (kinp_gts.eq.0)  then 
          do 3002 jj = 1, ny
          do 3002 ii = 1, nx
            psat100 (ii,jj) = 100.0
            ssat100 (ii,jj) = 100.0 
 3002     continue
        else 
          read  (kunit,rec=krec1)   psat100 
          read  (kunit,rec=krec2)   ssat100 
          call  cal_err_pc  ( nx, ny, kdg, kstp,
     #                        jsouth, jnorth,
     #                        undef, ratio (kk), rland100,
     #                        pgts100, sgts100,
     #                        psat100, ssat100, esat100 )
          do 3003 jj = 1, ny
          do 3003 ii = 1, nx
            pc100 (ii,jj,kk) = esat100 (ii,jj) 
            if  (esat100(ii,jj).ne.undef.and.
     #           ssat100(ii,jj).gt.0.0)  then
              if  (prn1100(ii,jj).ne.undef)  then
                psat100 (ii,jj) = factor (kk)
     #                          * esat100 (ii,jj)
     #                          * prn1100 (ii,jj)
     #                          / ssat100 (ii,jj)
                if  (psat100(ii,jj).lt.0.01)  then 
                  psat100 (ii,jj) = 0.01 
                end  if  
              else
                psat100 (ii,jj) = undef
              end  if
              if  (prn2100(ii,jj).ne.undef)  then
                ssat100 (ii,jj) = factor (kk)
     #                          * esat100 (ii,jj)
     #                          * prn2100 (ii,jj)
     #                          / ssat100 (ii,jj)
                if  (ssat100(ii,jj).lt.0.01)  then 
                  ssat100 (ii,jj) = 0.01 
                end  if  
              else
                ssat100 (ii,jj) = undef
              end  if
            else
              psat100 (ii,jj) = undef
              ssat100 (ii,jj) = undef
            end  if
 3003     continue
        end  if  
        write  (kunit,rec=krec3)   psat100 
        write  (kunit,rec=krec4)   ssat100 
 3004 continue
      write  (6,*)  '          finished defining error for 1.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define for 0.50 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     4.1  to set the parameters
      kunit  =  93  
      nx     =  nx050 
      ny     =  ny050 
c
c     4.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland050, prn1050, prn2050 )
c
c     4.3  to calculate the error variance
      read  (kunit,rec=1)   pgts050 
      read  (kunit,rec=2)   sgts050 
      do 4009 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 4001 jj = 1, ny 
          do 4001 ii = 1, nx 
            psat050 (ii,jj) = undef
            ssat050 (ii,jj) = undef
 4001     continue   
        else  if  (kinp_gts.eq.0)  then 
          do 4002 jj = 1, ny
          do 4002 ii = 1, nx
            psat050 (ii,jj) = 100.0 
            ssat050 (ii,jj) = 100.0 
 4002     continue
        else 
          read  (kunit,rec=krec1)   psat050 
          read  (kunit,rec=krec2)   ssat050 
          do 4004 jj = 1, ny100 
          do 4004 ii = 1, nx100 
            j1 = (jj-1)*2 + 1 
            j2 = j1 + 1 
            i1 = (ii-1)*2 + 1 
            i2 = i1 + 1 
            do 4003 j = j1, j2 
            do 4003 i = i1, i2 
              esat050 (i,j) = pc100 (ii,jj,kk) 
 4003       continue 
 4004     continue  
          kd = 3 
 4005     nmissing = 0 
          do 4007 jj = 1, ny 
          do 4007 ii = 1, nx 
            if  (esat050(ii,jj).le.0.0)  then 
              j1 = jj - kd 
              if  (j1.lt.1)  then      
                j1 = 1
              end  if  
              j2 = jj + kd 
              if  (j2.gt.ny)  then 
                j2 = ny 
              end  if  
              i1 = ii - kd  
              if  (i1.lt.1)  then 
                i1 = 1    
              end  if  
              i2 = ii + kd 
              if  (i2.gt.nx)  then 
                i2 = nx 
              end  if  
              nn = 0 
              ss = 0.0 
              do 4006 j = j1, j2 
              do 4006 i = i1, i2 
                if  (esat050 (i,j).gt.0.0)  then 
                  nn = nn + 1 
                  ss = ss + esat050 (i,j) 
                end  if 
 4006         continue 
              if  (nn.ge.5)  then 
                esat050 (ii,jj) = ss / nn 
              else 
                nmissing = nmissing + 1 
              end  if  
            end  if  
 4007     continue 
          if  (nmissing.gt.0)  then 
            write  (6,*)  'missing:',nmissing 
            kd = kd * 2 
            go  to  4005 
          end  if  
          do 4008 jj = 1, ny
          do 4008 ii = 1, nx
            if  (esat050(ii,jj).ne.undef.and.
     #           ssat050(ii,jj).gt.0.0)  then
              if  (prn1050(ii,jj).ne.undef)  then
                psat050 (ii,jj) = factor (kk)
     #                          * esat050 (ii,jj)
     #                          * prn1050 (ii,jj)
     #                          / ssat050 (ii,jj)
                if  (psat050(ii,jj).lt.0.01)  then 
                  psat050(ii,jj) = 0.01 
                end  if  
              else
                psat050 (ii,jj) = undef
              end  if
              if  (prn2050(ii,jj).ne.undef)  then
                ssat050 (ii,jj) = factor (kk)
     #                          * esat050 (ii,jj)
     #                          * prn2050 (ii,jj)
     #                          / ssat050 (ii,jj)
                if  (ssat050(ii,jj).lt.0.01)  then 
                  ssat050 (ii,jj) = 0.01 
                end  if  
              else
                ssat050 (ii,jj) = undef
              end  if
            else
              psat050 (ii,jj) = undef
              ssat050 (ii,jj) = undef
            end  if
 4008     continue
        end  if  
        write  (kunit,rec=krec3)   psat050 
        write  (kunit,rec=krec4)   ssat050 
 4009 continue
      write  (6,*)  '          finished defining error for 0.50 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define for 0.25 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     5.1  to set the parameters
      kunit  =  92   
      nx     =  nx025  
      ny     =  ny025  
c
c     5.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland025, prn1025, prn2025 )
c
c     5.3  to calculate the error variance
      read  (kunit,rec=1)   pgts025  
      read  (kunit,rec=2)   sgts025 
      do 5009 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 5001 jj = 1, ny 
          do 5001 ii = 1, nx 
            psat025 (ii,jj) = undef
            ssat025 (ii,jj) = undef
 5001     continue   
        else  if  (kinp_gts.eq.0)  then 
          do 5002 jj = 1, ny
          do 5002 ii = 1, nx
            psat025 (ii,jj) = 100.0 
            ssat025 (ii,jj) = 100.0 
 5002     continue
        else 
          read  (kunit,rec=krec1)   psat025 
          read  (kunit,rec=krec2)   ssat025 
          do 5004 jj = 1, ny100 
          do 5004 ii = 1, nx100 
            j1 = (jj-1)*4 + 1 
            j2 = j1 + 3 
            i1 = (ii-1)*4 + 1 
            i2 = i1 + 3 
            do 5003 j = j1, j2 
            do 5003 i = i1, i2 
              esat025 (i,j) = pc100 (ii,jj,kk) 
 5003       continue 
 5004     continue  
          kd = 3 
 5005     nmissing = 0 
          do 5007 jj = 1, ny 
          do 5007 ii = 1, nx 
            if  (esat025(ii,jj).le.0.0)  then 
              j1 = jj - kd 
              if  (j1.lt.1)  then      
                j1 = 1
              end  if  
              j2 = jj + kd 
              if  (j2.gt.ny)  then 
                j2 = ny 
              end  if  
              i1 = ii - kd  
              if  (i1.lt.1)  then 
                i1 = 1    
              end  if  
              i2 = ii + kd 
              if  (i2.gt.nx)  then 
                i2 = nx 
              end  if  
              nn = 0 
              ss = 0.0 
              do 5006 j = j1, j2 
              do 5006 i = i1, i2 
                if  (esat025 (i,j).gt.0.0)  then 
                  nn = nn + 1 
                  ss = ss + esat025 (i,j) 
                end  if 
 5006         continue 
              if  (nn.ge.5)  then 
                esat025 (ii,jj) = ss / nn 
              else 
                nmissing = nmissing + 1 
              end  if  
            end  if  
 5007     continue 
          if  (nmissing.gt.0)  then 
            write  (6,*)  'missing:',nmissing 
            kd = kd * 2 
            go  to  5005 
          end  if  
          do 5008 jj = 1, ny
          do 5008 ii = 1, nx
            if  (esat025(ii,jj).ne.undef.and.
     #           ssat025(ii,jj).gt.0.0)  then
              if  (prn1025(ii,jj).ne.undef)  then
                psat025 (ii,jj) = factor (kk)
     #                          * esat025 (ii,jj)
     #                          * prn1025 (ii,jj)
     #                          / ssat025 (ii,jj)
                if  (psat025(ii,jj).lt.0.01)  then 
                  psat025 (ii,jj) = 0.01 
                end  if  
              else
                psat025 (ii,jj) = undef
              end  if
              if  (prn2025(ii,jj).ne.undef)  then
                ssat025 (ii,jj) = factor (kk)
     #                          * esat025 (ii,jj)
     #                          * prn2025 (ii,jj)
     #                          / ssat025 (ii,jj)
                if  (ssat025(ii,jj).lt.0.01)  then 
                  ssat025 (ii,jj) = 0.01 
                end  if  
              else
                ssat025 (ii,jj) = undef
              end  if
            else
              psat025 (ii,jj) = undef
              ssat025 (ii,jj) = undef
            end  if
 5008     continue
        end  if  
        write  (kunit,rec=krec3)   psat025 
        write  (kunit,rec=krec4)   ssat025 
 5009 continue
      write  (6,*)  '          finished defining error for 0.25 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define for 0.10 deg grid boxes                               *
c     *                                                                      *
c     ************************************************************************
c
c     6.1  to set the parameters
      kunit  =  91   
      nx     =  nx000   
      ny     =  ny000   
c
c     6.2  to define the first guess of precip
      call   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                     rland000, prn1000, prn2000 )
c
c     6.3  to calculate the error variance
      read  (kunit,rec=1)   pgts000   
      read  (kunit,rec=2)   sgts000  
      do 6009 kk = 1, nsate
        krec1 = kk*4 + 1
        krec2 = kk*4 + 2
        krec3 = kk*4 + 3
        krec4 = kk*4 + 4
        if  (kinp_sate(kk).eq.0)  then 
          do 6001 jj = 1, ny 
          do 6001 ii = 1, nx 
            psat000 (ii,jj) = undef
            ssat000 (ii,jj) = undef
 6001     continue   
        else  if  (kinp_gts.eq.0)  then 
          do 6002 jj = 1, ny
          do 6002 ii = 1, nx
            psat000 (ii,jj) = 100.0 
            ssat000 (ii,jj) = 100.0 
 6002     continue
        else 
          read  (kunit,rec=krec1)   psat000  
          read  (kunit,rec=krec2)   ssat000  
          do 6004 jj = 1, ny100 
          do 6004 ii = 1, nx100 
            j1 = (jj-1)*10 + 1 
            j2 = j1 + 10 
            i1 = (ii-1)*10 + 1 
            i2 = i1 + 10 
            do 6003 j = j1, j2 
            do 6003 i = i1, i2 
              esat000 (i,j) = pc100 (ii,jj,kk) 
 6003       continue 
 6004     continue  
          kd = 3 
 6005     nmissing = 0 
          do 6007 jj = 1, ny 
          do 6007 ii = 1, nx 
            if  (esat000(ii,jj).le.0.0)  then 
              j1 = jj - kd 
              if  (j1.lt.1)  then      
                j1 = 1
              end  if  
              j2 = jj + kd 
              if  (j2.gt.ny)  then 
                j2 = ny 
              end  if  
              i1 = ii - kd  
              if  (i1.lt.1)  then 
                i1 = 1    
              end  if  
              i2 = ii + kd 
              if  (i2.gt.nx)  then 
                i2 = nx 
              end  if  
              nn = 0 
              ss = 0.0 
              do 6006 j = j1, j2 
              do 6006 i = i1, i2 
                if  (esat000 (i,j).gt.0.0)  then 
                  nn = nn + 1 
                  ss = ss + esat000 (i,j) 
                end  if 
 6006         continue 
              if  (nn.ge.5)  then 
                esat000 (ii,jj) = ss / nn 
              else 
                nmissing = nmissing + 1 
              end  if  
            end  if  
 6007     continue 
          if  (nmissing.gt.0)  then 
            write  (6,*)  'missing:',nmissing 
            kd = kd * 2 
            go  to  6005 
          end  if  
          do 6008 jj = 1, ny
          do 6008 ii = 1, nx
            if  (esat000(ii,jj).ne.undef.and.
     #           ssat000(ii,jj).gt.0.0)  then
              if  (prn1000(ii,jj).ne.undef)  then
                psat000 (ii,jj) = factor (kk)
     #                          * esat000 (ii,jj)
     #                          * prn1000 (ii,jj)
     #                          / ssat000 (ii,jj)
                if  (psat000(ii,jj).lt.0.01)  then 
                  psat000 (ii,jj) = 0.01 
                end  if  
              else
                psat000 (ii,jj) = undef
              end  if
              if  (prn2000(ii,jj).ne.undef)  then
                ssat000 (ii,jj) = factor (kk)
     #                          * esat000 (ii,jj)
     #                          * prn2000 (ii,jj)
     #                          / ssat000 (ii,jj)
                if  (ssat000(ii,jj).lt.0.01)  then 
                  ssat000(ii,jj) = 0.01 
                end  if  
              else
                ssat000 (ii,jj) = undef
              end  if
            else
              psat000 (ii,jj) = undef
              ssat000 (ii,jj) = undef
            end  if
 6008     continue
        end  if  
        write  (kunit,rec=krec3)   psat000 
        write  (kunit,rec=krec4)   ssat000 
 6009 continue
      write  (6,*)  '          finished defining error for 0.10 box !!'
c
c
      return 
      end  
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *      *****   *   *           ***** ***** *****       ***** *****     *
c     *      *      * *  *           *     *   * *   *       *     *   *     *
c     *      *     ***** *           ***** ***** *****       ***** *   *     *
c     *      *     *   * *           *     *  *  *  *        *     *   *     *
c     *      ***** *   * ***** ***** ***** *   * *   * ***** *     *****     *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                cal_err_f0                                            *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to define the first guess of the precipitation field  *
c     *                for the error variance calculation                    *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                Over land, the first guess is a simple arithematic    *
c     *                mean of gauge-based analysis and all other available  *
c     *                satellite estimates and model outputs;                *
c     *                                                                      *
c     *                Over ocean, it is the arithematic mean of satellite   *
c     *                estimates and model outputs.                          *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                kunit  =  unit number of the input/output data file   *
c     *                          (91 ~ 96 for various spatial resolutions)   *
c     *                                                                      *
c     *                undef  =  undefined code                              *
c     *                                                                      *
c     *                                                                      *
c     *                nx     =  number of grids in East-West Direction      *
c     *                                                                      *
c     *                                                                      *
c     *                ny     =  number of grids in South - North Direction  *
c     *                                                                      *
c     *                                                                      *
c     *                nsate  =  number of satellite estimates / model       *
c     *                          outputs used in definition                  *
c     *                                                                      *
c     *                nobs   =  number of observation-based data sources    *
c     *                          among nsate (nobs<=nsate)                   *
c     *                                                                      *
c     *                rland  =  land/ocean mask                             *
c     *                          nx * ny; land = 1.0; ocean = 0.0            *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                rain1  =  first guess using all available sources     *
c     *                          nx * ny                                     *
c     *                                                                      *
c     *                rain2  =  first guess using observation-based sources *
c     *                          nx * ny                                     *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
      subroutine   cal_err_f0  ( kunit, undef, nx, ny, nsate, nobs,
     #                           rland, rain1, rain2 )
c
      parameter   ( mx = 751, my = 801 ) 
c
      dimension   rland (nx,ny),   
     #            rain1 (nx,ny), rain2 (nx,ny) 
c
      dimension   ndat1 (mx,my), sdat1 (mx,my), 
     #            ndat2 (mx,my), sdat2 (mx,my) 
c
      dimension   kuse (5)  
      data        kuse / 1, 1, 1, 1, 1 / 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to read the gauge data                                          *  
c     *                                                                      *
c     ************************************************************************
c 
      read  (kunit,rec=1)   rain1  
      read  (kunit,rec=2)   rain2  
      do 1001 jj = 1, ny 
      do 1001 ii = 1, nx 
        if  (kuse(1).eq.1.and.
     #       rland(ii,jj).eq.1.0.and. 
     #       rain1(ii,jj).ne.undef)  then  
          ndat1 (ii,jj) = 1 
          sdat1 (ii,jj) = rain1 (ii,jj) 
          ndat2 (ii,jj) = 1 
          sdat2 (ii,jj) = rain1 (ii,jj) 
        else 
          ndat1 (ii,jj) = 0 
          sdat1 (ii,jj) = 0.0 
          ndat2 (ii,jj) = 0 
          sdat2 (ii,jj) = 0.0 
        end  if  
 1001 continue  
c
c     ************************************************************************
c     *                                                                      *
c     *  2. to read the satellite estimates and define the first guess       *  
c     *                                                                      *
c     ************************************************************************
c 
      do 2002 kk = 1, nsate  
        kinp = kk*4 + 1 
        read  (kunit,rec=kinp)   rain1   
        if  (kuse(kk+1).eq.1)  then 
          do 2001 jj = 1, ny 
          do 2001 ii = 1, nx 
            if  (rain1(ii,jj).ne.undef)  then
              ndat1 (ii,jj) = ndat1 (ii,jj) + 1 
              sdat1 (ii,jj) = sdat1 (ii,jj) + rain1 (ii,jj) 
              if  (kk.le.nobs)  then 
                ndat2 (ii,jj) = ndat2 (ii,jj) + 1 
                sdat2 (ii,jj) = sdat2 (ii,jj) + rain1 (ii,jj)
              end  if  
            end  if  
 2001     continue 
        end  if  
 2002 continue 
c
      do 2003 jj = 1, ny 
      do 2003 ii = 1, nx 
        if  (ndat1(ii,jj).gt.0)  then 
          rain1 (ii,jj) = sdat1 (ii,jj) / ndat1 (ii,jj) 
        else 
          rain1 (ii,jj) = undef 
        end  if  
        if  (ndat2(ii,jj).gt.0)  then 
          rain2 (ii,jj) = sdat2 (ii,jj) / ndat2 (ii,jj) 
        else 
          rain2 (ii,jj) = undef 
        end  if   
 2003 continue 
c
      return 
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *      *****   *   *           ***** ***** *****       ***** *****     *
c     *      *      * *  *           *     *   * *   *       *   * *         *
c     *      *     ***** *           ***** ***** *****       ***** *         *
c     *      *     *   * *           *     *  *  *  *        *     *         *
c     *      ***** *   * ***** ***** ***** *   * *   * ***** *     *****     *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                cal_err_pc                                            *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to calculate the proportional constant (PC)           *
c     *                in deriving the random error                          *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                1)  the error estimation is basically based on        *
c     *                    Bell el al. (1996) that the sampling related      *
c     *                    error variance (E^2) is proportional to the       *
c     *                    precipitation amount (R) and inversely            *
c     *                    proportional to the sampling size (S):            *
c     *                                                                      *
c     *                    E^2   ~  R / S                                    *
c     *                                                                      *
c     *                 2) the key to conduct error estimation with          *
c     *                    reasonable accuracy is to define the proportional *
c     *                    constant (PC) which is a function of the kind of  *
c     *                    satellite estimates, target region and season;    *
c     *                                                                      *
c     *                 3) in this version of the algorithm, PC is defined   *
c     *                    by comparing with concurrent gauge-based analysis *
c     *                    over land and by subjective assumption over ocean;*
c     *                                                                      *
c     *                 4) the error scheme over land:                       *
c     *                                                                      *
c     *                    *  PC is defined for each grid by comparing the   *
c     *                       satellite estimates PSAT (i,j) with the        *
c     *                       concurrent gauge-based analysis PGTS (i,j)     *
c     *                       over a domain of (2*KDG+1 by 2*KDG+1) centered *
c     *                       at the target grid;                            *
c     *                                                                      *
c     *                    *  PC over land grids over area with insufficient *
c     *                       gauge data is defined by interpolation;        *
c     *                                                                      *
c     *                    *  to reduce compution time for cases with too    *
c     *                       many grids (e.g. 0.1 deg lat/lon resolution),  *
c     *                       PC is first calculated for one in every KSTP   *
c     *                       grids in both directions, and PC over the      *
c     *                       remaining remaining grids are determined by    *
c     *                       bi-linear interpolation from the calculated    *
c     *                       points;                                        *
c     *                                                                      *
c     *                  5) the error scheme over ocean                      *
c     *                                                                      *
c     *                     *  the error schme over ocean is basically an    *
c     *                        assumption;                                   *
c     *                                                                      *
c     *                     *  first, the mean PC (MPC) is calculated for a  *
c     *                        domain from Line # JSOUTH to Line # JNORTH    *
c     *                        over land;                                    *
c     *                                                                      *
c     *                     *  the PC over ocean (PCO) is assumed to be      *
c     *                        homogeneous and is a fraction (RAT) of MPC:   *
c     *                                                                      *
c     *                        PCO = RAT * MPC                               *
c     *                                                                      *
c     *                        where the fraction (RAT) is a function of the *
c     *                        kind of satellite estimates.                  *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                mx    =   maximum dimension in east-west direction    *
c     *                          integer                                     *
c     *                                                                      *
c     *                my    =   maximum dimension in north-south direction  *
c     *                          integer                                     *
c     *                                                                      *
c     *                nx    =   dimension in east-west direction            *
c     *                          integer                                     *
c     *                                                                      *
c     *                ny    =   dimension in north-south direction          *
c     *                          integer                                     *
c     *                                                                      *
c     *                kdg   =   half side length of the domain over which   *
c     *                          satellite estimates are compared against    *
c     *                          gauge data to calculate the proportional    *
c     *                          constant (see the above algorithm           *
c     *                          explanation )                               *
c     *                                                                      *
c     *                kstp  =   calculation step length                     *
c     *                          ( see the above explanation )               *
c     *                          1 for non-skip; 2 for 1 in every 2 grids    *
c     *                                                                      *
c     *                jsouth=   south board of the domain over land the PC  *
c     *                          of which is used to define the oceanic PC;  *
c     *                                                                      *
c     *                jnorth=   north board of the domain over land the PC  *
c     *                          of which is used to define the oceanic PC;  *
c     *                                                                      *
c     *                undef =   the undefined value                         *
c     *                                                                      *
c     *                ratio =   the ratio between oceanic PC (PCO) and the  *
c     *                          mean PC over land (MPC)                     *
c     *                                                                      *
c     *                rland =   land/ocean mask                             *
c     *                          1.0 = land                                  *
c     *                          0.0 = ocean                                 *
c     *                                                                      *
c     *                pgts  =   gauge based precipitation analysis          *
c     *                                                                      *
c     *                sgts  =   number of gauges in the grid box            *
c     *                                                                      *
c     *                psat  =   satellite estimates of precipitation        *
c     *                                                                      *
c     *                ssat  =   satellite estimates sampling                *
c     *                                                                      *
c     *   output    :                                                        *
c     *                                                                      *
c     *                pc    =   proportional constant                       *
c     *                                                                      *
c     *   date      :                                                        *
c     *                                                                      *
c     *                July 7, 1999                                          *
c     *                                                                      *
c     ************************************************************************
c   
      subroutine   cal_err_pc  ( nx, ny, kdg, kstp, 
     #                          jsouth, jnorth, 
     #                          undef, ratio, rland,  
     #                          pgts, sgts, psat, ssat, pc )  
c
      parameter   ( mx = 751, my = 801 ) 
c
      dimension   rland(nx,ny), 
     #            pgts (nx,ny), sgts (nx,ny), 
     #            psat (nx,ny), ssat (nx,ny), pc (nx,ny)  
c 
      dimension   dd (mx,my)   
c
      doubleprecision   dxy  
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to prepare for the calculation                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, ny 
      do 1001 ii = 1, nx 
        if  (rland(ii,jj).eq.1.0.and. 
     #       pgts (ii,jj).ne.undef.and.  
     #       sgts (ii,jj).ge.1.0.and.  
     #       psat (ii,jj).ne.undef)  then  
          dd (ii,jj) = (pgts (ii,jj) - psat (ii,jj))  
     #               * (pgts (ii,jj) - psat (ii,jj)) 
        else 
          dd (ii,jj) = undef      
        end  if  
        pc   (ii,jj) = undef 
 1001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to calculate the  proportional constant over land               *
c     *      at selected points ( one in every kstp points )                 *
c     *                                                                      *
c     ************************************************************************
c
      do 2003 jj = 1, ny, kstp   
      do 2003 ii = 1, nx, kstp   
c
        if  (rland(ii,jj).eq.1.0.and.
     #       pc   (ii,jj).eq.undef)  then 
c
c         2.1  to determine the calculation domain 
          kdg0  = kdg 
 2001     dist0 = kdg0 * kdg0   
c
          j1 = jj - kdg0    
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + kdg0    
          if  (j2.gt.ny)  then 
            j2 = ny 
          end  if  
          i1 = ii - kdg0   
          if  (i1.lt.1)  then 
            i1 = 1 
          end  if  
          i2 = ii + kdg0  
          if  (i2.gt.nx)  then 
            i2 = nx 
          end  if  
c
c         2.2  to accumulate the difference variance
          nn = 0 
          sx  = 0.0  
          sy  = 0.0 
          dxy = 0.0 
          sam = 0.0 
          do 2002 j = j1, j2 
          do 2002 i = i1, i2 
            if  (dd(i,j).ne.undef)  then  
              dist = (j-jj)*(j-jj) + (i-ii)*(i-ii) 
              if  (dist.le.dist0)  then 
                x    = psat (i,j) 
                y    = pgts (i,j) 
                nn   = nn  +  1 
                sx   = sx  +  x    
                sy   = sy  +  y 
                dxy  = dxy +  dd   (i,j) 
                sam  = sam +  ssat (i,j) 
              end  if  
            end  if  
 2002     continue 
c
c         2.3  to calculate the proportional constant 
          if  (nn.ge.10)  then 
            ax  = sx  / nn     
            ay  = sy  / nn   
            as  = sam / nn 
            if  (ay.gt.0.0)  then 
              dif = dxy - nn * (ax-ay)*(ax-ay) 
              if  (dif.lt.0.0)  then 
                dif = 0.0 
              end  if  
              e2         = dif / nn 
              pc (ii,jj) = e2  * as / ( ay + 1.0 )   
c              pc (ii,jj) = e2     
            end  if  
          else 
            kdg0 = 3 * kdg0  
            nmiss = nmiss + 1 
c            go  to  2001 
          end  if  
        end  if  
 2003 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to fill in the missings at the selected points using land values*
c     *      ( one in every kstp points )                                    *
c     *                                                                      *
c     ************************************************************************
c
      kcircle  = 3 
 3001 nmissing = 0
      do 3003 jj = 1, ny, kstp
      do 3003 ii = 1, nx, kstp
        if  (rland(ii,jj).eq.1.0.and.
     #       pc   (ii,jj).eq.undef)  then
          j1 = jj - kcircle*kstp
          if  (j1.lt.1)  then
            j1 = 1
          end  if
          j2 = jj + kcircle*kstp
          if  (j2.gt.ny)  then
            j2 = ny
          end  if
          i1 = ii - kcircle*kstp
          if  (i1.lt.1)  then
            i1 = 1
          end  if
          i2 = ii + kcircle*kstp
          if  (i2.gt.nx)  then
            i2 = nx
          end  if
          nn = 0
          ss = 0.0
          do 3002 j = j1, j2, kstp
          do 3002 i = i1, i2, kstp
            if  (rland(i,j).eq.1.0.and.
     #           pc(i,j).ne.undef)  then
              nn = nn + 1
              ss = ss + pc (i,j)
            end  if
 3002     continue
          if  (nn.ge.3)  then
            pc  (ii,jj) = ss / nn
          else
            nmissing = nmissing + 1
          end  if
        end  if
 3003 continue
      if  (nmissing.gt.0.and.
     #     kcircle.lt.10)  then
        kcircle = 2 * kcircle  
        go  to  3001  
      end  if
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define the PC over oceanic grids                             *
c     *                                                                      *
c     ************************************************************************
c
      sw = 0 
      ss = 0.0 
      do 4002 jj = 1, ny, kstp     
        if  (jj.ge.jsouth.and.
     #       jj.le.jnorth)  then 
          do 4001 ii = 1, nx, kstp   
            if  (rland(ii,jj).eq.1.0.and. 
     #           pc   (ii,jj).ge.0.0.and.
     #           pgts (ii,jj).ne.undef)  then 
              w   = pgts (ii,jj) + 0.1    
              sw  = sw + w   
              ss  = ss + w * pc  (ii,jj) 
            end  if  
 4001     continue 
        end  if  
 4002 continue 
      if  (sw.gt.0.0)  then 
        pco = ratio * ss / sw  
      else 
        pco = undef 
      end  if  
      do 4003 jj = 1, ny 
      do 4003 ii = 1, nx 
        if  (rland(ii,jj).eq.0.0)  then 
          pc  (ii,jj) = pco  
        end  if  
 4003 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to fill in the missings over the selected grids over land       *
c     *      using both land and oceanic values                              *
c     *                                                                      *
c     ************************************************************************
c
      kcircle  = 3 
 5001 nmissing = 0
      do 5003 jj = 1, ny, kstp
      do 5003 ii = 1, nx, kstp
        if  (rland(ii,jj).eq.1.0.and.
     #       pc   (ii,jj).eq.undef)  then
          j1 = jj - kcircle*kstp
          if  (j1.lt.1)  then
            j1 = 1
          end  if
          j2 = jj + kcircle*kstp
          if  (j2.gt.ny)  then
            j2 = ny
          end  if
          i1 = ii - kcircle*kstp
          if  (i1.lt.1)  then
            i1 = 1
          end  if
          i2 = ii + kcircle*kstp
          if  (i2.gt.nx)  then
            i2 = nx
          end  if
          nn = 0
          ss = 0.0
          do 5002 j = j1, j2, kstp
          do 5002 i = i1, i2, kstp
            if  (pc(i,j).ne.undef)  then
              nn = nn + 1
              ss = ss + pc (i,j)
            end  if
 5002     continue
          if  (nn.ge.3)  then
            pc  (ii,jj) = ss / nn
          else
            nmissing = nmissing + 1
          end  if
        end  if
 5003 continue
      if  (nmissing.gt.0)  then 
        kcircle = kcircle * 2 
        go  to  5001
      end  if
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to fill in the undefined land grids between the selected grids  *
c     *                                                                      *
c     ************************************************************************
c
      if  (kstp.eq.1)  then 
        go  to  7001 
      end  if  
c
      npx = (nx-1) / kstp 
      npy = (ny-1) / kstp 
      do 6002 jj = 1, npy  
      do 6002 ii = 1, npx  
        j1 = (jj-1)*kstp + 1 
        j2 = j1 + kstp   
        i1 = (ii-1)*kstp + 1 
        i2 = i1 + kstp   
        r11 = pc (i1,j1) 
        r21 = pc (i2,j1) 
        r12 = pc (i1,j2) 
        r22 = pc (i2,j2)  
        do 6001 j = j1, j2 
        do 6001 i = i1, i2 
          if  (pc(i,j).eq.undef)  then 
            wx1 = (i2 - i) / kstp 
            wx2 = 1.0 - wx1 
            wy1 = (j2 - j) / kstp 
            wy2 = 1.0 - wy1  
            pc (i,j) = r11 * wx1 * wy1 
     #               + r21 * wx2 * wy1 
     #               + r12 * wx1 * wy2 
     #               + r22 * wx2 * wy2 
          end  if  
 6001   continue 
 6002 continue  
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to fill in the missings remaining in the entire domain          *
c     *                                                                      *
c     ************************************************************************
c
 7001 nmissing = 0
      do 7003 jj = 1, ny
      do 7003 ii = 1, nx
        if  (pc(ii,jj).eq.undef)  then
          j1 = jj - kdg 
          if  (j1.lt.1)  then
            j1 = 1
          end  if
          j2 = jj + kdg 
          if  (j2.gt.ny)  then
            j2 = ny
          end  if
          i1 = ii - kdg 
          if  (i1.lt.1)  then
            i1 = 1
          end  if
          i2 = ii + kdg 
          if  (i2.gt.nx)  then
            i2 = nx
          end  if
          nn = 0
          ss = 0.0
          do 7002 j = j1, j2
          do 7002 i = i1, i2
            if  (pc(i,j).ne.undef)  then
              nn = nn + 1
              ss = ss + pc (i,j)
            end  if
 7002     continue
          if  (nn.ge.3)  then
            pc  (ii,jj) = ss / nn
          else
            nmissing = nmissing + 1
          end  if
        end  if
 7003 continue
      if  (nmissing.gt.0)  then
        go  to  7001
      end  if
c
 9999 return 
      end 
c
c
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******  *******  *******           *******  *******  *     *    *
c     *     *        *           *              *        *     *  **   **    *
c     *     *        *           *              *        *     *  * * * *    *
c     *     * *****  *******     *              *        *     *  *  *  *    * 
c     *     * *   *  *           *              *        *     *  *     *    * 
c     *     *     *  *           *              *        *     *  *     *    * 
c     *     *******  *******     *     *******  *******  *******  *     *    * 
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *                      *   * ***** *****    ***** ***** ***** *****    *
c     *                      *   * *     *   *    *   * *   * *   * *   *    *
c     *                      *   * ***** *****    ***** ***** *   * *****    *
c     *                       * *  *     *  *  **     *     * *   *     *    *
c     *                        *   ***** *   * ** ***** ***** ***** *****    *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_com.f                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to combine the various satellite estimates            *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                mode  =  1  ==>  combine all sources                  *
c     *                         2       combined observation only            *
c     *                                                                      *
c     *    algorithm:                                                        *
c     *                                                                      *
c     *                1)  This is an algorithm based on the Maximum         *
c     *                    Likelihood Estimation;                            *
c     *                                                                      *
c     *                2)  The output (combined analysis) is a linear        *
c     *                    combination of individual input data sources,     *
c     *                    in which the weighting coefficient is inversely   *
c     *                    proportional to the error variance of the input   *
c     *                    data source;                                      *
c     *                                                                      *
c     *                3)  The error variance for each input data source     *
c     *                    is calculated by another subroutine (get_err)     *
c     *                    and is read in from an outside file;              *
c     *                                                                      *
c     *                4)  There are two modes of this combining operation,  *
c     *                    one combining all input data sources and the      *
c     *                    other just for observation-based ones;            *
c     *                                                                      *
c     *   files     :                                                        *
c     *                                                                      *
c     *             re-gridded individual input fields and merged analysis   *
c     *             at various spatial resolution                            *
c     *                                                                      *
c     *                 unit 91  == output file at 0.10 deg grid points      *
c     *                                                                      *
c     *                 unit 92  == output file at 0.25 deg grid boxes       *
c     *                                                                      *
c     *                 unit 93  == output file at 0.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 94  == output file at 1.00 deg grid boxes       *
c     *                                                                      *
c     *                 unit 95  == output file at 2.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 96  == output file at 5.00 deg grid boxes       *
c     *                                                                      *
c     *                 In each file :                                       *
c     *                                                                      *
c     *                 ch 01    == GTS  precip    (mm/day)                  *
c     *                    02    ==      samping   (gauge number)            *
c     *                    03    ==      error1    (mm/day,all sources)      *
c     *                    04    ==      error2    (mm/day,obs only)         *
c     *                    05    == GPI  precip    (mm/day)                  *
c     *                    06    ==      sampling                            *
c     *                    07    ==      error1    (mm/day,all sources)      *
c     *                    08    ==      error2    (mm/day,obs only)         *
c     *                    09    == SSMI precip    (mm/day)                  *
c     *                    10    ==      sampling                            *
c     *                    11    ==      error1    (mm/day,all sources)      *
c     *                    12    ==      error2    (mm/day,obs only)         *
c     *                    13    == AMSU precip    (mm/day)                  *
c     *                    14    ==      sampling                            *
c     *                    15    ==      error1    (mm/day,all sources)      *
c     *                    16    ==      error2    (mm/day,obs only)         *

c     *                    21    == combined analysis using all data (mm/day)*
c     *                    22    == merged analysis using all data (mm/day)  *
c     *                    23    == error estimation   (mm/day)              *
c     *                    24    == combined analysis without GDAS (mm/day)  *
c     *                    25    == merged analysis without GDAS   (mm/day)  *
c     *                    26    == error estimation   (mm/day)              *
c     *                    27    == combined analysis  (GPI mm/day)          *
c     *                    28    == merged analysis    (GPI + GTS mm/day)    *
c     *                    29    == error estimation   (mm/day)              *
c     *                                                                      *
c     ************************************************************************
c
      subroutine  get_com  ( mode )   
c
      include  'merging_v0500_parameter.h'
c
      dimension   psat000 (nx000,ny000), esat000 (nx000,ny000), 
     #            pcom000 (nx000,ny000), ecom000 (nx000,ny000),
     #            psat025 (nx025,ny025), esat025 (nx025,ny025), 
     #            pcom025 (nx025,ny025), ecom025 (nx025,ny025),
     #            psat050 (nx050,ny050), esat050 (nx050,ny050), 
     #            pcom050 (nx050,ny050), ecom050 (nx050,ny050),
     #            psat100 (nx100,ny100), esat100 (nx100,ny100), 
     #            pcom100 (nx100,ny100), ecom100 (nx100,ny100),
     #            psat250 (nx250,ny250), esat250 (nx250,ny250), 
     #            pcom250 (nx250,ny250), ecom250 (nx250,ny250),
     #            psat500 (nx500,ny500), esat500 (nx500,ny500), 
     #            pcom500 (nx500,ny500), ecom500 (nx500,ny500)
c
      dimension   nn (nx000,ny000), 
     #            ss (nx000,ny000), sw (nx000,ny000)  
c
c     ************************************************************************
c     *                                                                      *
c     *  0.  to check the operation mode                                     *
c     *                                                                      *
c     ************************************************************************
c 
      if  (mode.lt.1.or.mode.gt.3)  then 
        write (6,*)  '  Wrong mode for combining !!' 
        write (6,*)  '  Your input :', mode 
        write (6,*)  '  Please choose 1 (all sources) or 2 (obs only) !'  
        stop 
      end  if  
      if  (mode.eq.1)  then 
        ndat = nsate 
      else  if  (mode.eq.2)  then   
        ndat = nobs  
      else 
        ndat = 1 
      end  if  
      write  (6,*)  '          finished checking combining mode !!'
c 
c     ************************************************************************
c     *                                                                      *
c     *  1.  to define for 0.1 deg grid pnt                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 1001 jj = 1, ny000 
      do 1001 ii = 1, nx000 
        ss (ii,jj) = 0.0 
        sw (ii,jj) = 0.0 
 1001 continue 
      do 1003 kk = 1, ndat 
        krec1 = kk * 4 + 1 
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2  
        else 
          krec2 = kk * 4 + 4 
        end  if  
        read  (91,rec=krec1)   psat000 
        read  (91,rec=krec2)   esat000 
        do 1002 jj = 1, ny000 
        do 1002 ii = 1, nx000 
          rr = psat000 (ii,jj) 
          ee = esat000 (ii,jj) 
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then 
            w          = 1.0 / ee  
            sw (ii,jj) = sw (ii,jj) + w  
            ss (ii,jj) = ss (ii,jj) + w * rr 
          end  if  
 1002   continue 
 1003 continue 
      do 1004 jj = 1, ny000 
      do 1004 ii = 1, nx000 
        if  (sw(ii,jj).gt.0.0)  then
          pcom000 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom000 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom000 (ii,jj) = undef 
          ecom000 (ii,jj) = undef 
        end  if  
 1004 continue 
      write  (6,*)  '          finished combining for 0.10 pnt !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define for 0.25 deg grid box                                 *
c     *                                                                      *
c     ************************************************************************
c
      do 2001 jj = 1, ny025 
      do 2001 ii = 1, nx025
        ss (ii,jj) = 0.0
        sw (ii,jj) = 0.0 
 2001 continue
      do 2003 kk = 1, ndat
        krec1 = kk * 4 + 1
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2 
        else 
          krec2 = kk * 4 + 4 
        end  if   
        read  (92,rec=krec1)   psat025
        read  (92,rec=krec2)   esat025
        do 2002 jj = 1, ny025 
        do 2002 ii = 1, nx025 
          rr = psat025 (ii,jj)
          ee = esat025 (ii,jj)
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then
            w          = 1.0 / ee 
            sw (ii,jj) = sw (ii,jj) + w    
            ss (ii,jj) = ss (ii,jj) + w * rr   
          end  if  
 2002   continue 
 2003 continue 
      do 2004 jj = 1, ny025  
      do 2004 ii = 1, nx025  
        if  (sw(ii,jj).gt.0.0)  then 
          pcom025 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom025 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom025 (ii,jj) = undef 
          ecom025 (ii,jj) = undef 
        end  if  
 2004 continue 
      write  (6,*)  '          finished combining for 0.25 box !!'             
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to define for 0.50 deg grid box                                 *
c     *                                                                      *
c     ************************************************************************
c
      do 3001 jj = 1, ny050  
      do 3001 ii = 1, nx050 
        ss (ii,jj) = 0.0
        sw (ii,jj) = 0.0 
 3001 continue
      do 3003 kk = 1, ndat
        krec1 = kk * 4 + 1
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2 
        else 
          krec2 = kk * 4 + 4 
        end  if  
        read  (93,rec=krec1)   psat050 
        read  (93,rec=krec2)   esat050 
        do 3002 jj = 1, ny050 
        do 3002 ii = 1, nx050 
          rr = psat050 (ii,jj)
          ee = esat050 (ii,jj)
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then
            w          = 1.0 / ee 
            sw (ii,jj) = sw (ii,jj) + w    
            ss (ii,jj) = ss (ii,jj) + w * rr   
          end  if  
 3002   continue 
 3003 continue 
      do 3004 jj = 1, ny050    
      do 3004 ii = 1, nx050    
        if  (sw(ii,jj).gt.0.0)  then 
          pcom050 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom050 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom050 (ii,jj) = undef 
          ecom050 (ii,jj) = undef 
        end  if  
 3004 continue 
      write  (6,*)  '          finished combining for 0.50 box !!'         
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to define for 1.0 deg grid box                                 *
c     *                                                                      *
c     ************************************************************************
c
      do 4001 jj = 1, ny100  
      do 4001 ii = 1, nx100  
        ss (ii,jj) = 0.0
        sw (ii,jj) = 0.0 
 4001 continue
      do 4003 kk = 1, ndat
        krec1 = kk * 4 + 1
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2 
        else 
          krec2 = kk * 4 + 4 
        end  if  
        read  (94,rec=krec1)   psat100 
        read  (94,rec=krec2)   esat100 
        do 4002 jj = 1, ny100 
        do 4002 ii = 1, nx100 
          rr = psat100 (ii,jj)
          ee = esat100 (ii,jj)
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then
            w          = 1.0 / ee 
            sw (ii,jj) = sw (ii,jj) + w    
            ss (ii,jj) = ss (ii,jj) + w * rr   
          end  if  
 4002   continue 
 4003 continue 
      do 4004 jj = 1, ny100   
      do 4004 ii = 1, nx100   
        if  (sw(ii,jj).gt.0.0)  then 
          pcom100 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom100 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom100 (ii,jj) = undef 
          ecom100 (ii,jj) = undef 
        end  if  
 4004 continue 
      write  (6,*)  '          finished combining for 1.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define for 2.5 deg grid box                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 5001 jj = 1, ny250    
      do 5001 ii = 1, nx250    
        ss (ii,jj) = 0.0
        sw (ii,jj) = 0.0 
 5001 continue
      do 5003 kk = 1, ndat
        krec1 = kk * 4 + 1
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2 
        else 
          krec2 = kk * 4 + 4 
        end  if  
        read  (95,rec=krec1)   psat250 
        read  (95,rec=krec2)   esat250 
        do 5002 jj = 1, ny250 
        do 5002 ii = 1, nx250 
          rr = psat250 (ii,jj)
          ee = esat250 (ii,jj)
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then
            w          = 1.0 / ee 
            sw (ii,jj) = sw (ii,jj) + w    
            ss (ii,jj) = ss (ii,jj) + w * rr   
          end  if  
 5002   continue 
 5003 continue 
      do 5004 jj = 1, ny250   
      do 5004 ii = 1, nx250   
        if  (sw(ii,jj).gt.0.0)  then 
          pcom250 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom250 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom250 (ii,jj) = undef 
          ecom250 (ii,jj) = undef 
        end  if  
 5004 continue 
      write  (6,*)  '          finished combining for 2.50 box !!'
c
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to define for 5.0 deg grid box                                  *
c     *                                                                      *
c     ************************************************************************
c
      do 6001 jj = 1, ny500    
      do 6001 ii = 1, nx500    
        ss (ii,jj) = 0.0
        sw (ii,jj) = 0.0 
 6001 continue
      do 6003 kk = 1, ndat
        krec1 = kk * 4 + 1
        if  (mode.le.2)  then 
          krec2 = kk * 4 + mode + 2 
        else 
          krec2 = kk * 4 + 4 
        end  if  
        read  (96,rec=krec1)   psat500 
        read  (96,rec=krec2)   esat500 
        do 6002 jj = 1, ny500 
        do 6002 ii = 1, nx500 
          rr = psat500 (ii,jj)
          ee = esat500 (ii,jj)
          if  (ee.eq.0.0)  then 
            ee = 0.000001 
          end  if  
          if  (rr.ne.undef.and.
     #         ee.ne.undef)   then
            w          = 1.0 / ee 
            sw (ii,jj) = sw (ii,jj) + w    
            ss (ii,jj) = ss (ii,jj) + w * rr   
          end  if  
 6002   continue 
 6003 continue 
      do 6004 jj = 1, ny500   
      do 6004 ii = 1, nx500   
        if  (sw(ii,jj).gt.0.0)  then 
          pcom500 (ii,jj) = ss (ii,jj) / sw (ii,jj) 
          ecom500 (ii,jj) = 1.0 / sqrt (sw(ii,jj)) 
        else    
          pcom500 (ii,jj) = undef 
          ecom500 (ii,jj) = undef 
        end  if  
 6004 continue 
      write  (6,*)  '          finished combining for 5.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to output the combined analysis                                 *
c     *                                                                      *
c     ************************************************************************
c 
      kout1 = (mode-1)*3 + 21 
      kout2 = kout1 + 2 
      write  (91,rec=kout1)   pcom000 
      write  (91,rec=kout2)   ecom000 
      write  (92,rec=kout1)   pcom025 
      write  (92,rec=kout2)   ecom025
      write  (93,rec=kout1)   pcom050 
      write  (93,rec=kout2)   ecom050
      write  (94,rec=kout1)   pcom100 
      write  (94,rec=kout2)   ecom100
      write  (95,rec=kout1)   pcom250 
      write  (95,rec=kout2)   ecom250
      write  (96,rec=kout1)   pcom500 
      write  (96,rec=kout2)   ecom500
      write  (6,*)  '          finished output the combined analysis !!'
c
      return 
      end  
c
c
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *                                                                      *
c     *     *******  *******  *******           *******  *     *  *******    *
c     *     *        *           *              *     *  **    *   *    *    *
c     *     *        *           *              *     *  * *   *   *    *    *
c     *     * *****  *******     *              ******   *  *  *   *    *    * 
c     *     * *   *  *           *              *     *  *   * *   *    *    * 
c     *     *     *  *           *              *     *  *    **   *    *    * 
c     *     *******  *******     *     *******  *******  *     *  *******    * 
c     *                                                                      *
c     *                                                                      *
c     *                                                                      *
c     *                      *   * ***** *****    ***** ***** ***** *****    *
c     *                      *   * *     *   *    *   * *   * *   * *   *    *
c     *                      *   * ***** *****    ***** ***** *   * *****    *
c     *                       * *  *     *  *  **     *     * *   *     *    *
c     *                        *   ***** *   * ** ***** ***** ***** *****    *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                get_bnd.f                                             *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to blend the combined satellite estimates with gauge  *
c     *                data                                                  *
c     *                                                                      *
c     *   input     :                                                        *
c     *                                                                      *
c     *                mode  =  1  ==>  blend all sources                    *
c     *                         2       blend observation only               *
c     *                                                                      *
c     *                kinp_gts     =   gts availability (1=yes)             *
c     *                                                                      *
c     *                kinp_com     =   combined analysis availability       *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                0)  Technical Terms:                                  *
c     *                      combining                                       * 
c     *                                = combining multiple individual       *
c     *                                  sources (satellite estimates or     *
c     *                                  model outputs) by Maximum Likelihood*
c     *                                  Estimation;                         *
c     *                                                                      *
c     *                      combined analysis                               *
c     *                                = output of the combining process.    *
c     *                                  random error should be reduced      *
c     *                                  but may contain bias from the       *
c     *                                  individual inputs;                  *
c     *                                                                      *
c     *                      blending                                        *
c     *                                = blending the combined analysis with *
c     *                                  gauge-based analysis through the    *
c     *                                  method of Reynolds (1988).          *
c     *                                                                      *
c     *                      blended analysis                                *
c     *                                = output of the blending process.     *
c     *                                  Bias is removed, or at least,       *
c     *                                  rediced.                            *
c     *                                                                      *
c     *                1)  The blending algorithm is based on the method of  *
c     *                    Reynolds (1988);                                  *
c     *                                                                      *
c     *                2)  The combined analysis and the gauge-based analysis*
c     *                    are used to define the 'shape' and the magnitude  *
c     *                    of the precipitation field, respectively;         *
c     *                                                                      *
c     *                3)  Because of the large spatial variation of the     *
c     *                    precipitation and the insufficient gauge network  *
c     *                    density to catch it, the blending is first done   *
c     *                    at coarser resolution to remove the bias with     *
c     *                    larger spatial scale and then repeat for finer    *
c     *                    resolution over areas with enough gauges;         *
c     *                                                                      *
c     *   files     :                                                        *
c     *                                                                      *
c     *             re-gridded individual input fields and merged analysis   *
c     *             at various spatial resolution                            *
c     *                                                                      *
c     *                 unit 91  == output file at 0.10 deg grid points      *
c     *                                                                      *
c     *                 unit 92  == output file at 0.25 deg grid boxes       *
c     *                                                                      *
c     *                 unit 93  == output file at 0.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 94  == output file at 1.00 deg grid boxes       *
c     *                                                                      *
c     *                 unit 95  == output file at 2.50 deg grid boxes       *
c     *                                                                      *
c     *                 unit 96  == output file at 5.00 deg grid boxes       *
c     *                                                                      *
c     *                 In each file :                                       *
c     *                                                                      *
c     *                 ch 01    == GTS  precip    (mm/day)                  *
c     *                    02    ==      samping   (gauge number)            *
c     *                    03    ==      error1    (mm/day,all sources)      *
c     *                    04    ==      error2    (mm/day,obs only)         *
c     *                    05    == GPI  precip    (mm/day)                  *
c     *                    06    ==      sampling                            *
c     *                    07    ==      error1    (mm/day,all sources)      *
c     *                    08    ==      error2    (mm/day,obs only)         *
c     *                    09    == SSMI precip    (mm/day)                  *
c     *                    10    ==      sampling                            *
c     *                    11    ==      error1    (mm/day,all sources)      *
c     *                    12    ==      error2    (mm/day,obs only)         *
c     *                    13    == AMSU precip    (mm/day)                  *
c     *                    14    ==      sampling                            *
c     *                    15    ==      error1    (mm/day,all sources)      *
c     *                    16    ==      error2    (mm/day,obs only)         *
c     *                    21    == combined analysis using all data (mm/day)*
c     *                    22    == merged analysis using all data (mm/day)  *
c     *                    23    == error estimation   (mm/day)              *
c     *                    24    == combined analysis without GDAS (mm/day)  *
c     *                    25    == merged analysis without GDAS   (mm/day)  *
c     *                    26    == error estimation   (mm/day)              *
c     *                    27    == combined analysis  ( GPI mm/day)         *
c     *                    28    == merged analysis    ( GPI + GTS )         *
c     *                    29    == error estimation   (mm/day)              *
c     *                                                                      *
c     ************************************************************************
c
      subroutine  get_bnd  ( mode, kinp_gts, kinp_com )   
c
      include  'merging_v0500_parameter.h'
c
      dimension   pcom000 (nx000,ny000), ecom000 (nx000,ny000), 
     #            pgag000 (nx000,ny000), egag000 (nx000,ny000),
     #            sgag000 (nx000,ny000), mask000 (nx000,ny000),
     #            pbnd000 (nx000,ny000), ebnd000 (nx000,ny000),
     #            p1st000 (nx000,ny000), 
     #            pcom025 (nx025,ny025), ecom025 (nx025,ny025), 
     #            pgag025 (nx025,ny025), egag025 (nx025,ny025),
     #            sgag025 (nx025,ny025), mask025 (nx025,ny025),
     #            pbnd025 (nx025,ny025), ebnd025 (nx025,ny025),
     #            p1st025 (nx025,ny025), 
     #            pcom050 (nx050,ny050), ecom050 (nx050,ny050), 
     #            pgag050 (nx050,ny050), egag050 (nx050,ny050),
     #            sgag050 (nx050,ny050), mask050 (nx050,ny050),
     #            pbnd050 (nx050,ny050), ebnd050 (nx050,ny050),
     #            p1st050 (nx050,ny050), 
     #            pcom100 (nx100,ny100), ecom100 (nx100,ny100), 
     #            pgag100 (nx100,ny100), egag100 (nx100,ny100),
     #            sgag100 (nx100,ny100), mask100 (nx100,ny100),
     #            pbnd100 (nx100,ny100), ebnd100 (nx100,ny100),
     #            p1st100 (nx100,ny100), 
     #            pcom250 (nx250,ny250), ecom250 (nx250,ny250), 
     #            pgag250 (nx250,ny250), egag250 (nx250,ny250),
     #            sgag250 (nx250,ny250), mask250 (nx250,ny250),
     #            pbnd250 (nx250,ny250), ebnd250 (nx250,ny250),
     #            p1st250 (nx250,ny250), 
     #            pcom500 (nx500,ny500), ecom500 (nx500,ny500), 
     #            pgag500 (nx500,ny500), egag500 (nx500,ny500),
     #            sgag500 (nx500,ny500), mask500 (nx500,ny500),
     #            pbnd500 (nx500,ny500), ebnd500 (nx500,ny500), 
     #            p1st500 (nx500,ny500) 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1. to check data availability                                       *
c     *                                                                      *
c     ************************************************************************
c
      if  (kinp_gts.eq.0.and.
     #     kinp_com.eq.0)  then 
        do 1101 jj = 1, ny000 
        do 1101 ii = 1, nx000 
          pbnd000 (ii,jj) = undef  
          ebnd000 (ii,jj) = undef 
 1101   continue 
        do 1102 jj = 1, ny025  
        do 1102 ii = 1, nx025  
          pbnd025 (ii,jj) = undef  
          ebnd025 (ii,jj) = undef 
 1102   continue
        do 1103 jj = 1, ny050 
        do 1103 ii = 1, nx050 
          pbnd050 (ii,jj) = undef  
          ebnd050 (ii,jj) = undef 
 1103   continue
        do 1104 jj = 1, ny100 
        do 1104 ii = 1, nx100 
          pbnd100 (ii,jj) = undef  
          ebnd100 (ii,jj) = undef 
 1104   continue
        do 1105 jj = 1, ny250 
        do 1105 ii = 1, nx250 
          pbnd250 (ii,jj) = undef  
          ebnd250 (ii,jj) = undef 
 1105   continue
        do 1106 jj = 1, ny500 
        do 1106 ii = 1, nx500 
          pbnd500 (ii,jj) = undef  
          ebnd500 (ii,jj) = undef 
 1106   continue
        go  to  9000 
      end  if  
c
      if  (kinp_gts.eq.0.and.
     #     kinp_com.ne.0)  then 
        kinp = (mode-1)*3 + 21 
        read  (91,rec=kinp)   pcom000
        read  (92,rec=kinp)   pcom025 
        read  (93,rec=kinp)   pcom050
        read  (94,rec=kinp)   pcom100
        read  (95,rec=kinp)   pcom250
        read  (96,rec=kinp)   pcom500
        do 1201 jj = 1, ny000 
        do 1201 ii = 1, nx000 
          pbnd000 (ii,jj) = pcom000 (ii,jj)   
          ebnd000 (ii,jj) = pcom000 (ii,jj)  
 1201   continue 
        do 1202 jj = 1, ny025   
        do 1202 ii = 1, nx025   
          pbnd025 (ii,jj) = pcom025 (ii,jj)   
          ebnd025 (ii,jj) = pcom025 (ii,jj)   
 1202   continue
        do 1203 jj = 1, ny050 
        do 1203 ii = 1, nx050 
          pbnd050 (ii,jj) = pcom050 (ii,jj)   
          ebnd050 (ii,jj) = pcom050 (ii,jj)   
 1203   continue
        do 1204 jj = 1, ny100 
        do 1204 ii = 1, nx100 
          pbnd100 (ii,jj) = pcom100 (ii,jj)   
          ebnd100 (ii,jj) = pcom100 (ii,jj)  
 1204   continue
        do 1205 jj = 1, ny250 
        do 1205 ii = 1, nx250 
          pbnd250 (ii,jj) = pcom250 (ii,jj)   
          ebnd250 (ii,jj) = pcom250 (ii,jj)   
 1205   continue
        do 1206 jj = 1, ny500 
        do 1206 ii = 1, nx500 
          pbnd500 (ii,jj) = pcom500 (ii,jj)   
          ebnd500 (ii,jj) = pcom250 (ii,jj)   
 1206   continue
        go  to  9000 
      end  if  
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to check the operation mode                                     *
c     *                                                                      *
c     ************************************************************************
c 
      if  (mode.lt.1.or.mode.gt.3)  then 
        write (6,*)  '  Wrong mode for combining !!' 
        write (6,*)  '  Your input :', mode 
        write (6,*)  '  Please choose 1 (all sources) or 2 (obs only) !'  
        stop 
      end  if  
      if  (mode.eq.1)  then 
        ndat = nsate 
      else  if  (mode.eq.2)  then  
        ndat = nobs  
      else 
        ndat = 1 
      end  if  
      write  (6,*)  '          finished checking blending mode !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to blend for 5.0 deg box                                        *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 0  
      nx0      = 15 
      ny0      = 16 
      rlat0    = -37.5 
      rlon0    = -17.5 
      dgrid0   = 5.0 
      nx1      = 15 
      ny1      = 16 
      rlat1    = -37.5 
      rlon1    = -17.5 
      dgrid1   = 5.0
c
      krec1 = 1 
      krec2 = 2 
      krec3 = mode + 2 
      krec4 = (mode-1)*3 + 21 
      krec5 = (mode-1)*3 + 23 
      read  (96,rec= krec1)   pgag500  
      read  (96,rec= krec2)   sgag500  
      read  (96,rec= krec3)   egag500  
      read  (96,rec= krec4)   pcom500  
      read  (96,rec= krec5)   ecom500  
c
      call   def_bnd_sub   
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland500, pbnd500,   
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland500, mask500,   
     #      pcom500, ecom500, pgag500, sgag500, egag500, 
     #      pbnd500, ebnd500, p1st500 )
      write  (6,*)  '          finished blending for 5.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to blend for 2.5 deg box                                        *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 1   
      nx0      = 15 
      ny0      = 16 
      rlat0    = -37.5 
      rlon0    = -17.5 
      dgrid0   = 5.0 
      nx1      = 30 
      ny1      = 32 
      rlat1    = -38.75  
      rlon1    = -18.75  
      dgrid1   = 2.5  
c
      krec1 = 1 
      krec2 = 2 
      krec3 = mode + 2 
      krec4 = (mode-1)*3 + 21
      krec5 = (mode-1)*3 + 23    
      read  (95,rec= krec1)   pgag250 
      read  (95,rec= krec2)   sgag250
      read  (95,rec= krec3)   egag250
      read  (95,rec= krec4)   pcom250
      read  (95,rec= krec5)   ecom250
c
      call   def_bnd_sub  
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland500, pbnd500,
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland250, mask250,
     #      pcom250, ecom250, pgag250, sgag250, egag250,
     #      pbnd250, ebnd250, p1st250 )
      write  (6,*)  '          finished blending for 2.50 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to blend for 1.0 deg box                                        *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 1
      nx0      = 30 
      ny0      = 32 
      rlat0    = -38.75 
      rlon0    = -18.75 
      dgrid0   = 2.5  
      nx1      = 75 
      ny1      = 80  
      rlat1    = -39.5 
      rlon1    = -19.5  
      dgrid1   = 1.0  
c
      krec1 = 1
      krec2 = 2
      krec3 = mode + 2
      krec4 = (mode-1)*3 + 21
      krec5 = (mode-1)*3 + 23   
      read  (94,rec= krec1)   pgag100
      read  (94,rec= krec2)   sgag100
      read  (94,rec= krec3)   egag100
      read  (94,rec= krec4)   pcom100
      read  (94,rec= krec5)   ecom100
c
      call   def_bnd_sub 
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland250, pbnd250,
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland100, mask100,
     #      pcom100, ecom100, pgag100, sgag100, egag100,
     #      pbnd100, ebnd100, p1st100 )
      write  (6,*)  '          finished blending for 1.00 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  6.  to blend for 0.5 deg box                                        *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 1
      nx0      = 75 
      ny0      = 80 
      rlat0    = -39.5  
      rlon0    = -19.5  
      dgrid0   = 1.0  
      nx1      = 150  
      ny1      = 160  
      rlat1    = -39.75  
      rlon1    = -19.75     
      dgrid1   = 0.5  
c
      krec1 = 1
      krec2 = 2
      krec3 = mode + 2
      krec4 = (mode-1)*3 + 21
      krec5 = (mode-1)*3 + 23   
      read  (93,rec= krec1)   pgag050
      read  (93,rec= krec2)   sgag050
      read  (93,rec= krec3)   egag050
      read  (93,rec= krec4)   pcom050
      read  (93,rec= krec5)   ecom050
c
      call   def_bnd_sub 
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland100, pbnd100,
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland050, mask050,
     #      pcom050, ecom050, pgag050, sgag050, egag050,
     #      pbnd050, ebnd050, p1st050 )
      write  (6,*)  '          finished blending for 0.50 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  7.  to blend for 0.25 deg box                                       *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 1
      nx0      = 150  
      ny0      = 160 
      rlat0    = -39.75     
      rlon0    = -19.75     
      dgrid0   = 0.5  
      nx1      = 300 
      ny1      = 320 
      rlat1    = -39.875 
      rlon1    = -19.875    
      dgrid1   = 0.25 
c
      krec1 = 1
      krec2 = 2
      krec3 = mode + 2
      krec4 = (mode-1)*3 + 21
      krec5 = (mode-1)*3 + 23   
      read  (92,rec= krec1)   pgag025
      read  (92,rec= krec2)   sgag025 
      read  (92,rec= krec3)   egag025
      read  (92,rec= krec4)   pcom025
      read  (92,rec= krec5)   ecom025
c
      call   def_bnd_sub 
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland050, pbnd050,
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland025, mask025,
     #      pcom025, ecom025, pgag025, sgag025, egag025,
     #      pbnd025, ebnd025, p1st025 )
c
      write  (6,*)  '          finished blending for 0.25 box !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  8.  to blend for 0.1 deg pnt                                        *
c     *                                                                      *
c     ************************************************************************
c 
      mode_bnd = 1
      nx0      = 300
      ny0      = 320
      rlat0    = -39.875
      rlon0    = -19.875
      dgrid0   = 0.25
      nx1      = 751 
      ny1      = 801 
      rlat1    = -40.00 
      rlon1    = -20.00    
      dgrid1   = 0.10 
c
      krec1 = 1
      krec2 = 2
      krec3 = mode + 2
      krec4 = (mode-1)*3 + 21
      krec5 = (mode-1)*3 + 23   
      read  (91,rec= krec1)   pgag000
      read  (91,rec= krec2)   sgag000   
      read  (91,rec= krec3)   egag000
      read  (91,rec= krec4)   pcom000
      read  (91,rec= krec5)   ecom000
c
      call   def_bnd_sub 
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rland025, pbnd025,
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rland000, mask000,
     #      pcom000, ecom000, pgag000, sgag000, egag000,
     #      pbnd000, ebnd000, p1st000 )
c
      kdg = 5    
      kds = kdg * kdg 
      do 8002 jj = 1, 801 
      do 8002 ii = 1, 751 
        if  (rland000(ii,jj).gt.0.0.and.
     #       pbnd000(ii,jj).gt.0.1)  then 
          j1 = jj - kdg  
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + kdg  
          if  (j2.gt.801)  then 
            j2 = 801 
          end  if  
          i1 = ii - kdg  
          if  (i1.lt.1)  then 
            i1 = 1  
          end  if  
          i2 = ii + kdg  
          if  (i2.gt.751)  then 
            i2 = 751 
          end  if   
          do 8001 j = j1, j2 
          do 8001 i = i1, i2 
            kd =   (j-jj)*(j-jj) + (i-ii)*(i-ii)
            if  (kd.le.kds)  then 
              if  (pcom000(i,j).gt.0.0)  then 
                go  to  8002 
              else 
                if  (pgag000(i,j).gt.0.0.and. 
     #               sgag000(i,j).ge.1.0)  then 
                  go  to  8002 
                end  if  
              end  if  
            end  if  
 8001     continue 
          pbnd000 (ii,jj) = 0.0 
        end  if  
 8002 continue 
c
      write  (6,*)  '          finished blending for 0.10 pnt !!'
c
c     ************************************************************************
c     *                                                                      *
c     *  9.  to output the results                                           *
c     *                                                                      *
c     ************************************************************************
c
 9000 continue 
      kout1 = (mode-1)*3 + 22 
      kout2 = (mode-1)*3 + 23 
      write  (91,rec=kout1)   pbnd000 
      write  (91,rec=kout2)   ebnd000 
      write  (92,rec=kout1)   pbnd025 
      write  (92,rec=kout2)   ebnd025
      write  (93,rec=kout1)   pbnd050 
      write  (93,rec=kout2)   ebnd050
      write  (94,rec=kout1)   pbnd100 
      write  (94,rec=kout2)   ebnd100
      write  (95,rec=kout1)   pbnd250 
      write  (95,rec=kout2)   ebnd250
      write  (96,rec=kout1)   pbnd500 
      write  (96,rec=kout2)   ebnd500 
      write  (6,*)  '          finished output the blended analysis !!'
c
      return 
      end  
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *   ***** ***** *****       ***** *   * *****       ***** *   * *****  *
c     *    *  * *     *           *   * **  *  *  *       *     *   * *   *  *
c     *    *  * ***** *****       ****  * * *  *  *       ***** *   * ****   *
c     *    *  * *     *           *   * *  **  *  *           * *   * *   *  *
c     *   ***** ***** *     ***** ***** *   * ***** ***** ***** ***** *****  *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                def_bnd_sub                                           *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to define the blended analysis                        *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                0)  technical terms:                                  *
c     *                       combining                                      *  
c     *                                 = combining the satellite estimates  *
c     *                                   and model outputs through the      *
c     *                                   Maximum Likelihood Estimation;     *
c     *                       combined analysis                              *
c     *                                 = output of the combining, with      *
c     *                                   reduced random error compared to   *
c     *                                   the individual data sources;       *
c     *                       blending                                       *
c     *                                 = blending the combined analysis     *
c     *                                   with the gauge-based analysis      *
c     *                                   through the method of Reynolds     *
c     *                                   (1988);                            *
c     *                       blended analysis                               *
c     *                                 = output of the blending, with       *
c     *                                   the bias inherent in the combined  *
c     *                                   analysis removed;                  *
c     *                                                                      *
c     *                1)  This algorithm is basically based on the method   *
c     *                    of Reynolds (1988);                               *
c     *                                                                      *
c     *                2)  The combined analysis (from satellite estimates   *
c     *                    and the model outputs) is used to define the      *
c     *                    shape, while the gauge-based analysis over anchor *
c     *                    points are used to define the magnitude of the    *
c     *                    precipitation field;                              *
c     *                                                                      *
c     *                3)  Since the gauge-based analysis has to be un-biased*
c     *                    over the anchor points, they are defined as those *
c     *                    grid boxes with at least 1 gauge inside;          *
c     *                                                                      *
c     *                4)  Based on the simulation results in Xie and Arkin  *
c     *                    (1996), the method of Reynolds (1988) is able to  *
c     *                    remove the bias over grids neiboring to an anchor,*
c     *                    otherwise the results are not desirable;          *
c     *                                                                      *
c     *                5)  In adopting the Reynolds (1988) to this case,     *
c     *                    some modifications were necessary to deal with    *
c     *                    the high spatial variation in the daily precip    *
c     *                    field and poor gauge network over the target area;*
c     *                                                                      *
c     *                6)  Instead of the one-step approach as used in CMAP, *
c     *                    a multi-step approach is designed;                *
c     *                                                                      *
c     *                7)  First, the combined satellite estimates/model     *
c     *                    output and the gauge-based analysis are combined  *
c     *                    for fields on 5.0 deg lat/lon grid boxes, with    *
c     *                    grid boxes with 1 or more gauges defined as       *
c     *                    anchors;                                          *
c     *                                                                      *
c     *                8)  A first guess of the blended analysis for 2.5 deg *
c     *                    grid boxes is then defined by removing the bias   *
c     *                    defined by comparing the combined analysis at 2.5 *
c     *                    deg grid boxes with the blended analysis at 5.0   *
c     *                    deg grid boxes;                                   *
c     *                                                                      *
c     *                9)  Finally, the Reynolds (1988) proceure is applied  *
c     *                    to define the value at grid boxes neiboring to an *
c     *                    anchor point;                                     *
c     *                                                                      *
c     *                a)  Steps 7-9 are repeated to define the blended      *
c     *                    analysis at 1.0, 0.5, 0.25 and 0.1 deg grid;      *
c     *                                                                      *
c     *                b)  The algorithm described above is able to remove   *
c     *                    the bias on finer scale where gauge network is    *
c     *                    denser, and on coarser scale where there is few   *
c     *                    gauges.                                           *
c     *                                                                      *
c     *   input / output     :                                               *
c     *                                                                      *
c     *                mode_bnd                                              *
c     *                      =  blending operation mode                      *
c     *                         0  =  no blended analysis at coarser grid    *
c     *                               is used                                *
c     *                         1  =  blended analysis at coarser grid       *
c     *                               is used                                *
c     *                                                                      *
c     *                undef =  undefined code                               *
c     *                                                                      *
c     *                ( coarser grid )                                      *
c     *                                                                      *
c     *                nx0   =   dimension in east-west direction            *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                ny0   =   dimension in north-south direction          *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                rlat0 =   latitude for the coarser grid at j = 1      *
c     *                                                                      *
c     *                rlon0 =   longitude for the coarser grid at i = 1     *
c     *                                                                      *
c     *                dgrid0=   lat/lon increment in the coarser grid       *
c     *                                                                      *
c     *                rmask0=   land/ocean mask at coarser resolution       *
c     *                          1.0 = land; 0.0 = ocean                     *
c     *                                                                      *
c     *                rblnd0=   blended analysis at coarser resolution      *
c     *                          rblnd0 (nx0,ny0)                            *
c     *                                                                      *
c     *                                                                      *
c     *                ( finer grid )                                        *
c     *                                                                      *
c     *                nx1   =   dimension in east-west direction            *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                ny1   =   dimension in north-south direction          *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                rlat1 =   latitude for the finer grid at j = 1        *
c     *                                                                      *
c     *                rlon1 =   longitude for the finer grid at i = 1       *
c     *                                                                      *
c     *                dgrid1=   lat/lon increment in the finer grid         *
c     *                                                                      *
c     *                rmask1=   land/ocean mask at finer resolution         *
c     *                          1.0 = land; 0.0 = ocean                     *
c     *                                                                      *
c     *                mask1 =   land/ocean mask at finer resolution         *
c     *                          used in blending                            *
c     *                          0 = ocean          ; 1 = land anchor      ; *
c     *                          2 = land non-anchor; 3 = land from coarser; *
c     *                                                                      *
c     *                rcomb1=   combined analysis at finer resolution       *
c     *                          rcomb1 (nx1,ny1)                            *
c     *                                                                      *
c     *                ecomb1=   error estimation for combined analysis      *
c     *                          at finer resolution                         *  
c     *                          rcomb1 (nx1,ny1)                            *
c     *                                                                      *
c     *                rgage1=   gauge-based analysis at finer resolution    *
c     *                          rgage1 (nx1,ny1)                            *
c     *                                                                      *
c     *                egage1=   error estimation for gauge-based analysis   *
c     *                          at finer resolution                         * 
c     *                          egage1 (nx1,ny1)                            *
c     *                                                                      *
c     *                sgage1=   number of gauge for gauge-based analysis    *
c     *                          at finer resolution                         * 
c     *                          sgage1 (nx1,ny1)                            *
c     *                                                                      *
c     *   (output)     rblnd1=   blended analysis at finer resolution        *
c     *                          rblnd1 (nx1,ny1)                            *
c     *                                                                      *
c     *   (output)     eblnd1=   error estimation for blended analysis       *
c     *                          at finer resolution                         * 
c     *                          eblnd1 (nx1,ny1)                            *
c     *                                                                      *
c     ************************************************************************
c
      subroutine   def_bnd_sub   
     #    ( mode_bnd      , undef ,
     #      nx0   , ny0   , rlat0 , rlon0 , dgrid0, rmask0, rblnd0,   
     #      nx1   , ny1   , rlat1 , rlon1 , dgrid1, rmask1, mask1,   
     #      rcomb1, ecomb1, rgage1, sgage1, egage1, 
     #      rblnd1, eblnd1, p1st1 )  

c
      dimension   rmask0 (nx0,ny0),  rblnd0 (nx0,ny0) 
      dimension   rmask1 (nx1,ny1),  mask1  (nx1,ny1),  
     #            rcomb1 (nx1,ny1),  ecomb1 (nx1,ny1),  
     #            rgage1 (nx1,ny1),  sgage1 (nx1,ny1), 
     #            egage1 (nx1,ny1),    
     #            rblnd1 (nx1,ny1),  eblnd1 (nx1,ny1), 
     #            p1st1  (nx1,ny1)  
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to define the land mask                                         *  
c     *        0  ==> ocean                                                  *
c     *        1  ==> land, anchor                                           *
c     *        2  ==> land, non-anchor                                       *
c     *                                                                      *
c     ************************************************************************
c
c     1.1  to define based on land/ocean mask and gauge number  
      do 1001 jj = 1, ny1 
      do 1001 ii = 1, nx1  
        if  (rmask1(ii,jj).eq.0.0)  then 
          mask1 (ii,jj) = 0 
        else 
          if  (sgage1(ii,jj).ge.1.0)  then 
            mask1 (ii,jj) = 1 
          else 
            mask1 (ii,jj) = 2 
          end  if  
        end  if  
 1001 continue 
c
c     1.2  to define the land/ocean board as anchor 
      do 1003 jj = 1, ny1  
      do 1003 ii = 1, nx1  
        if  (mask1(ii,jj).eq.2)  then 
          j1 = jj - 1 
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + 1 
          if  (j2.gt.ny1)  then 
            j2 = ny1  
          end  if  
          i1 = ii - 1 
          if  (i1.lt.1)  then 
            i1 = 1 
          end  if  
          i2 = ii + 1 
          if  (i2.gt.nx1)  then 
            i2 = nx1  
          end  if  
          do 1002 j = j1, j2 
          do 1002 i = i1, i2 
            if  (mask1(i,j).eq.0)  then 
              mask1 (ii,jj) = 1 
              go  to  1003 
            end  if  
 1002     continue 
          if  (ii.eq.1.or. 
     #         ii.eq.nx1.or. 
     #         jj.eq.1.or. 
     #         jj.eq.ny1)  then 
            mask1 (ii,jj) = 1 
          end  if  
        end  if   
 1003 continue 
c
c     1.3  to judge if or not need to define blended analysis
c          from coarser data 
c
      if  (mode_bnd.eq.0)  then
        go  to  3001    
      end  if
c
c     1.4  to define the grid boxes with no-neighboring anchor as 3 
c          ( values at those grid boxes will be defined from  
c            blended analysis at coarser resolution ) 
c   
      do 1005 jj = 1, ny1 
      do 1005 ii = 1, nx1  
        if  (mask1(ii,jj).eq.2)  then 
          j1 = jj - 1 
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + 1 
          if  (j2.gt.ny1)  then 
            j2 = ny1  
          end  if  
          i1 = ii - 1 
          if  (i1.lt.1)  then 
            i1 = 1 
          end  if  
          i2 = ii + 1 
          if  (i2.gt.nx1)  then 
            i2 = nx1  
          end  if  
          do 1004 j = j1, j2 
          do 1004 i = i1, i2 
            if  (mask1(i,j).eq.1)  then 
              go  to  1005 
            end  if  
 1004     continue 
          mask1 (ii,jj) = 3 
        end  if   
 1005 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the blended field from blended analysis               *
c     *      at coarser resolution                                           *
c     *                                                                      *
c     ************************************************************************
c
      call  def_fine 
     #      ( nx0, ny0, rmask0, rblnd0, rlat0, rlon0, dgrid0,
     #        nx1, ny1, rmask1, rblnd1, rlat1, rlon1, dgrid1,
     #                  rcomb1, p1st1 , undef                 )
      do 2001 jj = 1, ny1 
      do 2001 ii = 1, nx1 
        if  (mask1(ii,jj).eq.3)  then 
          mask1  (ii,jj) = 1 
          rgage1 (ii,jj) = rblnd1 (ii,jj) 
        end  if  
 2001 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to blend the combined field with the gauge data                 *
c     *                                                                      *
c     ************************************************************************
c
 3001 continue 
      do 3002 jj = 1, ny1 
      do 3002 ii = 1, nx1  
        p1st1 (ii,jj) = rcomb1 (ii,jj) 
 3002 continue 
c     note:  the data array sgage1 is used to hold the first guess
c            for input to the subroutine blending 
c
      mode_smoothing = 0 
      call  blending  (  mode_smoothing,  
     #                   nx1,    ny1,   mask1, 
     #                   rgage1,  egage1, rcomb1, ecomb1, 
     #                   p1st1 ,  rblnd1, eblnd1         ) 
c
c     ************************************************************************
c     *                                                                      *
c     *  4.  to modify the non-rain area                                     *
c     *                                                                      *
c     ************************************************************************
c
      do 4001 jj = 1, ny1 
      do 4001 ii = 1, nx1 
        if  (rblnd1(ii,jj).ne.undef.and. 
     #       rblnd1(ii,jj).lt.0.2)  then 
          rblnd1 (ii,jj) = 0.0 
        end  if  
 4001 continue 
c
c
c     ************************************************************************
c     *                                                                      *
c     *  5.  to define error estimation                                      *
c     *                                                                      *
c     ************************************************************************
c
      do 5001 jj = 1, ny1 
      do 5001 ii = 1, nx1 
        if  (rmask1(ii,jj).eq.0.0)  then 
          eblnd1 (ii,jj) = ecomb1 (ii,jj) 
        else 
          if  (sgage1(ii,jj).ge.1.0)  then 
            eblnd1 (ii,jj) = egage1 (ii,jj) 
          else 
            eblnd1 (ii,jj) = ecomb1 (ii,jj) 
          end  if  
        end  if  
 5001 continue 
c
      return  
      end 
c
c
c
c     ************************************************************************
c     *                                                                      *
c     *        *****  *****  *****        *****  *****  *   *  *****         *
c     *         *  *  *      *            *        *    **  *  *             *
c     *         *  *  *****  *****        *****    *    * * *  *****         *
c     *         *  *  *      *            *        *    *  **  *             *
c     *        *****  *****  *      ***** *      *****  *   *  *****         *
c     *                                                                      *
c     ************************************************************************
c
c     ************************************************************************
c     *                                                                      *
c     *   subroutine:                                                        *
c     *                                                                      *
c     *                def_fine                                              *
c     *                                                                      *
c     *   objective :                                                        *
c     *                                                                      *
c     *                to define the blended analysis at finer resolution    *
c     *                by removing bias defined for coarser resolution       *
c     *                                                                      *
c     *   algorithm :                                                        *
c     *                                                                      *
c     *                1)  This step is included to deal with those grid     *
c     *                    boxes where regular blending may not apply        *
c     *                    because of the lack of neiboring anchors;         *
c     *                                                                      *
c     *                2)  This is done by comparing the combined field      *
c     *                    (with bias) at finer resolution with blended      *
c     *                    field (without bias) at corser resolution;        *
c     *                                                                      *
c     *                3)  First, all missing values in the combined field   *
c     *                    at finer resolution are filled by interpolation;  *
c     *                                                                      *
c     *                4)  The first guess of the blended field at finer     *
c     *                    resolution is then defined by interpolating from  *
c     *                    the blended field at coarser resolution;          *
c     *                                                                      *
c     *                5)  Finally, the blended field at finer resolution    *
c     *                    is obtained by correcting the first guess         *
c     *                    considering the local spatial variation defined   *
c     *                    from the combined field at finer resolution;      *
c     *                                                                      *
c     *                6)  This blended field will be used as the input to   *
c     *                    the next step which will redefine the field over  *
c     *                    grid boxes where noboring achnors are available.  *
c     *                                                                      *
c     *                                                                      *
c     *   input / output    :                                                *
c     *                                                                      *
c     *                ( coarser grid )                                      *
c     *                                                                      *
c     *                nx0   =   dimension in east-west direction            *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                ny0   =   dimension in north-south direction          *
c     *                          in coarser resolution                       *
c     *                                                                      *
c     *                rmask0=   land/ocean mask at coarser resolution       *
c     *                          1.0 = land; 0.0 = ocean                     *
c     *                                                                      *
c     *                rain0 =   blended field at coarser resolution         *
c     *                          rain0 (nx0,ny0)                             *
c     *                                                                      *
c     *                rlat0 =   latitude for the coarser grid at j = 1      *
c     *                                                                      *
c     *                rlon0 =   longitude for the coarser grid at i = 1     *
c     *                                                                      *
c     *                dgrid0=   lat/lon increment in the coarser grid       *
c     *                                                                      *
c     *                                                                      *
c     *                ( finer grid )                                        *
c     *                                                                      *
c     *                nx1   =   dimension in east-west direction            *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                ny1   =   dimension in north-south direction          *
c     *                          in finer resolution                         *
c     *                                                                      *
c     *                rmask1=   land/ocean mask at finer resolution         *
c     *                          1.0 = land; 0.0 = ocean                     *
c     *                                                                      *
c     *   (output)     rain1 =   blended field at finer resolution           *
c     *                          rain1 (nx1,ny1)                             *
c     *                                                                      *
c     *                rlat1 =   latitude for the finer grid at j = 1        *
c     *                                                                      *
c     *                rlon1 =   longitude for the finer grid at i = 1       *
c     *                                                                      *
c     *                dgrid1=   lat/lon increment in the finer grid         *
c     *                                                                      *
c     *                comb1 =   combined field at finer resolution          *
c     *                          comb1 (nx1,ny1)                             *
c     *                                                                      *
c     *    (output)    first1=   first guess at finer resolution             *
c     *                          first1 (nx1,ny1)                            *
c     *                                                                      *
c     *                undef =   undefined code                              *
c     *                                                                      *
c     *                                                                      *
c     ************************************************************************
c
      subroutine  def_fine            
     #       ( nx0, ny0, rmask0, rain0, rlat0, rlon0, dgrid0, 
     #         nx1, ny1, rmask1, rain1, rlat1, rlon1, dgrid1, 
     #                   comb1,  first1,undef                  )  
c
      dimension   rmask0 (nx0,ny0), rain0 (nx0,ny0), 
     #            rmask1 (nx1,ny1), rain1 (nx1,ny1), 
     #            first1 (nx1,ny1), comb1 (nx1,ny1)  
c
c
c     ************************************************************************
c     *                                                                      *
c     *  1.  to fill in the missing values in the combined field             *  
c     *      on finer resolution                                             *
c     *                                                                      *
c     ************************************************************************
c
 1001 missing = 0 
      do 1003 jj = 1, ny1 
      do 1003 ii = 1, nx1 
        if  (comb1(ii,jj).eq.undef)  then 
          j0 = jj - 2 
          if  (j0.lt.1)  then 
            j0 = 1 
          end  if  
          j1 = jj + 2 
          if  (j1.gt.ny1)  then 
            j1 = ny1 
          end  if  
          i0 = ii - 2 
          if  (i0.lt.1)  then 
            i0 = 1 
          end  if  
          i1 = ii + 2 
          if  (i1.gt.nx1)  then 
            i1 = nx1 
          end  if  
          sw = 0.0 
          ss = 0.0 
          do 1002 j = j0, j1 
          do 1002 i = i0, i1  
            if  (comb1 (i,j).ne.undef)  then 
              dd = float( (jj-j)*(jj-j) + (ii-i)*(ii-i)) 
              w  = 1.0 / dd 
              sw = sw + w 
              ss = ss + w * comb1 (i,j) 
            end  if  
 1002     continue 
          if  (sw.gt.0.0)  then 
            comb1 (ii,jj) = ss / sw 
          else 
            missing = missing + 1 
          end  if   
        end  if  
 1003 continue 
      if  (missing.ne.0)  then 
        go  to  1001 
      end  if  
c
c     ************************************************************************
c     *                                                                      *
c     *  2.  to define the blended field in finer resolution                 *  
c     *      by interpolating from blended field on coarser resolution       *
c     *                                                                      *
c     ************************************************************************
c
      dist0 = 0.5 * dgrid0  
c
      do 2002 jj = 1, ny1    
      do 2002 ii = 1, nx1   
c
c       2.1  to define for the oceanic grids 
        if  (rmask1(ii,jj).eq.0.0)  then 
          first1 (ii,jj) = undef 
          go  to  2002 
        end  if  
c
c       2.2  to select the center pixel 
        rlat  = (jj-1)*dgrid1 + rlat1 
        rlon  = (ii-1)*dgrid1 + rlon1 
        jc    = nint ((rlat-rlat0)/dgrid0) + 1  
        ic    = nint ((rlon-rlon0)/dgrid0) + 1 
c
c       2.3  to determine the pixels used to interpolate 
        j0 = jc - 1 
        if  (j0.lt.1)  then 
          j0 = 1 
        end  if  
        j1 = jc + 1 
        if  (jc.gt.ny0)  then 
          j1 = ny0 
        end  if  
        i0 = ic - 1 
        if  (i0.lt.1)  then 
          i0 = 1 
        end  if  
        i1 = ic + 1 
        if  (i1.gt.nx0)  then 
          i1 = nx0 
        end  if  
c
c       2.4  to interpolate 
        sw = 0.0 
        ss = 0.0 
        do 2001 j = j0, j1 
        do 2001 i = i0, i1   
          if  (rmask0(i,j).eq.1.0.and.
     #         rain0(i,j).ne.undef)  then 
            dlat = (j-1)*dgrid0 + rlat0 - rlat 
            dlon = (i-1)*dgrid0 + rlon0 - rlon 
            dist = dlat*dlat + dlon*dlon 
            if  (dist.eq.0.0)  then 
              first1 (ii,jj) = rain0 (i,j) 
              go  to  2002 
            else  if  (dlon.le.dist0.and.dlat.le.dist0)  then    
              w  = 1.0 / dist 
              sw = sw + w 
              ss = ss + w * rain0 (i,j) 
            end  if  
          end  if 
 2001   continue 
        if  (sw.gt.0.0)  then 
          first1 (ii,jj) = ss / sw 
        else 
          first1 (ii,jj) = undef 
        end  if  
 2002 continue 
c
c     ************************************************************************
c     *                                                                      *
c     *  3.  to conduct the correction based on combined analysis            * 
c     *      on finer resolution                                             *  
c     *                                                                      *
c     ************************************************************************
c
      kdg = 5   
      kdg2 = kdg * kdg 
c
      do 3002 jj = 1, ny1 
      do 3002 ii = 1, nx1 
        rain1 (ii,jj) = first1 (ii,jj)  
        if  (rmask1(ii,jj).eq.1.0)  then 
          j0 = jj - kdg  
          if  (j0.lt.1)  then 
            j0 = 1 
          end  if  
          j1 = jj + kdg  
          if  (j1.gt.ny1)  then 
            j1 = ny1 
          end  if  
          i0 = ii - kdg  
          if  (i0.lt.1)  then 
            i0 = 1 
          end  if  
          i1 = ii + kdg  
          if  (i1.gt.nx1)  then 
            i1 = nx1 
          end  if  
          nn = 0 
          rr = 0.0 
          cc = 0.0 
          do 3001 j = j0, j1 
          do 3001 i = i0, i1 
            kdst = (j-jj)*(j-jj) + (i-ii)*(i-ii) 
            if  (rmask1(i,j).eq.1.0.and.
     #           first1(i,j).ne.undef.and. 
     #           comb1 (i,j).ne.undef.and.
     #           kdst.le.kdg2)  then 
              nn = nn + 1 
              rr = rr + first1 (i,j) 
              cc = cc + comb1  (i,j) 
            end  if  
 3001     continue 
          if  (nn.gt.0.and. 
     #         rr.gt.0.0.and. 
     #         cc.gt.0.0)  then 
            rain1 (ii,jj) = comb1 (ii,jj) * rr / cc 
          end  if  
        end  if  
 3002 continue 
c
      do 3003 jj = 1, ny1 
      do 3003 ii = 1, nx1 
        if  (rain1(ii,jj).ne.undef.and. 
     #       rain1(ii,jj).lt.0.1)  then 
          rain1 (ii,jj) = 0.0 
        end  if  
 3003 continue
c
      return  
      end 
c
c
c
c     *************************************************************************
c     ***                                                                   ***
c     ***                                                                   ***
c     ***        *******   *         *******    *     *    *******          ***
c     ***         *    *   *         *          **    *     *    *          ***
c     ***         *    *   *         *          * *   *     *    *          ***
c     ***         *****    *         *******    *  *  *     *    *          ***
c     ***         *    *   *         *          *   * *     *    *          ***
c     ***         *    *   *         *          *    **     *    *          ***
c     ***        *******   *******   *******    *     *    *******          ***
c     ***                                                                   ***
c     ***                                                                   ***
c     ***                                                                   ***
c     ***       *    *  *****  *****      *****  *****  *****  *****        ***
c     ***       *    *  *      *   *      *   *  *      *   *  *   *        ***
c     ***       *    *  *****  *****      *****  *****  *   *  *****        ***
c     ***        *  *   *      *  *   **      *      *  *   *      *        ***
c     ***         *     *****  *   *  **  *****  *****  *****  *****        ***
c     ***                                                                   ***
c     ***                                                                   ***
c     *************************************************************************
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   Program       :                                                 ***
c     ***                   blending.f                                      ***
c     ***                                                                   ***
c     ***   Objective     :                                                 ***
c     ***                                                                   ***
c     ***         to blend the satellite estimates and gage observation     ***
c     ***                                                                   ***
c     ***     of the target field by applying Laplacian interplotation      ***
c     ***                                                                   ***
c     ***   Programmer    :                                                 ***
c     ***                                                                   ***
c     ***     Dr. Pingping Xie                                              ***
c     ***     National Meteorological Center, #800A                         ***
c     ***     5200 Auth Road                                                ***
c     ***     Camp Springs, MD 20746                                        ***
c     ***                                                                   ***
c     ***     Tel.     301-763-8167                                         ***
c     ***     Fax.     301-763-8125                                         ***
c     ***     E-mail   xping@sgi17.wwb.noaa.gov                             ***
c     ***                                                                   ***
c     *************************************************************************
c
      subroutine    blending   (mode,nx,ny,mask,
     #                          gage,egage,sate,esate,
     #                          first,blend,eblend)     
c  
c     *************************************************************************
c     ***                                                                   ***
c     ***   parameters:                                                     ***
c     ***                                                                   ***
c     ***     mode     :   mode of blending procedure                       ***
c     ***                    0  ==  blending                                ***
c     ***                    1  ==  blending + smoothing at all grids       ***
c     ***                    2  ==  blending + smoothing at non-anchor grids***
c     ***                                                                   ***
c     ***     nx       :   number of grids in east-west direction           ***
c     ***                    1 <= nx <= 1000                                ***
c     ***                                                                   ***
c     ***     ny       :   number of grids in north-south direction         ***
c     ***                    1 <= ny <= 1000                                ***
c     ***                                                                   ***
c     ***     mask     :   land-ocean mask                                  ***
c     ***                    mask (nx,ny)  ==  0  ==>  ocean grid           ***
c     ***                                      1  ==>  anchor land grid     ***
c     ***                                      2  ==>  non-anchor land grid ***
c     ***                                                                   ***
c     ***    gage      :   gage observation field                           ***
c     ***                    gage (nx,ny)                                   ***
c     ***                    ( must >= 0.0 when mask = 1 )                  ***
c     ***                                                                   ***
c     ***    egage     :   random error field for gauge                     ***
c     ***                    egage (nx,ny)                                  ***
c     ***                    ( >= 0.0 in percentage. e.g. 20% ==> 20.0 )    ***
c     ***                                                                   ***
c     ***    sate      :   satellite estimates field                        ***
c     ***                    sate (nx,ny)                                   ***
c     ***                    ( >= 0.0 unless -999.0 )                       ***
c     ***                                                                   ***
c     ***    esate     :   random error fields for satellite estimates      ***
c     ***                    esate (nx,ny)                                  ***
c     ***                    ( >= 0.0 in percentage.  e.g. 20% ==> 20.0 )   ***
c     ***                                                                   ***
c     ***    first     :   first guess field                                ***
c     ***                    first(nx,ny)                                   ***
c     ***                    (could be any but must be complete)            ***
c     ***                                                                   ***
c     ***    blend     :   blended analysis                                 ***
c     ***                    blend (nx,ny)                                  ***
c     ***                    ( >= 0.0 when mask = 1 or 2)                   ***
c     ***                    ( undefined when mask =0 )                     ***
c     ***                                                                   ***
c     ***    eblend     :  error field for the blended analysis             ***
c     ***                    eblend (nx,ny)                                 ***
c     ***                    ( >= 0.0 in percentage.  e.g. 20% ==> 20.0 )   ***
c     ***                                                                   ***
c     ***  notice:                                                          ***
c     ***                                                                   ***
c     ***    undefined value  ==  -999.0                                    ***
c     ***                                                                   ***
c     *************************************************************************
c 
      dimension     mask(nx,ny),first(nx,ny), 
     #               gage(nx,ny), sate(nx,ny), blend(nx,ny), 
     #              egage(nx,ny),esate(nx,ny),eblend(nx,ny) 
c  
c     *************************************************************************
c     ***                                                                   ***
c     ***   1.  to check the input                                          ***
c     ***                                                                   ***
c     *************************************************************************
c 
      if  (mode.lt.0.and.mode.gt.2)  then 
        write  (6,*)  'wrong blending mode :',mode  
        write  (6,*)  'Please select from 0, 1, or 2 !' 
        stop 
      end  if  
      if  (nx.le.0.or.nx.gt.1000)  then 
        write  (6,*)  'wrong input (nx):',nx 
        write  (6,*)  'Please select from 1 -- 1000 !' 
        stop 
      end  if  
      if  (ny.le.0.or.ny.gt.1000)  then 
        write  (6,*)  'wrong input (ny):',ny 
        write  (6,*)  'Please select from 1 -- 1000 !' 
        stop 
      end  if  
      ng=0   
      ns=0 
      nf=0 
      do 1001 jj=1,nx 
      do 1001 ii=1,ny 
c      print *, sate(ii,jj)
        if  (gage(ii,jj).lt.0.0.and. 
     #       gage(ii,jj).ne.-999.0.and.
     #       mask(ii,jj).eq.1)   then 
          ng=ng+1 
        end  if 
        if  (sate(ii,jj).lt.0.0.and. 
     #       sate(ii,jj).ne.-999.0)   then 
          ns=ns+1 
        end  if
        if  (first(ii,jj).lt.0.0.and. 
     #       first(ii,jj).ne.-999.0.and.
     #       mask(ii,jj).gt.0)   then 
          nf=nf+1 
        end  if
 1001 continue 
      if  (ng.ge.1)  then 
        write  (6,*)  'wrong input (gage):',ng 
        write  (6,*)  'Gage field must be define at anchor grids !' 
      end  if  
      if  (ns.ge.1)  then 
        write  (6,*)  'wrong input (sate):',ns  
        write  (6,*)  'No negative satellite estimates are allowed !' 
      end  if 
      if  (nf.ge.1)  then 
        write  (6,*)  'wrong input (first):',nf  
        write  (6,*)  'First guess must be define at every grid !'  
      end  if 
      if  ((ng+ns+nf).ge.1)   then 
        stop 
      end  if  
c  
c     *************************************************************************
c     ***                                                                   ***
c     ***   2.  to define the blending parameters                           ***
c     ***                                                                   ***
c     *************************************************************************
c  
      call  def_para   (flp_lim,alpha) 
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   3.  to blend the satellite and gage data                        ***   
c     ***                                                                   ***
c     *************************************************************************
c
      call  cal_blend  (mode,nx,ny,mask,
     #                  gage,egage,sate,esate,first,
     #                  flp_lim,alpha,blend,eblend) 
c
 9999 return 
      end  
c
c
c     *************************************************************************
c     ***                                                                   ***
c     ***                                                                   ***
c     ***      *****  *****  *****         *****    *    *****    *         ***
c     ***       *  *  *      *             *   *   * *   *   *   * *        ***
c     ***       *  *  *****  *****         *****  *****  *****  *****       ***
c     ***       *  *  *      *             *      *   *  *  *   *   *       ***
c     ***      *****  *****  *      *****  *      *   *  *   *  *   *       ***
c     ***                                                                   ***
c     ***                                                                   ***
c     *************************************************************************
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   Subroutine    :                                                 ***
c     ***                   def_para                                        ***
c     ***                                                                   ***
c     ***   Objective     :                                                 ***
c     ***                   to define the operation modes and calculation   ***
c     ***                                                                   ***
c     ***                   parameters to be used in the followed           ***
c     ***                                                                   ***
c     ***                   subroutines                                     ***
c     ***                                                                   ***
c     *************************************************************************
c
      subroutine   def_para  (flp_lim,alpha)   
c
c     1.  blending procedures  
c
c     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c     +++                                                                   +++
c     +++  flp_lim      ==   limitation of difference in Laplacian          +++
c     +++                    between two consecssive calculation.           +++
c     +++                    Calculation will be regarded as completed      +++
c     +++                    when the differences for all grids are smaller +++
c     +++                    than the limitation.                           +++
c     +++                                                                   +++
c     +++  alpha        ==   coeffifient used to revise the field values    +++
c     +++                    ( 0.0 --  0.5 )                                +++
c     +++                                                                   +++
c     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c
      flp_lim      =  0.1   
      alpha        =  0.25  
c
c
      return 
      end  
c
c
c     *************************************************************************
c     ***                                                                   ***
c     ***                                                                   ***
c     ***   *****    *    *             *****  *      *****  *   *  *****   ***
c     ***   *       * *   *             *   *  *      *      **  *   *  *   ***
c     ***   *      *****  *             ****   *      *****  * * *   *  *   ***
c     ***   *      *   *  *             *   *  *      *      *  **   *  *   ***
c     ***   *****  *   *  *****  *****  *****  *****  *****  *   *  *****   ***
c     ***                                                                   ***
c     ***                                                                   ***
c     *************************************************************************
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   Subroutine     :                                                ***
c     ***                                                                   ***
c     ***                      cal_blend                                    ***
c     ***                                                                   ***
c     ***   Objective      :                                                ***
c     ***                                                                   ***
c     ***                      To construct the blended analysis of gage    ***
c     ***                                                                   ***
c     ***                      observation and satellite estimate of        ***
c     ***                                                                   ***
c     ***                      the target field using Laplacian             ***
c     ***                                                                   ***
c     ***                      interplotation                               ***
c     ***                                                                   ***
c     *************************************************************************
c
      subroutine   cal_blend  (mode,nx,ny,mask,
     #                         gage,egage,sate,esate,first,
     #                         flp_lim,alpha,blend,eblend)  
c
      dimension       mask(nx,ny),first(nx,ny), 
     #                 gage(nx,ny), sate(nx,ny), blend(nx,ny), 
     #                egage(nx,ny),esate(nx,ny),eblend(nx,ny)
c 
      dimension       shape(1000,1000),field(1000,1000)  
      data            shape/1000000*0.0/,field/1000000*0.0/ 
c 
c     *************************************************************************
c     ***                                                                   ***
c     ***   1.  to define the field of Laplacian of satellite estimate      ***  
c     ***                                                                   ***
c     *************************************************************************
c
      do 1001 jj=1,ny 
      do 1001 ii=1,nx 
        shape(ii,jj)=0.0 
 1001 continue 
      do 1002 jj=2,ny-1 
      do 1002 ii=2,nx-1  
        fc=sate(ii,jj)
        fn=sate(ii,jj+1)
        fs=sate(ii,jj-1)
        fw=sate(ii-1,jj)
        fe=sate(ii+1,jj) 
        if  (fc.ne.-999.0.and.
     #       fn.ne.-999.0.and.
     #       fs.ne.-999.0.and.
     #       fw.ne.-999.0.and.
     #       fe.ne.-999.0)  then 
          shape(ii,jj)=fn+fs+fw+fe-4.0*fc 
        end  if  
 1002 continue  
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   2.  to define the blended field                                 *** 
c     ***                                                                   ***
c     *************************************************************************
c
      do 2001 jj=1,ny   
      do 2001 ii=1,nx   
        if  (mask(ii,jj).eq.0)  then 
c         field(ii,jj)=-999.0 
          field(ii,jj)=sate(ii,jj)  
        else if  (mask(ii,jj).eq.1)  then 
          field(ii,jj)=gage(ii,jj) 
        else 
          field(ii,jj)=first(ii,jj)  
        end  if  
 2001 continue  
c
 2002 n_undef=0  
      do 2003 jj=2,ny-1   
      do 2003 ii=2,nx-1  
        if  (mask(ii,jj).eq.2)  then  
          rc=field(ii,jj)
          rn=field(ii,jj+1)
          rs=field(ii,jj-1)
          rw=field(ii-1,jj)
          re=field(ii+1,jj)
          if  (rc.ne.-999.0.and. 
     #         rn.ne.-999.0.and. 
     #         rs.ne.-999.0.and. 
     #         rw.ne.-999.0.and. 
     #         re.ne.-999.0)  then 
            rlap=rn+rs+rw+re-4.0*rc  
          else  
            rlap=0.0 
          end  if  
          rdif=rlap-shape(ii,jj) 
          if  (abs(rdif).gt.flp_lim)  then  
            n_undef=n_undef+1 
            field(ii,jj)=field(ii,jj)+alpha*rdif  
          end  if  
        end  if  
 2003 continue
      if  (n_undef.ne.0)  then  
        go  to  2002
      else  
        do 2004 jj=1,ny 
        do 2004 ii=1,nx   
          if  (mask(ii,jj).eq.0)  then 
            blend(ii,jj)=field (ii,jj)  
          else  
            if  (field(ii,jj).ge.0.0)  then  
              blend(ii,jj)=field(ii,jj)
            else  
              if  (field(ii,jj).ne.-999.0)  then 
                blend(ii,jj)=0.0  
                field(ii,jj)=0.0  
              end  if  
            end  if  
          end  if  
 2004   continue  
      end  if
c
c     *************************************************************************
c     ***                                                                   ***
c     ***   3.  to smooth the results                                       *** 
c     ***                                                                   ***
c     *************************************************************************
c
      if  (mode.ne.0)  then 
        call  smoothing  (mode,nx,ny,mask,field,blend) 
      end  if  
c 
c     *************************************************************************
c     ***                                                                   ***
c     ***   4.  to define the error field                                   ***
c     ***                                                                   ***
c     *************************************************************************
c 
      do 4001 jj=1,ny 
      do 4001 ii=1,nx 
        if  (blend(ii,jj).lt.0.0)  then 
          eblend(ii,jj)=-999.0 
        else  
          if  (mask(ii,jj).eq.0)  then 
            eblend(ii,jj)=-999.0 
          else  if  (mask(ii,jj).eq.1)  then 
            eblend(ii,jj)=egage(ii,jj) 
          else  
            eblend(ii,jj)=esate(ii,jj) 
          end  if  
        end  if  
 4001 continue 
c
 9999 return  
      end 
c
c 
c     *************************************************************************
c     ***                                                                   ***
c     ***                                                                   ***
c     ***   *****  *   *  *****  *****  *****  *   *  *****  *   *  *****   ***
c     ***   *      ** **  *   *  *   *    *    *   *    *    **  *  *       ***
c     ***   *****  * * *  *   *  *   *    *    *****    *    * * *  *  **   ***
c     ***       *  *   *  *   *  *   *    *    *   *    *    *  **  *   *   ***
c     ***   *****  *   *  *****  *****    *    *   *  *****  *   *  *****   ***
c     ***                                                                   ***
c     ***                                                                   ***
c     *************************************************************************
c
c     *************************************************************************
c     ***                                                                   ***
c     ***  Subroutine     :                                                 ***
c     ***                                                                   ***
c     ***                    smoothing                                      ***
c     ***                                                                   ***
c     ***  Objective      :                                                 ***
c     ***                                                                   ***
c     ***                    To remove the unreal and unwanted small scale  ***
c     ***                                                                   ***
c     ***                    features in the original blended analysis      ***
c     ***                                                                   ***
c     ***                    by using a linear ninomial (1-2-1) smoothing   ***
c     ***                                                                   ***
c     ***                    filter                                         ***
c     ***                                                                   ***
c     *************************************************************************
c
      subroutine   smoothing  (mode,nx,ny,mask,orig,smooth)  
c
      dimension    mask(nx,ny),orig(1000,1000),smooth(nx,ny)
c 
      dimension    kcheck(1000,1000),wei(3) 
      data         kcheck/1000000*0/,wei/1.0,2.0,1.0/
c
c
c     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c     +++                                                                   +++
c     +++  mod_smooth   ==   smoothing mode                                 +++
c     +++                                                                   +++
c     +++                    0  ---  no smooth process                      +++
c     +++                    1  ---  bi-directional linear smoothing        +++
c     +++                    2  ---  smoothing but keep benchmark unchange  +++
c     +++                                                                   +++
c     +++  mask         ==   land/ocean mask                                +++
c     +++                    0  ---  no ocean grid                          +++
c     +++                    1  ---  anchor land grid                       +++
c     +++                    2  ---  non-anchor land grid                   +++
c     +++                                                                   +++
c     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c
c     #########################################################################   
c     ###                                                                   ### 
c     ###   1.  to define the smoothing points                              ### 
c     ###          kcheck  ==  0    smoothing needed                        ### 
c     ###                      1    keep as the same as in orig             ### 
c     ###                                                                   ### 
c     #########################################################################   
c 
      if  (mode.eq.1)  then 
        do 1001 jj=1,ny 
        do 1001 ii=1,nx 
          if  (mask(ii,jj).eq.0)  then 
            kcheck(ii,jj)=1 
          else  
            kcheck(ii,jj)=0 
          end  if  
 1001   continue 
      else  if  (mode.eq.2)  then 
        do 1002 jj=1,ny 
        do 1002 ii=1,nx 
          if  (mask(ii,jj).eq.0)  then 
            kcheck(ii,jj)=1 
          else  if  (mask(ii,jj).eq.1)  then 
            kcheck(ii,jj)=1 
          else  
            kcheck(ii,jj)=0 
          end  if  
 1002   continue 
      else 
        write  (6,*)  'wrong smoothing mode:',mode  
        write  (6,*)  'Please select from 0, 1, or 2 !!' 
      end  if  
c 
c     #########################################################################   
c     ###                                                                   ### 
c     ###   2.  to smooth the blended field                                 ###  
c     ###                                                                   ### 
c     #########################################################################   
c
      do 2002 jj=2,ny-1  
      do 2002 ii=2,nx-1 
        if  (kcheck(ii,jj).ne.1)  then
          sw=0.0
          sr=0.0
          do 2001 i=1,3
            if  (orig(ii-2+i,jj).ne.-999.0)  then
              sw=sw+wei(i)
              sr=sr+wei(i)*orig(ii-2+i,jj)
            end  if
 2001     continue
          if  (sw.ne.0.0)  then
            orig(ii,jj)=sr/sw
          else
            orig(ii,jj)=-999.0
          end  if
        end  if
 2002 continue
      do 2004 jj=2,ny-1 
      do 2004 ii=2,nx-1 
        if  (kcheck(ii,jj).ne.1)  then 
          sw=0.0
          sr=0.0
          do 2003 j=1,3
            if  (orig(ii,jj-2+j).ne.-999.0)  then
              sw=sw+wei(j)
              sr=sr+wei(j)*orig(ii,jj-2+j)
            end  if
 2003     continue
          if  (sw.ne.0.0)  then
            orig(ii,jj)=sr/sw
          else
            orig(ii,jj)=-999.0
          end  if
        end  if
 2004 continue
c
      do 2005 jj=1,ny
      do 2005 ii=1,nx 
        smooth(ii,jj)=orig(ii,jj)
 2005 continue
c
 9999 return  
      end 
