ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c  PROGRAM:            get_gpi_fc.f
c
c  LANGAUGE:           fortran
c
c  MACHINE:            cpcnfns (compute farm)
c
c--------------------------------------------------------------------------------------------
c
c  PURPOSE:            To define the fractional coverage at 275K and 235K from Tb arrays
c
c  USAGE:              N/A
c
c--------------------------------------------------------------------------------------------
c
c  INPUT FILES:        unit  9 = gpidate.txt
c                      unit 10 = qcfilelist.txt
c                      unit 20 = metsat_tbb_full.gra.*          
c
c  OUPUT FILES:        unit 50 = africa_fc_275.gra.
c                      unit 60 = africa_fc_235.gra.
c
c--------------------------------------------------------------------------------------------
c
c  SUBROUTINES:        N/A
c
c  FUNCTIONS:          int, ichar, float
c
c--------------------------------------------------------------------------------------------
c
c  INPUT VARS:         see below declarations
c
c  OUTPUT VARS:        see below declarations
c
c--------------------------------------------------------------------------------------------
c
c  AUTHORS:            PingPing Xie, Vadlamani Kumar, Nick Novella
c
c  DATE:               Sept, 2013
c
c  MODIFICATIONS:      Sept, 2013
c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      parameter    ( nx0=3848, ny0=3298, nx1=2064, ny1=2202 ) 
      parameter    ( nx2=751,  ny2=801 ) 

      character*1  cir  (nx0,ny0)  
       
      character    cls*40, crm*24 
      character    cfile1*49, cfile275*26, cfile235*26, cdate*8	
          
      dimension    jgrid (ny1), igrid (nx1),  
     #             fc000 (nx2,ny2), fcttt (nx2,ny2),  
     #             fc275 (nx2,ny2), fc235 (nx2,ny2)   

c     Get GPI Date
      open  (unit=9,file='gpidate.txt', 
     #       access='sequential',status='old',form='formatted') 
      read  (9,1901)  cdate
 1901 format (a8)
      close (unit=9) 
      write  (6,*)  'started def_fc for: ',cdate      
     
c     Create QC filelist
      cls ( 1:40) = 'ls metsat_tbb_full.gra* > qcfilelist.txt' 
      call system  ( cls ) 
      write  (6,*)  '     finished file listing !!'   


c     To open the QC files 
      open  ( unit=10, file='qcfilelist.txt', 
     #        access='sequential', status='old',form='formatted') 
      write  (6,*)  '     finished opening file !!' 


c     To initilize the data arrays
      do 3001 jj = 1, ny2 
      do 3001 ii = 1, nx2  
        fc000 (ii,jj) = 0.0 
        fc275 (ii,jj) = 0.0 
        fc235 (ii,jj) = 0.0 
        fcttt (ii,jj) = 0.0 
 3001 continue 
      do 3002 j = 1, ny1
        rlat      = (j-1) * 0.036383683 - 40.0437    
        jgrid (j) = int((rlat+40.05)/0.1) + 1
        if  (jgrid(j).lt.1.or.
     #       jgrid(j).gt.ny2)  then
          write  (6,*)  'wrong jj grid:',jgrid,j,rlat
        end  if
 3002 continue
      do 3003 i = 1, nx1
        rlon      = (i-1) * 0.036378335 - 20.0260
        igrid (i) = int((rlon+20.05)/0.1) + 1
        if  (igrid(i).lt.1.or.
     #       igrid(i).gt.nx2)  then
          write  (6,*)  'wrong ii grid:',igrid,i,rlon
        end  if
 3003 continue
      do 3004 j = 1, ny1 
      do 3004 i = 1, nx1 
        jj = jgrid (j) 
        ii = igrid (i) 
        fcttt (ii,jj) = fcttt (ii,jj) + 1.0 
 3004 continue 
      write  (6,*)  '     finished initializing !!'


c     To read the tbb and define the histogram
      nfile = 0 
 4000 read  (10,4901,end=4002)   cfile1  
      nfile = nfile + 1 
      write  (6,*)  '     started for file:',nfile 
      write  (6,*)  '                      ',cfile1 
 4901 format  (a49) 
c
      open  ( unit=20, 
     #        file=cfile1,convert='little_endian', 
     #        access='direct',status='old',recl=nx0*ny0) 
c
      read  (20,rec=1)   cir 
      do 4001 j = 1, ny1 
      do 4001 i = 1, nx1 
        j0 = j + 548 
        i0 = i + 1374   
        js = 3299 - j0 
        is = i0 
        kir = ichar (cir(is,js)) 
        if  (kir.lt.255)  then 
          tbb  = float (kir) + 75.0 
        else 
          tbb  = -999.0 
        end  if  
        if  (tbb.ne.-999.0)  then 
          jj = jgrid (j) 
          ii = igrid (i)  
          fc000 (ii,jj) = fc000 (ii,jj) + 1.0 
          if  (tbb.le.275.0)  then 
            fc275 (ii,jj) = fc275 (ii,jj) + 1.0 
            if  (tbb.le.235.0)  then 
              fc235 (ii,jj) = fc235 (ii,jj) + 1.0 
            end  if  
          end  if  
        end  if  
 4001 continue 
c
      close  (unit=20) 
      write  (6,*)  '     finished for file:',nfile 
c
      go  to  4000 
 4002 write  (6,*)  '     finished defining histograms !!', nfile  
c
      do 4003 jj = 1, ny2 
      do 4003 ii = 1, nx2 
        if  (fc000(ii,jj).ge.4.0)  then 
          fc275 (ii,jj) = fc275 (ii,jj) / fcttt (ii,jj) 
          fc235 (ii,jj) = fc235 (ii,jj) / fcttt (ii,jj) 
        else 
          fc275 (ii,jj) = -999.0 
          fc235 (ii,jj) = -999.0 
        end  if  
        fc000 (ii,jj) = fc000 (ii,jj) / fcttt (ii,jj) 
 4003 continue 
      write  (6,*)  '     finished defining FC !!' 


c     To check out strange lines 
      do 5002 jj = 1, 801 
      do 5002 ii = 1, 751 
        if  (fc235(ii,jj).ne.-999.0.and.
     #       fc235 (ii,jj).le.1.0)  then 
          j1 = jj - 1 
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + 1 
          if  (j2.gt.801)  then 
            j2 = 801 
          end  if  
          i1 = ii - 1 
          if  (i1.lt.1)  then 
            i1 = 1 
          end  if  
          i2 = ii + 1 
          if  (i2.gt.751)  then 
            i2 = 751 
          end  if  
          nn = 0 
          do 5001 j = j1, j2 
          do 5001 i = i1, i2 
            if  (fc235(i,j).ge.1.0)  then 
              nn = nn + 1 
            end  if  
 5001     continue 
          if  (nn.le.3)  then 
            fc235 (ii,jj) = 0.0 
          end  if  
        end  if  
 5002 continue 
c
      do 5004 jj = 1, 801 
      do 5004 ii = 1, 751 
        if  (fc275(ii,jj).ne.-999.0.and.
     #       fc275 (ii,jj).le.1.0)  then 
          j1 = jj - 1 
          if  (j1.lt.1)  then 
            j1 = 1 
          end  if  
          j2 = jj + 1 
          if  (j2.gt.801)  then 
            j2 = 801 
          end  if  
          i1 = ii - 1 
          if  (i1.lt.1)  then 
            i1 = 1 
          end  if  
          i2 = ii + 1 
          if  (i2.gt.751)  then 
            i2 = 751 
          end  if  
          nn = 0 
          do 5003 j = j1, j2 
          do 5003 i = i1, i2 
            if  (fc275(i,j).ge.1.0)  then 
              nn = nn + 1 
            end  if  
 5003     continue 
          if  (nn.le.3)  then 
            fc275 (ii,jj) = 0.0 
          end  if  
        end  if  
 5004 continue


c     To output  
      cfile275 ( 1:18) = 'africa_fc_275.gra.'
      cfile275 (19:26) = cdate (1:8) 
      cfile235 ( 1:18) = 'africa_fc_235.gra.'
      cfile235 (19:26) = cdate (1:8)
c
      open  (unit=50, 
     #       file=cfile275,
     #       access='direct',status='unknown',recl=nx2*ny2*4) 
      open  (unit=60,
     #       file=cfile235,
     #       access='direct',status='unknown',recl=nx2*ny2*4) 
c
      write  (50,rec=1)   fc275 
      write  (50,rec=2)   fc000  
      write  (60,rec=1)   fc235 
      write  (60,rec=2)   fc000 
      write  (6,*)  '     finished output !!' 
c
      write  (6,*)  'finished for: ',cdate  

c
      stop 
      end 
    
     