ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c  PROGRAM:            get_gpi_qc.f
c
c  LANGAUGE:           fortran
c
c  MACHINE:            cpcnfns (compute farm)
c
c--------------------------------------------------------------------------------------------
c
c  PURPOSE:            To conduct quality control for the meteosat TB 
c
c  USAGE:              N/A
c
c--------------------------------------------------------------------------------------------
c
c  INPUT FILES:        unit 20 = irfilelist.txt
c                      unit 71 = metsat_tbb_05_previous.gra
c                      unit 72 = metsat_tbb_full.1byte          
c
c  OUPUT FILES:        unit 71 = metsat_tbb_05_previous.gra
c                      unit 72 = metsat_tbb_full.1byte
c                      unit 73 = metsat_tbb_05_orig.gra
c                      unit 74 = metsat_tbb_05_qced.gra
c                      unit 75 = metsat_qc.log   
c
c--------------------------------------------------------------------------------------------
c
c  SUBROUTINES:        N/A
c
c  FUNCTIONS:          int, ichar, float, sqrt, char
c
c--------------------------------------------------------------------------------------------
c
c  INPUT VARS:         see below declarations
c
c  OUTPUT VARS:        see below declarations
c
c--------------------------------------------------------------------------------------------
c
c  AUTHORS:            PingPing Xie, Vadlamani Kumar, Nick Novella
c
c  DATE:               Sept, 2013
c
c  MODIFICATIONS:      Sept, 2013
c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      parameter      ( nx0 = 3848, ny0 = 3298, nx1 = 280, ny1 = 240 ) 
      character      cfile*25, ctime*12
      character      ccp*50, cmv1*61, cmv2*61, cmv3*57	
      character*1    cir (nx0,ny0), cmiss  
      dimension      igrid (nx0), jgrid (ny0)
      dimension      tbb0  (nx1,ny1), tbb1  (nx1,ny1), ndat (nx1,ny1),  
     #               corr0 (ny1)    , corr1 (ny1)    , 
     #               kflag0(ny0)    , kflag1(ny1) 
	
      nfile = 0 

c     To open files 
      open  (unit=20,file='irfilelist.txt', 
     #       access='sequential',status='old',form='formatted') 
     
      open  (unit=71,file='metsat_tbb_05_previous.gra',
     #       convert='big_endian',access='direct',
     #       status='unknown',recl=nx1*ny1*4) 
     
      open  (unit=72,file='metsat_tbb_full.1byte',
     #       convert='big_endian',access='direct',
     #       status='unknown',recl=nx0*ny0)
     
      open  (unit=73,file='metsat_tbb_05_orig.gra',
     #       convert='little_endian',access='direct',
     #       status='unknown',recl=nx1*ny1*4)
     
      open  (unit=74,file='metsat_tbb_05_qced.gra',
     #       convert='little_endian',access='direct',
     #       status='unknown',recl=nx1*ny1*4)
     
      open  (unit=75,file='metsat_qc.log',    
     #       access='sequential',status='unknown',form='formatted') 

c     To read the file name 
 3000 read  (20,3901,end=4000)   cfile  
 3901 format  (a25) 
      nfile = nfile + 1 
      write  (6,3901)  cfile  

c     To copy raw to generic 
      ccp   ( 1:  3) = 'cp ' 
      ccp   ( 4: 28) = cfile(1:25) 
      ccp   ( 29:50) = ' metsat_tbb_full.1byte' 
c      write(6,*)  '       *******************', ccp
      call  system  ( ccp ) 

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Begin QC'ING
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     To define grid box conversion table  
      do 2001 j = 1, ny0 
        rlat = (j-1) * 0.036383683  
        jgrid (j) = int (rlat/0.5) + 1 
        jgrid (j) = ny1 - jgrid (j)  + 1  
        if  (jgrid(j).lt.1.or. 
     #       jgrid(j).gt.ny1)  then 
          write  (6,*)  'wrong grid j:',j,rlat,jgrid(j) 
        end  if  
 2001 continue 
      do 2002 i = 1, nx0 
        rlon = (i-1) * 0.036378335 
        igrid (i) = int (rlon/0.5) + 1 
        if  (igrid(i).lt.1.or. 
     #       igrid(i).gt.nx1)  then 
          write  (6,*)  'wrong grid i:',i,rlon,igrid(i) 
        end  if  
 2002 continue
      write(6,*)  '          finished defining 0.5 grid location !!' 


c     Read previous Tb data
      read  (71,rec=1)   tbb0
      write  (6,*)  '          finished reading ref data !!' 


c     Define 0.5 degree Grid Box for current data
      read  (72,rec=1)   cir 
      do 4001 jj = 1, ny1 
      do 4001 ii = 1, nx1 
        ndat (ii,jj) = 0 
        tbb1 (ii,jj) = 0.0 
 4001 continue 
      do 4002 j = 1, ny0 
      do 4002 i = 1, nx0 
        ktb = ichar (cir(i,j)) + 75 
        if  (ktb.ne.330)  then 
          ii           = igrid (i) 
          jj           = jgrid (j) 
          ndat (ii,jj) = ndat (ii,jj) + 1 
          tbb1 (ii,jj) = tbb1 (ii,jj) + float (ktb) 
        end  if    
 4002 continue 
      do 4003 jj = 1, ny1 
      do 4003 ii = 1, nx1 
        if  (ndat(ii,jj).ge.30)  then 
          tbb1 (ii,jj) = tbb1 (ii,jj) / ndat (ii,jj) 
        else 
          tbb1 (ii,jj) = -999.0 
        end  if  
 4003 continue 
      write  (73,rec=1)   tbb1 
      write  (6,*)  '          finished defining 0.5 grid mean !!' 

	
c     To Calculate Lag Correlation for current data
      do 5001 jj = 1, ny1  
        corr0 (jj) = -999.0 
 5001 continue 
      do 5004 ky = 1, 5  
      do 5004 kx = 1, 5  
        if  (kx.eq.3.and.ky.eq.3)  then 
          go  to  5004 
        end  if  
        kdy = ky - 3 
        kdx = kx - 3  
        do 5003 jj = 1, ny1   
          nn  = 0 
          sx  = 0.0 
          sy  = 0.0 
          sxx = 0.0 
          sxy = 0.0 
          syy = 0.0 
          cor = -999.0 
          do 5002 ii =  1, nx1  
            yy = tbb1 (ii,jj) 
            if  (yy.ne.-999.0)  then 
              j = jj + kdy 
              i = ii + kdx  
              if  (i.ge.1.and.i.le.nx1.and.
     #             j.ge.1.and.j.le.ny1)  then  
                xx  = tbb1 (i,j) 
                nn  = nn  + 1 
                sx  = sx  + xx 
                sy  = sy  + yy 
                sxx = sxx + xx * xx 
                sxy = sxy + xx * yy 
                syy = syy + yy * yy 
              end  if  
            end  if  
 5002     continue  
          if  (nn.ge.(nx1/2))  then 
            ax  = sx  / nn 
            ay  = sy  / nn 
            axx = sxx - nn * ax * ax 
            axy = sxy - nn * ax * ay 
            ayy = syy - nn * ay * ay 
            if  (axx.gt.0.0.and.ayy.gt.0.0)  then 
              cor = axy / sqrt (axx*ayy) 
              if  (cor.gt.corr0(jj))  then 
                corr0 (jj) = cor 
              end  if  
            end  if  
          end  if  
 5003   continue 
 5004 continue 
      write(6,*) '          finished calculating lag-correlation !!' 

	
c     To Calculate Cross Correlation for current data
      do 6001 jj = 1, ny1  
        corr1 (jj) = -999.0 
 6001 continue 
      do 6004 ky = 1, 5  
      do 6004 kx = 1, 5  
        kdy = ky - 3 
        kdx = kx - 3  
        do 6003 jj = 1, ny1   
          nn  = 0 
          sx  = 0.0 
          sy  = 0.0 
          sxx = 0.0 
          sxy = 0.0 
          syy = 0.0 
          cor = -999.0 
          do 6002 ii =  1, nx1  
            yy = tbb1 (ii,jj) 
            if  (yy.ne.-999.0)  then 
              j = jj + kdy 
              i = ii + kdx  
              if  (i.ge.1.and.i.le.nx1.and.
     #             j.ge.1.and.j.le.ny1)  then  
                xx  = tbb0 (i,j) 
                nn  = nn  + 1 
                sx  = sx  + xx 
                sy  = sy  + yy 
                sxx = sxx + xx * xx 
                sxy = sxy + xx * yy 
                syy = syy + yy * yy 
              end  if  
            end  if  
 6002     continue  
          if  (nn.ge.(nx1/2))  then 
            ax  = sx  / nn 
            ay  = sy  / nn 
            axx = sxx - nn * ax * ax 
            axy = sxy - nn * ax * ay 
            ayy = syy - nn * ay * ay 
            if  (axx.gt.0.0.and.ayy.gt.0.0)  then 
              cor = axy / sqrt (axx*ayy) 
              if  (cor.gt.corr1(jj))  then 
                corr1 (jj) = cor 
              end  if  
            end  if  
          end  if  
 6003   continue 
 6004 continue 
      write(6,*)  '          finished calculating crs-correlation !!' 


c     To set flag for missing line ( kflag: 1=missing, 0=good)
      do 7001 jj = 1, ny1 
        kflag1 (jj) = 1  
 7001 continue 
      do 7002 jj = 1, ny1 
        if  (corr0(jj).ge.0.5)  then 
          kflag1 (jj) = 0 
        else   
          if (corr0(jj).ge.0.4.and. 
     #        corr1(jj).ge.0.4)  then 
            kflag1 (jj) = 0 
          end  if  
        end  if  
 7002 continue 
      do 7003 j = 1, ny0 
        jj = jgrid (j) 
        kflag0 (j) = kflag1 (jj) 
 7003 continue  
      write  (6,*)  '          finished setting flag !!'  

c     To set tbb as missing for flagged pixels
      kmiss = 255 
      cmiss = char (kmiss) 
      do 8002 j = 1, ny0 
        if  (kflag0 (j).eq.1)  then 
          do 8001 i = 1, nx0 
            cir (i,j) = cmiss (1:1) 
 8001     continue 
        end  if  
 8002 continue  
      do 8003 jj = 1, ny1 
      do 8003 ii = 1, nx1 
        ndat (ii,jj) = 0 
        tbb1 (ii,jj) = 0.0 
 8003 continue 
      do 8004 j = 1, ny0 
      do 8004 i = 1, nx0 
        ktb = ichar (cir(i,j)) + 75 
        if  (ktb.ne.330)  then 
          ii           = igrid (i) 
          jj           = jgrid (j) 
          ndat (ii,jj) = ndat (ii,jj) + 1 
          tbb1 (ii,jj) = tbb1 (ii,jj) + float (ktb) 
        end  if    
 8004 continue 
      do 8005 jj = 1, ny1 
      do 8005 ii = 1, nx1 
        if  (ndat(ii,jj).ge.30)  then 
          tbb1 (ii,jj) = tbb1 (ii,jj) / ndat (ii,jj) 
        else 
          tbb1 (ii,jj) = -999.0 
        end  if  
 8005 continue
      write  (72,rec=1)   cir  
      write  (74,rec=1)   tbb1 
      write  (6,*)  '          finished defining missing values  !!' 

c     Output QC'ed data
      nmiss = 0 
      do 9001 jj = 1, ny1 
        if  (kflag1(jj).eq.1)  then 
          nmiss = nmiss + 1 
        end  if  
 9001 continue 
      nmiss0 = int (ny1*0.1) 
      if  (nmiss.lt.nmiss0)  then 
        write  (71,rec=1)   tbb1  
      end  if  
c
      write  (6,*)  '          finished output !!' 
c
      write  (6,*)  '     finished quality control !!', nmiss    
c
      write  (75,*)  nmiss,' 0.5 deg lines set as missing.' 

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Output
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


c     Time Stamp Tb files
      ctime ( 1: 12) = cfile (8:19) 
      write  (6,*)  ctime,'  ',nmiss 
c
      cmv1 (  1: 26) = 'cp metsat_tbb_05_qced.gra '
      cmv1 ( 27: 49) = 'metsat_tbb_05_qced.gra.'
      cmv1 ( 50: 61) = ctime (1:12) 
      call  system  ( cmv1 ) 
c
      cmv2 (  1: 26) = 'cp metsat_tbb_05_orig.gra '
      cmv2 ( 27: 49) = 'metsat_tbb_05_orig.gra.'
      cmv2 ( 50: 61) = ctime (1:12) 
      call  system  ( cmv2 ) 
c
      cmv3 (  1: 25) = 'cp metsat_tbb_full.1byte '
      cmv3 ( 26: 45) = 'metsat_tbb_full.gra.'
      cmv3 ( 46: 57) = ctime (1:12)
      call  system  ( cmv3 )


	
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


c     To proceed to the next file 
      go  to  3000 


 4000 continue 
 
      write  (6,*)   ' '   
      write  (6,*)   'total number of files processed:',nfile   
      write  (6,*)  'finished quality control for the whole day !!' 

      stop 
      end 
	
	